--#SET TERMINATOR ;

CREATE SCHEMA "RTD";

CREATE TABLE "RTD"."REAL_TIME_FORMULAS" (
    "ID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY,
    "TABLE_SCHEMA" VARCHAR(128) NOT NULL,
    "TABLE_NAME" VARCHAR(128) NOT NULL,
    "COLUMN_NAME" VARCHAR(128) NOT NULL,
    "RTD_FORMULA" VARCHAR(255) NULL,
    "IS_DISABLED" SMALLINT NULL,
  CONSTRAINT "PK_REAL_TIME_FORMULAS"
    PRIMARY KEY ("ID"),
  CONSTRAINT "IX_REAL_TIME_FORMULAS_COLUMN"
    UNIQUE ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME")
);


CREATE TABLE "RTD"."REAL_TIME_TABLES" (
    "ID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY,
    "TABLE_SCHEMA" VARCHAR(128) NOT NULL,
    "TABLE_NAME" VARCHAR(128) NOT NULL,
    "LOAD_CODE" VARCHAR(2000) NULL,
    "IS_HISTORY" SMALLINT NULL,
    "IS_DISABLED" SMALLINT NULL,
    "TIME_ZONE" VARCHAR(50) NULL,
    "RTD_INSTANCE_NAME" VARCHAR(50) NULL,
  CONSTRAINT "PK_REAL_TIME_TABLES"
    PRIMARY KEY ("ID"),
  CONSTRAINT "IX_REAL_TIME_TABLES_TABLE"
    UNIQUE ("TABLE_SCHEMA", "TABLE_NAME")
);

--#SET TERMINATOR ;

CREATE TABLE "RTD"."ES_STOCK_LIST" (
    "CODE" VARCHAR(50) NOT NULL,
  CONSTRAINT "PK_ES_STOCK_LIST"
    PRIMARY KEY ("CODE")
);


--#SET TERMINATOR ;

CREATE TABLE "RTD"."ES_HISTORICAL_PRICES" (
    "SYMBOL" VARCHAR(50) NOT NULL,
    "DATE" DATE NOT NULL,
    "TIME" TIME NULL,
    "LAST" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "BID_SIZE" INTEGER NULL,
    "ASK_SIZE" INTEGER NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "VOLUME" BIGINT NULL,
    "OPEN_INT" INTEGER NULL,
    "TRADE_PRICE" DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
  CONSTRAINT "PK_ES_HISTORICAL_PRICES"
    PRIMARY KEY ("SYMBOL", "DATE")
);


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'ES_HISTORICAL_PRICES', 'SELECT CODE FROM RTD.ES_STOCK_LIST', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_HISTORICAL_PRICES', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_HISTORICAL_PRICES', 'SYMBOL', '=RTD("esrtd",,[CODE],"Symbol")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_HISTORICAL_PRICES', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_HISTORICAL_PRICES', 'TIME', '=RTD("esrtd",,[CODE],"Time")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_HISTORICAL_PRICES', 'LAST', '=RTD("esrtd",,[CODE],"Last")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_HISTORICAL_PRICES', 'TRADE_PRICE', '=RTD("esrtd",,[CODE],"TradePrice")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_HISTORICAL_PRICES', 'CHANGE', '=RTD("esrtd",,[CODE],"Change")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_HISTORICAL_PRICES', 'PERCENT_CHANGE', '=RTD("esrtd",,[CODE],"% Change")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_HISTORICAL_PRICES', 'BID', '=RTD("esrtd",,[CODE],"Bid")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_HISTORICAL_PRICES', 'ASK', '=RTD("esrtd",,[CODE],"Ask")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_HISTORICAL_PRICES', 'BID_SIZE', '=RTD("esrtd",,[CODE],"Bid Size")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_HISTORICAL_PRICES', 'ASK_SIZE', '=RTD("esrtd",,[CODE],"Ask Size")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_HISTORICAL_PRICES', 'OPEN', '=RTD("esrtd",,[CODE],"Open")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_HISTORICAL_PRICES', 'HIGH', '=RTD("esrtd",,[CODE],"High")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_HISTORICAL_PRICES', 'LOW', '=RTD("esrtd",,[CODE],"Low")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_HISTORICAL_PRICES', 'VOLUME', '=RTD("esrtd",,[CODE],"Volume")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_HISTORICAL_PRICES', 'OPEN_INT', '=RTD("esrtd",,[CODE],"OpenInt")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_HISTORICAL_PRICES', 'LAST_UPDATE_TIMESTAMP', '=TimeStamp()', NULL);

--#SET TERMINATOR ;

CREATE TABLE "RTD"."ES_LAST_STOCK_QUOTES" (
    "SYMBOL" VARCHAR(50) NOT NULL,
    "DATE" DATE NULL,
    "TIME" TIME NULL,
    "LAST" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "BID_SIZE" INTEGER NULL,
    "ASK_SIZE" INTEGER NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "VOLUME" BIGINT NULL,
    "OPEN_INT" INTEGER NULL,
    "TRADE_PRICE" DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
  CONSTRAINT "PK_ES_LAST_STOCK_QUOTES"
    PRIMARY KEY ("SYMBOL")
);


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'ES_LAST_STOCK_QUOTES', 'SELECT CODE FROM RTD.ES_STOCK_LIST', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_LAST_STOCK_QUOTES', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_LAST_STOCK_QUOTES', 'SYMBOL', '=RTD("esrtd",,[CODE],"Symbol")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_LAST_STOCK_QUOTES', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_LAST_STOCK_QUOTES', 'TIME', '=RTD("esrtd",,[CODE],"Time")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_LAST_STOCK_QUOTES', 'LAST', '=RTD("esrtd",,[CODE],"Last")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_LAST_STOCK_QUOTES', 'TRADE_PRICE', '=RTD("esrtd",,[CODE],"TradePrice")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_LAST_STOCK_QUOTES', 'CHANGE', '=RTD("esrtd",,[CODE],"Change")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_LAST_STOCK_QUOTES', 'PERCENT_CHANGE', '=RTD("esrtd",,[CODE],"% Change")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_LAST_STOCK_QUOTES', 'BID', '=RTD("esrtd",,[CODE],"Bid")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_LAST_STOCK_QUOTES', 'ASK', '=RTD("esrtd",,[CODE],"Ask")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_LAST_STOCK_QUOTES', 'BID_SIZE', '=RTD("esrtd",,[CODE],"Bid Size")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_LAST_STOCK_QUOTES', 'ASK_SIZE', '=RTD("esrtd",,[CODE],"Ask Size")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_LAST_STOCK_QUOTES', 'OPEN', '=RTD("esrtd",,[CODE],"Open")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_LAST_STOCK_QUOTES', 'HIGH', '=RTD("esrtd",,[CODE],"High")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_LAST_STOCK_QUOTES', 'LOW', '=RTD("esrtd",,[CODE],"Low")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_LAST_STOCK_QUOTES', 'VOLUME', '=RTD("esrtd",,[CODE],"Volume")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_LAST_STOCK_QUOTES', 'OPEN_INT', '=RTD("esrtd",,[CODE],"OpenInt")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_LAST_STOCK_QUOTES', 'LAST_UPDATE_TIMESTAMP', '=TimeStamp()', NULL);

--#SET TERMINATOR ;

CREATE TABLE "RTD"."ES_STOCK_QUOTES_TICKS" (
    "ID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY,
    "SYMBOL" VARCHAR(50) NULL,
    "DATE" DATE NULL,
    "TIME" TIME NULL,
    "LAST" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "BID_SIZE" INTEGER NULL,
    "ASK_SIZE" INTEGER NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "VOLUME" BIGINT NULL,
    "OPEN_INT" INTEGER NULL,
    "TRADE_PRICE" DOUBLE NULL,
  CONSTRAINT "PK_ES_STOCK_QUOTES_TICKS"
    PRIMARY KEY ("ID")
);


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'ES_STOCK_QUOTES_TICKS', 'SELECT CODE FROM RTD.ES_STOCK_LIST', 1, 1, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TICKS', 'ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TICKS', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TICKS', 'SYMBOL', '=RTD("esrtd",,[CODE],"Symbol")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TICKS', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TICKS', 'TIME', '=RTD("esrtd",,[CODE],"Time")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TICKS', 'LAST', '=RTD("esrtd",,[CODE],"Last")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TICKS', 'TRADE_PRICE', '=RTD("esrtd",,[CODE],"TradePrice")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TICKS', 'CHANGE', '=RTD("esrtd",,[CODE],"Change")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TICKS', 'PERCENT_CHANGE', '=RTD("esrtd",,[CODE],"% Change")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TICKS', 'BID', '=RTD("esrtd",,[CODE],"Bid")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TICKS', 'ASK', '=RTD("esrtd",,[CODE],"Ask")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TICKS', 'BID_SIZE', '=RTD("esrtd",,[CODE],"Bid Size")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TICKS', 'ASK_SIZE', '=RTD("esrtd",,[CODE],"Ask Size")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TICKS', 'OPEN', '=RTD("esrtd",,[CODE],"Open")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TICKS', 'HIGH', '=RTD("esrtd",,[CODE],"High")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TICKS', 'LOW', '=RTD("esrtd",,[CODE],"Low")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TICKS', 'VOLUME', '=RTD("esrtd",,[CODE],"Volume")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TICKS', 'OPEN_INT', '=RTD("esrtd",,[CODE],"OpenInt")', NULL);

--#SET TERMINATOR ;

CREATE TABLE "RTD"."ES_STOCK_QUOTES_TIME" (
    "SYMBOL" VARCHAR(50) NOT NULL,
    "DATE" DATE NOT NULL,
    "TIME" TIME NOT NULL,
    "LAST" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "BID_SIZE" INTEGER NULL,
    "ASK_SIZE" INTEGER NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "VOLUME" BIGINT NULL,
    "OPEN_INT" INTEGER NULL,
    "TRADE_PRICE" DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
  CONSTRAINT "PK_ES_STOCK_QUOTES_TIME"
    PRIMARY KEY ("SYMBOL", "DATE", "TIME")
);


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'ES_STOCK_QUOTES_TIME', 'SELECT CODE FROM RTD.ES_STOCK_LIST', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TIME', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TIME', 'SYMBOL', '=RTD("esrtd",,[CODE],"Symbol")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TIME', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TIME', 'TIME', '=RTD("esrtd",,[CODE],"Time")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TIME', 'LAST', '=RTD("esrtd",,[CODE],"Last")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TIME', 'TRADE_PRICE', '=RTD("esrtd",,[CODE],"TradePrice")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TIME', 'CHANGE', '=RTD("esrtd",,[CODE],"Change")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TIME', 'PERCENT_CHANGE', '=RTD("esrtd",,[CODE],"% Change")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TIME', 'BID', '=RTD("esrtd",,[CODE],"Bid")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TIME', 'ASK', '=RTD("esrtd",,[CODE],"Ask")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TIME', 'BID_SIZE', '=RTD("esrtd",,[CODE],"Bid Size")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TIME', 'ASK_SIZE', '=RTD("esrtd",,[CODE],"Ask Size")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TIME', 'OPEN', '=RTD("esrtd",,[CODE],"Open")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TIME', 'HIGH', '=RTD("esrtd",,[CODE],"High")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TIME', 'LOW', '=RTD("esrtd",,[CODE],"Low")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TIME', 'VOLUME', '=RTD("esrtd",,[CODE],"Volume")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TIME', 'OPEN_INT', '=RTD("esrtd",,[CODE],"OpenInt")', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'ES_STOCK_QUOTES_TIME', 'LAST_UPDATE_TIMESTAMP', '=TimeStamp()', NULL);

