--#SET TERMINATOR ;

CREATE SCHEMA "RTD";

CREATE TABLE "RTD"."REAL_TIME_FORMULAS" (
    "ID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY,
    "TABLE_SCHEMA" VARCHAR(128) NOT NULL,
    "TABLE_NAME" VARCHAR(128) NOT NULL,
    "COLUMN_NAME" VARCHAR(128) NOT NULL,
    "RTD_FORMULA" VARCHAR(255) NULL,
    "IS_DISABLED" SMALLINT NULL,
  CONSTRAINT "PK_REAL_TIME_FORMULAS"
    PRIMARY KEY ("ID"),
  CONSTRAINT "IX_REAL_TIME_FORMULAS_COLUMN"
    UNIQUE ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME")
);


CREATE TABLE "RTD"."REAL_TIME_TABLES" (
    "ID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY,
    "TABLE_SCHEMA" VARCHAR(128) NOT NULL,
    "TABLE_NAME" VARCHAR(128) NOT NULL,
    "LOAD_CODE" VARCHAR(2000) NULL,
    "IS_HISTORY" SMALLINT NULL,
    "IS_DISABLED" SMALLINT NULL,
    "TIME_ZONE" VARCHAR(50) NULL,
    "RTD_INSTANCE_NAME" VARCHAR(50) NULL,
  CONSTRAINT "PK_REAL_TIME_TABLES"
    PRIMARY KEY ("ID"),
  CONSTRAINT "IX_REAL_TIME_TABLES_TABLE"
    UNIQUE ("TABLE_SCHEMA", "TABLE_NAME")
);

--#SET TERMINATOR ;

CREATE TABLE "RTD"."QUOTE_LIST_VFX" (
    "CODE" VARCHAR(50) NOT NULL,
  CONSTRAINT "PK_QUOTE_LIST_VFX"
    PRIMARY KEY ("CODE")
);


--#SET TERMINATOR ;

CREATE TABLE "RTD"."QUOTE_DAY_HISTORY_VFX" (
    "SYMBOL" VARCHAR(50) NOT NULL,
    "DATE" DATE NOT NULL,
    "TIME" TIME NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "CLOSE" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
  CONSTRAINT "PK_QUOTE_DAY_HISTORY_VFX"
    PRIMARY KEY ("SYMBOL", "DATE")
);


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'QUOTE_DAY_HISTORY_VFX', 'SELECT CODE FROM RTD.QUOTE_LIST_VFX', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_VFX', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_VFX', 'SYMBOL', '=VFX|Name![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_VFX', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_VFX', 'TIME', '=VFX|Time![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_VFX', 'CHANGE', '=VFX|NetChange![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_VFX', 'PERCENT_CHANGE', '=VFX|PercentChange![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_VFX', 'BID', '=VFX|Bid![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_VFX', 'ASK', '=VFX|Ask![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_VFX', 'OPEN', '=VFX|OpenPrice![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_VFX', 'HIGH', '=VFX|High![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_VFX', 'LOW', '=VFX|Low![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_VFX', 'CLOSE', '=VFX|ClosePrice![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_DAY_HISTORY_VFX', 'LAST_UPDATE_TIMESTAMP', '=TimeStamp()', NULL);

--#SET TERMINATOR ;

CREATE TABLE "RTD"."QUOTES_VFX" (
    "SYMBOL" VARCHAR(50) NOT NULL,
    "DATE" DATE NULL,
    "TIME" TIME NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "CLOSE" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
  CONSTRAINT "PK_QUOTES_VFX"
    PRIMARY KEY ("SYMBOL")
);


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'QUOTES_VFX', 'SELECT CODE FROM RTD.QUOTE_LIST_VFX', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_VFX', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_VFX', 'SYMBOL', '=VFX|Name![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_VFX', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_VFX', 'TIME', '=VFX|Time![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_VFX', 'CHANGE', '=VFX|NetChange![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_VFX', 'PERCENT_CHANGE', '=VFX|PercentChange![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_VFX', 'BID', '=VFX|Bid![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_VFX', 'ASK', '=VFX|Ask![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_VFX', 'OPEN', '=VFX|OpenPrice![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_VFX', 'HIGH', '=VFX|High![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_VFX', 'LOW', '=VFX|Low![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_VFX', 'CLOSE', '=VFX|ClosePrice![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTES_VFX', 'LAST_UPDATE_TIMESTAMP', '=TimeStamp()', NULL);

--#SET TERMINATOR ;

CREATE TABLE "RTD"."QUOTE_TICK_HISTORY_VFX" (
    "ID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY,
    "SYMBOL" VARCHAR(50) NULL,
    "DATE" DATE NULL,
    "TIME" TIME NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "CLOSE" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
  CONSTRAINT "PK_QUOTE_TICK_HISTORY_VFX"
    PRIMARY KEY ("ID")
);


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'SELECT CODE FROM RTD.QUOTE_LIST_VFX', 1, 1, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'SYMBOL', '=VFX|Name![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'TIME', '=VFX|Time![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'CHANGE', '=VFX|NetChange![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'PERCENT_CHANGE', '=VFX|PercentChange![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'BID', '=VFX|Bid![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'ASK', '=VFX|Ask![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'OPEN', '=VFX|OpenPrice![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'HIGH', '=VFX|High![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'LOW', '=VFX|Low![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TICK_HISTORY_VFX', 'CLOSE', '=VFX|ClosePrice![CODE]', NULL);

--#SET TERMINATOR ;

CREATE TABLE "RTD"."QUOTE_TIME_HISTORY_VFX" (
    "SYMBOL" VARCHAR(50) NOT NULL,
    "DATE" DATE NOT NULL,
    "TIME" TIME NOT NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "CLOSE" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
  CONSTRAINT "PK_QUOTE_TIME_HISTORY_VFX"
    PRIMARY KEY ("SYMBOL", "DATE", "TIME")
);


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'QUOTE_TIME_HISTORY_VFX', 'SELECT CODE FROM RTD.QUOTE_LIST_VFX', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_VFX', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_VFX', 'SYMBOL', '=VFX|Name![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_VFX', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_VFX', 'TIME', '=VFX|Time![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_VFX', 'CHANGE', '=VFX|NetChange![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_VFX', 'PERCENT_CHANGE', '=VFX|PercentChange![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_VFX', 'BID', '=VFX|Bid![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_VFX', 'ASK', '=VFX|Ask![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_VFX', 'OPEN', '=VFX|OpenPrice![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_VFX', 'HIGH', '=VFX|High![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_VFX', 'LOW', '=VFX|Low![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_VFX', 'CLOSE', '=VFX|ClosePrice![CODE]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'QUOTE_TIME_HISTORY_VFX', 'LAST_UPDATE_TIMESTAMP', '=TimeStamp()', NULL);

