CREATE TABLE [real_time_formulas](
    [id] [int] IDENTITY(1,1) NOT NULL,
    [table_schema] [nvarchar](128) NULL,
    [table_name] [nvarchar](128) NOT NULL,
    [column_name] [nvarchar](128) NOT NULL,
    [rtd_formula] [nvarchar](255) NULL,
    [is_disabled] [tinyint] NULL,
  CONSTRAINT [pk_real_time_formulas] PRIMARY KEY ([id]),
  CONSTRAINT [ix_real_time_formulas_name_column_name] UNIQUE ([table_name], [column_name])
);

CREATE TABLE [real_time_tables](
    [id] [int] IDENTITY(1,1) NOT NULL,
    [table_schema] [nvarchar](128) NULL,
    [table_name] [nvarchar](128) NOT NULL,
    [load_code] [nvarchar](2000) NULL,
    [is_history] [tinyint] NULL,
    [is_disabled] [tinyint] NULL,
    [time_zone] [nvarchar](50) NULL,
    [rtd_instance_name] [nvarchar](50) NULL,
  CONSTRAINT [pk_real_time_tables] PRIMARY KEY ([id]),
  CONSTRAINT [ix_real_time_tables_schema_name] UNIQUE ([table_name])
);

CREATE TABLE [es_stock_list] (
    [code] [nvarchar](50) NOT NULL,
  CONSTRAINT [pk_es_stock_list] PRIMARY KEY ([code])
);

CREATE TABLE [es_historical_prices] (
    [symbol] [nvarchar](50) NOT NULL,
    [date] [datetime] NOT NULL,
    [time] [datetime] NULL,
    [last] [money] NULL,
    [change] [money] NULL,
    [percent_change] [float] NULL,
    [bid] [money] NULL,
    [ask] [money] NULL,
    [bid_size] [int] NULL,
    [ask_size] [int] NULL,
    [open] [money] NULL,
    [high] [money] NULL,
    [low] [money] NULL,
    [volume] [bigint] NULL,
    [open_int] [int] NULL,
    [trade_price] [money] NULL,
    [last_update_timestamp] [timestamp] NOT NULL,
  CONSTRAINT [pk_es_historical_prices] PRIMARY KEY ([symbol], [date])
);

INSERT INTO [real_time_tables] ([TABLE_NAME], [LOAD_CODE], [IS_HISTORY], [IS_DISABLED], [TIME_ZONE], [RTD_INSTANCE_NAME]) VALUES ('es_historical_prices', 'SELECT code FROM es_stock_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_historical_prices', 'code', NULL, NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_historical_prices', 'symbol', '=RTD("esrtd",,[code],"Symbol")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_historical_prices', 'date', '=Date()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_historical_prices', 'time', '=RTD("esrtd",,[code],"Time")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_historical_prices', 'last', '=RTD("esrtd",,[code],"Last")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_historical_prices', 'trade_price', '=RTD("esrtd",,[code],"TradePrice")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_historical_prices', 'change', '=RTD("esrtd",,[code],"Change")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_historical_prices', 'percent_change', '=RTD("esrtd",,[code],"% Change")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_historical_prices', 'bid', '=RTD("esrtd",,[code],"Bid")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_historical_prices', 'ask', '=RTD("esrtd",,[code],"Ask")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_historical_prices', 'bid_size', '=RTD("esrtd",,[code],"Bid Size")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_historical_prices', 'ask_size', '=RTD("esrtd",,[code],"Ask Size")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_historical_prices', 'open', '=RTD("esrtd",,[code],"Open")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_historical_prices', 'high', '=RTD("esrtd",,[code],"High")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_historical_prices', 'low', '=RTD("esrtd",,[code],"Low")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_historical_prices', 'volume', '=RTD("esrtd",,[code],"Volume")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_historical_prices', 'open_int', '=RTD("esrtd",,[code],"OpenInt")', NULL);

CREATE TABLE [es_last_stock_quotes] (
    [symbol] [nvarchar](50) NOT NULL,
    [date] [datetime] NULL,
    [time] [datetime] NULL,
    [last] [money] NULL,
    [change] [money] NULL,
    [percent_change] [float] NULL,
    [bid] [money] NULL,
    [ask] [money] NULL,
    [bid_size] [int] NULL,
    [ask_size] [int] NULL,
    [open] [money] NULL,
    [high] [money] NULL,
    [low] [money] NULL,
    [volume] [bigint] NULL,
    [open_int] [int] NULL,
    [trade_price] [money] NULL,
    [last_update_timestamp] [timestamp] NULL,
  CONSTRAINT [pk_es_last_stock_quotes] PRIMARY KEY ([symbol])
);

INSERT INTO [real_time_tables] ([TABLE_NAME], [LOAD_CODE], [IS_HISTORY], [IS_DISABLED], [TIME_ZONE], [RTD_INSTANCE_NAME]) VALUES ('es_last_stock_quotes', 'SELECT code FROM es_stock_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_last_stock_quotes', 'code', NULL, NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_last_stock_quotes', 'symbol', '=RTD("esrtd",,[code],"Symbol")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_last_stock_quotes', 'date', '=Date()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_last_stock_quotes', 'time', '=RTD("esrtd",,[code],"Time")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_last_stock_quotes', 'last', '=RTD("esrtd",,[code],"Last")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_last_stock_quotes', 'trade_price', '=RTD("esrtd",,[code],"TradePrice")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_last_stock_quotes', 'change', '=RTD("esrtd",,[code],"Change")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_last_stock_quotes', 'percent_change', '=RTD("esrtd",,[code],"% Change")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_last_stock_quotes', 'bid', '=RTD("esrtd",,[code],"Bid")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_last_stock_quotes', 'ask', '=RTD("esrtd",,[code],"Ask")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_last_stock_quotes', 'bid_size', '=RTD("esrtd",,[code],"Bid Size")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_last_stock_quotes', 'ask_size', '=RTD("esrtd",,[code],"Ask Size")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_last_stock_quotes', 'open', '=RTD("esrtd",,[code],"Open")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_last_stock_quotes', 'high', '=RTD("esrtd",,[code],"High")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_last_stock_quotes', 'low', '=RTD("esrtd",,[code],"Low")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_last_stock_quotes', 'volume', '=RTD("esrtd",,[code],"Volume")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_last_stock_quotes', 'open_int', '=RTD("esrtd",,[code],"OpenInt")', NULL);

CREATE TABLE [es_stock_quotes_ticks] (
    [id] [int] IDENTITY(1,1) NOT NULL,
    [symbol] [nvarchar](50) NOT NULL,
    [date] [datetime] NULL,
    [time] [datetime] NULL,
    [last] [money] NULL,
    [change] [money] NULL,
    [percent_change] [float] NULL,
    [bid] [money] NULL,
    [ask] [money] NULL,
    [bid_size] [int] NULL,
    [ask_size] [int] NULL,
    [open] [money] NULL,
    [high] [money] NULL,
    [low] [money] NULL,
    [volume] [bigint] NULL,
    [open_int] [int] NULL,
    [trade_price] [money] NULL,
  CONSTRAINT [pk_es_stock_quotes_ticks] PRIMARY KEY ([id])
);

INSERT INTO [real_time_tables] ([TABLE_NAME], [LOAD_CODE], [IS_HISTORY], [IS_DISABLED], [TIME_ZONE], [RTD_INSTANCE_NAME]) VALUES ('es_stock_quotes_ticks', 'SELECT code FROM es_stock_list', 1, 1, 'Eastern Standard Time', NULL);

INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_ticks', 'id', NULL, NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_ticks', 'code', NULL, NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_ticks', 'symbol', '=RTD("esrtd",,[code],"Symbol")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_ticks', 'date', '=Date()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_ticks', 'time', '=RTD("esrtd",,[code],"Time")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_ticks', 'last', '=RTD("esrtd",,[code],"Last")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_ticks', 'trade_price', '=RTD("esrtd",,[code],"TradePrice")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_ticks', 'change', '=RTD("esrtd",,[code],"Change")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_ticks', 'percent_change', '=RTD("esrtd",,[code],"% Change")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_ticks', 'bid', '=RTD("esrtd",,[code],"Bid")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_ticks', 'ask', '=RTD("esrtd",,[code],"Ask")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_ticks', 'bid_size', '=RTD("esrtd",,[code],"Bid Size")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_ticks', 'ask_size', '=RTD("esrtd",,[code],"Ask Size")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_ticks', 'open', '=RTD("esrtd",,[code],"Open")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_ticks', 'high', '=RTD("esrtd",,[code],"High")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_ticks', 'low', '=RTD("esrtd",,[code],"Low")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_ticks', 'volume', '=RTD("esrtd",,[code],"Volume")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_ticks', 'open_int', '=RTD("esrtd",,[code],"OpenInt")', NULL);

CREATE TABLE [es_stock_quotes_time] (
    [symbol] [nvarchar](50) NOT NULL,
    [date] [datetime] NOT NULL,
    [time] [datetime] NOT NULL,
    [last] [money] NULL,
    [change] [money] NULL,
    [percent_change] [float] NULL,
    [bid] [money] NULL,
    [ask] [money] NULL,
    [bid_size] [int] NULL,
    [ask_size] [int] NULL,
    [open] [money] NULL,
    [high] [money] NULL,
    [low] [money] NULL,
    [volume] [bigint] NULL,
    [open_int] [int] NULL,
    [trade_price] [money] NULL,
    [last_update_timestamp] [timestamp] NULL,
  CONSTRAINT [pk_es_stock_quotes_time] PRIMARY KEY ([symbol], [date], [time])
);

INSERT INTO [real_time_tables] ([TABLE_NAME], [LOAD_CODE], [IS_HISTORY], [IS_DISABLED], [TIME_ZONE], [RTD_INSTANCE_NAME]) VALUES ('es_stock_quotes_time', 'SELECT code FROM es_stock_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_time', 'code', NULL, NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_time', 'symbol', '=RTD("esrtd",,[code],"Symbol")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_time', 'date', '=Date()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_time', 'time', '=RTD("esrtd",,[code],"Time")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_time', 'last', '=RTD("esrtd",,[code],"Last")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_time', 'trade_price', '=RTD("esrtd",,[code],"TradePrice")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_time', 'change', '=RTD("esrtd",,[code],"Change")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_time', 'percent_change', '=RTD("esrtd",,[code],"% Change")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_time', 'bid', '=RTD("esrtd",,[code],"Bid")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_time', 'ask', '=RTD("esrtd",,[code],"Ask")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_time', 'bid_size', '=RTD("esrtd",,[code],"Bid Size")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_time', 'ask_size', '=RTD("esrtd",,[code],"Ask Size")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_time', 'open', '=RTD("esrtd",,[code],"Open")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_time', 'high', '=RTD("esrtd",,[code],"High")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_time', 'low', '=RTD("esrtd",,[code],"Low")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_time', 'volume', '=RTD("esrtd",,[code],"Volume")', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('es_stock_quotes_time', 'open_int', '=RTD("esrtd",,[code],"OpenInt")', NULL);

