CREATE TABLE [real_time_formulas](
    [id] [int] IDENTITY(1,1) NOT NULL,
    [table_schema] [nvarchar](128) NULL,
    [table_name] [nvarchar](128) NOT NULL,
    [column_name] [nvarchar](128) NOT NULL,
    [rtd_formula] [nvarchar](255) NULL,
    [is_disabled] [tinyint] NULL,
  CONSTRAINT [pk_real_time_formulas] PRIMARY KEY ([id]),
  CONSTRAINT [ix_real_time_formulas_name_column_name] UNIQUE ([table_name], [column_name])
);

CREATE TABLE [real_time_tables](
    [id] [int] IDENTITY(1,1) NOT NULL,
    [table_schema] [nvarchar](128) NULL,
    [table_name] [nvarchar](128) NOT NULL,
    [load_code] [nvarchar](2000) NULL,
    [is_history] [tinyint] NULL,
    [is_disabled] [tinyint] NULL,
    [time_zone] [nvarchar](50) NULL,
    [rtd_instance_name] [nvarchar](50) NULL,
  CONSTRAINT [pk_real_time_tables] PRIMARY KEY ([id]),
  CONSTRAINT [ix_real_time_tables_schema_name] UNIQUE ([table_name])
);

CREATE TABLE [tos_stock_list] (
    [symbol] [nvarchar](50) NOT NULL,
  CONSTRAINT [pk_tos_stock_list] PRIMARY KEY ([symbol])
);

INSERT INTO [tos_stock_list] ([symbol]) VALUES ('SPY');

CREATE TABLE [tos_option_list] (
    [code] [nvarchar](50) NOT NULL,
  CONSTRAINT [pk_tos_option_list] PRIMARY KEY ([code])
);

CREATE TABLE [tos_historical_option_data] (
    [code] [nvarchar](50) NOT NULL,
    [date] [datetime] NOT NULL,
    [time] [datetime] NULL,
    [description] [nvarchar](255) NULL,
    [last] [money] NULL,
    [change] [money] NULL,
    [percent_change] [float] NULL,
    [last_size] [smallint] NULL,
    [last_x] [nchar](1) NULL,
    [mark] [money] NULL,
    [mark_change] [money] NULL,
    [mark_percent_change] [float] NULL,
    [bid] [money] NULL,
    [ask] [money] NULL,
    [bid_size] [smallint] NULL,
    [ask_size] [smallint] NULL,
    [bid_ask_size] [nvarchar](50) NULL,
    [bid_x] [nchar](1) NULL,
    [ask_x] [nchar](1) NULL,
    [open] [money] NULL,
    [high] [money] NULL,
    [low] [money] NULL,
    [close] [money] NULL,
    [volume] [int] NULL,
    [open_int] [int] NULL,
    [implied_vol] [float] NULL,
    [delta] [float] NULL,
    [gamma] [float] NULL,
    [theta] [float] NULL,
    [vega] [float] NULL,
    [rho] [float] NULL,
    [extrinsic] [money] NULL,
    [intrinsic] [money] NULL,
    [probability_itm] [float] NULL,
    [probability_otm] [float] NULL,
    [probability_touch] [float] NULL,
    [covered_return] [float] NULL,
    [max_covered_return] [float] NULL,
    [last_update_timestamp] [timestamp] NULL,
  CONSTRAINT [pk_tos_historical_option_data] PRIMARY KEY ([code], [date])
);

INSERT INTO [real_time_tables] ([TABLE_NAME], [LOAD_CODE], [IS_HISTORY], [IS_DISABLED], [TIME_ZONE], [RTD_INSTANCE_NAME]) VALUES ('tos_historical_option_data', 'SELECT code FROM tos_option_list', NULL, NULL, 'Eastern Standard Time', NULL);

INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME]) VALUES ('tos_historical_option_data', 'code');
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'date', '=Date()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'time', '=Time()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'description', '=TOS|DESCRIPTION!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'last', '=TOS|LAST!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'change', '=TOS|NET_CHANGE!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'percent_change', '=TOS|PERCENT_CHANGE!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'last_size', '=TOS|LAST_SIZE!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'last_x', '=TOS|LX!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'mark', '=TOS|MARK!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'mark_change', '=TOS|MARK_CHANGE!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'mark_percent_change', '=TOS|MARK_PERCENT_CHANGE!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'bid', '=TOS|BID!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'ask', '=TOS|ASK!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'bid_size', '=TOS|BID_SIZE!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'ask_size', '=TOS|ASK_SIZE!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'bid_ask_size', '=TOS|BA_SIZE!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'bid_x', '=TOS|BX!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'ask_x', '=TOS|AX!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'open', '=TOS|OPEN!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'high', '=TOS|HIGH!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'low', '=TOS|LOW!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'close', '=TOS|Close!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'volume', '=TOS|VOLUME!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'open_int', '=TOS|OPEN_INT!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'implied_vol', '=TOS|IMPL_VOL!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'delta', '=TOS|DELTA!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'gamma', '=TOS|GAMMA!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'theta', '=TOS|THETA!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'vega', '=TOS|VEGA!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'rho', '=TOS|RHO!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'extrinsic', '=TOS|EXTRINSIC!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'intrinsic', '=TOS|INTRINSIC!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'probability_itm', '=TOS|PROB_OF_EXPIRING!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'probability_otm', '=TOS|PROB_OTM!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'probability_touch', '=TOS|PROB_OF_TOUCHING!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'covered_return', '=TOS|COVERED_RETURN!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_option_data', 'max_covered_return', '=TOS|MAX_COVERED_RETURN!''[code]''', 1);

CREATE TABLE [tos_historical_prices] (
    [symbol] [nvarchar](50) NOT NULL,
    [date] [datetime] NOT NULL,
    [time] [datetime] NULL,
    [description] [nvarchar](255) NULL,
    [last] [money] NULL,
    [change] [money] NULL,
    [percent_change] [float] NULL,
    [last_size] [int] NULL,
    [last_x] [nchar](1) NULL,
    [mark] [money] NULL,
    [mark_change] [money] NULL,
    [mark_percent_change] [float] NULL,
    [bid] [money] NULL,
    [ask] [money] NULL,
    [bid_size] [int] NULL,
    [ask_size] [int] NULL,
    [bid_ask_size] [nvarchar](255) NULL,
    [bid_x] [nchar](1) NULL,
    [ask_x] [nchar](1) NULL,
    [strength_meter] [nvarchar](255) NULL,
    [open] [money] NULL,
    [high] [money] NULL,
    [low] [money] NULL,
    [close] [money] NULL,
    [volume] [bigint] NULL,
    [open_int] [int] NULL,
    [implied_vol] [float] NULL,
    [vol_index] [float] NULL,
    [front_vol] [float] NULL,
    [back_vol] [float] NULL,
    [weighted_back_vol] [float] NULL,
    [vol_diff] [float] NULL,
    [put_call_ratio] [float] NULL,
    [call_volume_index] [float] NULL,
    [put_volume_index] [float] NULL,
    [option_volume_index] [float] NULL,
    [front_expected_move] [float] NULL,
    [back_expected_move] [float] NULL,
    [expected_move_diff] [float] NULL,
    [beta] [float] NULL,
    [high52] [money] NULL,
    [low52] [money] NULL,
    [pe] [float] NULL,
    [eps] [float] NULL,
    [market_cap] [nvarchar](255) NULL,
    [shares] [bigint] NULL,
    [dividend_yield] [float] NULL,
    [dividend_share] [float] NULL,
    [last_update_timestamp] [timestamp] NOT NULL,
  CONSTRAINT [pk_tos_historical_prices] PRIMARY KEY ([symbol], [date])
);

INSERT INTO [real_time_tables] ([TABLE_NAME], [LOAD_CODE], [IS_HISTORY], [IS_DISABLED], [TIME_ZONE], [RTD_INSTANCE_NAME]) VALUES ('tos_historical_prices', 'SELECT symbol FROM tos_stock_list', NULL, NULL, 'Eastern Standard Time', NULL);

INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME]) VALUES ('tos_historical_prices', 'symbol');
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'date', '=Date()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'time', '=Time()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'description', '=TOS|DESCRIPTION![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'last', '=TOS|LAST![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'change', '=TOS|NET_CHANGE![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'percent_change', '=TOS|PERCENT_CHANGE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'last_size', '=TOS|LAST_SIZE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'last_x', '=TOS|LX![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'mark', '=TOS|MARK![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'mark_change', '=TOS|MARK_CHANGE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'mark_percent_change', '=TOS|MARK_PERCENT_CHANGE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'bid', '=TOS|BID![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'ask', '=TOS|ASK![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'bid_size', '=TOS|BID_SIZE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'ask_size', '=TOS|ASK_SIZE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'bid_ask_size', '=TOS|BA_SIZE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'bid_x', '=TOS|BX![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'ask_x', '=TOS|AX![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'strength_meter', '=TOS|STRENGTH_METER![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'open', '=TOS|OPEN![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'high', '=TOS|HIGH![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'low', '=TOS|LOW![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'close', '=TOS|CLOSE![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'volume', '=TOS|VOLUME![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'open_int', '=TOS|OPEN_INT![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'implied_vol', '=TOS|IMPL_VOL![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'vol_index', '=TOS|VOL_INDEX![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'front_vol', '=TOS|FRONT_VOL![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'back_vol', '=TOS|BACK_VOL![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'weighted_back_vol', '=TOS|WEIGHTED_BACK_VOL![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'vol_diff', '=TOS|VOL_DIFF![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'put_call_ratio', '=TOS|PUT_CALL_RATIO![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'call_volume_index', '=TOS|CALL_VOLUME_INDEX![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'put_volume_index', '=TOS|PUT_VOLUME_INDEX![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'option_volume_index', '=TOS|OPTION_VOLUME_INDEX![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'front_expected_move', '=TOS|FRONT_EX_MOVE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'back_expected_move', '=TOS|BACK_EX_MOVE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'expected_move_diff', '=TOS|EX_MOVE_DIFF![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'beta', '=TOS|BETA![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'high52', '=TOS|''52HIGH''![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'low52', '=TOS|''52LOW''![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'pe', '=TOS|PE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'eps', '=TOS|EPS![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'market_cap', '=TOS|MARKET_CAP![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'shares', '=TOS|SHARES![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'dividend_yield', '=TOS|YIELD![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_historical_prices', 'dividend_share', '=TOS|DIV![symbol]', NULL);

CREATE TABLE [tos_last_option_data] (
    [code] [nvarchar](50) NOT NULL,
    [datetime] [datetime] NULL,
    [date] [datetime] NULL,
    [time] [datetime] NULL,
    [description] [nvarchar](255) NULL,
    [last] [money] NULL,
    [change] [money] NULL,
    [percent_change] [float] NULL,
    [last_size] [smallint] NULL,
    [last_x] [nchar](1) NULL,
    [mark] [money] NULL,
    [mark_change] [money] NULL,
    [mark_percent_change] [float] NULL,
    [bid] [money] NULL,
    [ask] [money] NULL,
    [bid_size] [smallint] NULL,
    [ask_size] [smallint] NULL,
    [bid_ask_size] [nvarchar](50) NULL,
    [bid_x] [nchar](1) NULL,
    [ask_x] [nchar](1) NULL,
    [open] [money] NULL,
    [high] [money] NULL,
    [low] [money] NULL,
    [close] [money] NULL,
    [volume] [int] NULL,
    [open_int] [int] NULL,
    [implied_vol] [float] NULL,
    [delta] [float] NULL,
    [gamma] [float] NULL,
    [theta] [float] NULL,
    [vega] [float] NULL,
    [rho] [float] NULL,
    [extrinsic] [money] NULL,
    [intrinsic] [money] NULL,
    [probability_itm] [float] NULL,
    [probability_otm] [float] NULL,
    [probability_touch] [float] NULL,
    [covered_return] [float] NULL,
    [max_covered_return] [float] NULL,
    [last_update_timestamp] [timestamp] NULL,
  CONSTRAINT [pk_tos_last_option_data] PRIMARY KEY ([code])
);

INSERT INTO [real_time_tables] ([TABLE_NAME], [LOAD_CODE], [IS_HISTORY], [IS_DISABLED], [TIME_ZONE], [RTD_INSTANCE_NAME]) VALUES ('tos_last_option_data', 'SELECT code FROM tos_option_list', NULL, NULL, 'Eastern Standard Time', NULL);

INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME]) VALUES ('tos_last_option_data', 'code');
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'datetime', '=DateTime()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'date', '=Date()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'time', '=Time()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'description', '=TOS|DESCRIPTION!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'last', '=TOS|LAST!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'change', '=TOS|NET_CHANGE!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'percent_change', '=TOS|PERCENT_CHANGE!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'last_size', '=TOS|LAST_SIZE!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'last_x', '=TOS|LX!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'mark', '=TOS|MARK!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'mark_change', '=TOS|MARK_CHANGE!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'mark_percent_change', '=TOS|MARK_PERCENT_CHANGE!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'bid', '=TOS|BID!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'ask', '=TOS|ASK!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'bid_size', '=TOS|BID_SIZE!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'ask_size', '=TOS|ASK_SIZE!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'bid_ask_size', '=TOS|BA_SIZE!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'bid_x', '=TOS|BX!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'ask_x', '=TOS|AX!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'open', '=TOS|OPEN!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'high', '=TOS|HIGH!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'low', '=TOS|LOW!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'close', '=TOS|Close!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'volume', '=TOS|VOLUME!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'open_int', '=TOS|OPEN_INT!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'implied_vol', '=TOS|IMPL_VOL!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'delta', '=TOS|DELTA!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'gamma', '=TOS|GAMMA!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'theta', '=TOS|THETA!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'vega', '=TOS|VEGA!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'rho', '=TOS|RHO!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'extrinsic', '=TOS|EXTRINSIC!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'intrinsic', '=TOS|INTRINSIC!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'probability_itm', '=TOS|PROB_OF_EXPIRING!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'probability_otm', '=TOS|PROB_OTM!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'probability_touch', '=TOS|PROB_OF_TOUCHING!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'covered_return', '=TOS|COVERED_RETURN!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_option_data', 'max_covered_return', '=TOS|MAX_COVERED_RETURN!''[code]''', 1);

CREATE TABLE [tos_last_stock_quotes] (
    [symbol] [nvarchar](50) NOT NULL,
    [datetime] [datetime] NULL,
    [date] [datetime] NULL,
    [time] [datetime] NULL,
    [description] [nvarchar](255) NULL,
    [last] [money] NULL,
    [change] [money] NULL,
    [percent_change] [float] NULL,
    [last_size] [int] NULL,
    [last_x] [nchar](1) NULL,
    [mark] [money] NULL,
    [mark_change] [money] NULL,
    [mark_percent_change] [float] NULL,
    [bid] [money] NULL,
    [ask] [money] NULL,
    [bid_size] [int] NULL,
    [ask_size] [int] NULL,
    [bid_ask_size] [nvarchar](255) NULL,
    [bid_x] [nchar](1) NULL,
    [ask_x] [nchar](1) NULL,
    [strength_meter] [nvarchar](255) NULL,
    [open] [money] NULL,
    [high] [money] NULL,
    [low] [money] NULL,
    [close] [money] NULL,
    [volume] [bigint] NULL,
    [open_int] [int] NULL,
    [implied_vol] [float] NULL,
    [vol_index] [float] NULL,
    [front_vol] [float] NULL,
    [back_vol] [float] NULL,
    [weighted_back_vol] [float] NULL,
    [vol_diff] [float] NULL,
    [put_call_ratio] [float] NULL,
    [call_volume_index] [float] NULL,
    [put_volume_index] [float] NULL,
    [option_volume_index] [float] NULL,
    [front_expected_move] [float] NULL,
    [back_expected_move] [float] NULL,
    [expected_move_diff] [float] NULL,
    [beta] [float] NULL,
    [high52] [money] NULL,
    [low52] [money] NULL,
    [pe] [float] NULL,
    [eps] [float] NULL,
    [market_cap] [nvarchar](255) NULL,
    [shares] [bigint] NULL,
    [dividend_yield] [float] NULL,
    [dividend_share] [float] NULL,
    [last_update_timestamp] [timestamp] NULL,
  CONSTRAINT [pk_tos_last_stock_quotes] PRIMARY KEY ([symbol])
);

INSERT INTO [real_time_tables] ([TABLE_NAME], [LOAD_CODE], [IS_HISTORY], [IS_DISABLED], [TIME_ZONE], [RTD_INSTANCE_NAME]) VALUES ('tos_last_stock_quotes', 'SELECT symbol FROM tos_stock_list', NULL, NULL, 'Eastern Standard Time', NULL);

INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME]) VALUES ('tos_last_stock_quotes', 'symbol');
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'datetime', '=DateTime()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'date', '=Date()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'time', '=Time()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'description', '=TOS|DESCRIPTION![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'last', '=TOS|LAST![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'change', '=TOS|NET_CHANGE![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'percent_change', '=TOS|PERCENT_CHANGE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'last_size', '=TOS|LAST_SIZE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'last_x', '=TOS|LX![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'mark', '=TOS|MARK![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'mark_change', '=TOS|MARK_CHANGE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'mark_percent_change', '=TOS|MARK_PERCENT_CHANGE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'bid', '=TOS|BID![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'ask', '=TOS|ASK![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'bid_size', '=TOS|BID_SIZE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'ask_size', '=TOS|ASK_SIZE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'bid_ask_size', '=TOS|BA_SIZE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'bid_x', '=TOS|BX![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'ask_x', '=TOS|AX![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'strength_meter', '=TOS|STRENGTH_METER![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'open', '=TOS|OPEN![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'high', '=TOS|HIGH![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'low', '=TOS|LOW![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'close', '=TOS|CLOSE![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'volume', '=TOS|VOLUME![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'open_int', '=TOS|OPEN_INT![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'implied_vol', '=TOS|IMPL_VOL![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'vol_index', '=TOS|VOL_INDEX![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'front_vol', '=TOS|FRONT_VOL![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'back_vol', '=TOS|BACK_VOL![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'weighted_back_vol', '=TOS|WEIGHTED_BACK_VOL![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'vol_diff', '=TOS|VOL_DIFF![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'put_call_ratio', '=TOS|PUT_CALL_RATIO![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'call_volume_index', '=TOS|CALL_VOLUME_INDEX![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'put_volume_index', '=TOS|PUT_VOLUME_INDEX![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'option_volume_index', '=TOS|OPTION_VOLUME_INDEX![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'front_expected_move', '=TOS|FRONT_EX_MOVE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'back_expected_move', '=TOS|BACK_EX_MOVE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'expected_move_diff', '=TOS|EX_MOVE_DIFF![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'beta', '=TOS|BETA![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'high52', '=TOS|''52HIGH''![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'low52', '=TOS|''52LOW''![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'pe', '=TOS|PE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'eps', '=TOS|EPS![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'market_cap', '=TOS|MARKET_CAP![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'shares', '=TOS|SHARES![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'dividend_yield', '=TOS|YIELD![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_last_stock_quotes', 'dividend_share', '=TOS|DIV![symbol]', NULL);

CREATE TABLE [tos_option_data_s] (
    [code] [nvarchar](50) NOT NULL,
    [datetime] [datetime] NULL,
    [date] [datetime] NOT NULL,
    [time] [datetime] NOT NULL,
    [description] [nvarchar](255) NULL,
    [last] [money] NULL,
    [change] [money] NULL,
    [percent_change] [float] NULL,
    [last_size] [smallint] NULL,
    [last_x] [nchar](1) NULL,
    [mark] [money] NULL,
    [mark_change] [money] NULL,
    [mark_percent_change] [float] NULL,
    [bid] [money] NULL,
    [ask] [money] NULL,
    [bid_size] [smallint] NULL,
    [ask_size] [smallint] NULL,
    [bid_ask_size] [nvarchar](50) NULL,
    [bid_x] [nchar](1) NULL,
    [ask_x] [nchar](1) NULL,
    [open] [money] NULL,
    [high] [money] NULL,
    [low] [money] NULL,
    [close] [money] NULL,
    [volume] [int] NULL,
    [open_int] [int] NULL,
    [implied_vol] [float] NULL,
    [delta] [float] NULL,
    [gamma] [float] NULL,
    [theta] [float] NULL,
    [vega] [float] NULL,
    [rho] [float] NULL,
    [extrinsic] [money] NULL,
    [intrinsic] [money] NULL,
    [probability_itm] [float] NULL,
    [probability_otm] [float] NULL,
    [probability_touch] [float] NULL,
    [covered_return] [float] NULL,
    [max_covered_return] [float] NULL,
    [last_update_timestamp] [timestamp] NULL,
  CONSTRAINT [pk_tos_option_data_s_rtd] PRIMARY KEY ([code], [date], [time])
);

INSERT INTO [real_time_tables] ([TABLE_NAME], [LOAD_CODE], [IS_HISTORY], [IS_DISABLED], [TIME_ZONE], [RTD_INSTANCE_NAME]) VALUES ('tos_option_data_s', 'SELECT code FROM tos_option_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME]) VALUES ('tos_option_data_s', 'code');
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'datetime', '=DateTime()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'date', '=Date()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'time', '=Time0()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'description', '=TOS|DESCRIPTION!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'last', '=TOS|LAST!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'change', '=TOS|NET_CHANGE!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'percent_change', '=TOS|PERCENT_CHANGE!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'last_size', '=TOS|LAST_SIZE!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'last_x', '=TOS|LX!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'mark', '=TOS|MARK!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'mark_change', '=TOS|MARK_CHANGE!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'mark_percent_change', '=TOS|MARK_PERCENT_CHANGE!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'bid', '=TOS|BID!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'ask', '=TOS|ASK!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'bid_size', '=TOS|BID_SIZE!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'ask_size', '=TOS|ASK_SIZE!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'bid_ask_size', '=TOS|BA_SIZE!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'bid_x', '=TOS|BX!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'ask_x', '=TOS|AX!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'open', '=TOS|OPEN!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'high', '=TOS|HIGH!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'low', '=TOS|LOW!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'close', '=TOS|Close!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'volume', '=TOS|VOLUME!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'open_int', '=TOS|OPEN_INT!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'implied_vol', '=TOS|IMPL_VOL!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'delta', '=TOS|DELTA!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'gamma', '=TOS|GAMMA!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'theta', '=TOS|THETA!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'vega', '=TOS|VEGA!''[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'rho', '=TOS|RHO!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'extrinsic', '=TOS|EXTRINSIC!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'intrinsic', '=TOS|INTRINSIC!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'probability_itm', '=TOS|PROB_OF_EXPIRING!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'probability_otm', '=TOS|PROB_OTM!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'probability_touch', '=TOS|PROB_OF_TOUCHING!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'covered_return', '=TOS|COVERED_RETURN!''[code]''', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_option_data_s', 'max_covered_return', '=TOS|MAX_COVERED_RETURN!''[code]''', 1);

CREATE TABLE [tos_stock_quotes_s] (
    [symbol] [nvarchar](50) NOT NULL,
    [datetime] [datetime] NULL,
    [date] [datetime] NOT NULL,
    [time] [datetime] NOT NULL,
    [description] [nvarchar](255) NULL,
    [last] [money] NULL,
    [change] [money] NULL,
    [percent_change] [float] NULL,
    [last_size] [int] NULL,
    [last_x] [nchar](1) NULL,
    [mark] [money] NULL,
    [mark_change] [money] NULL,
    [mark_percent_change] [float] NULL,
    [bid] [money] NULL,
    [ask] [money] NULL,
    [bid_size] [int] NULL,
    [ask_size] [int] NULL,
    [bid_ask_size] [nvarchar](255) NULL,
    [bid_x] [nchar](1) NULL,
    [ask_x] [nchar](1) NULL,
    [strength_meter] [nvarchar](255) NULL,
    [open] [money] NULL,
    [high] [money] NULL,
    [low] [money] NULL,
    [close] [money] NULL,
    [volume] [bigint] NULL,
    [open_int] [int] NULL,
    [implied_vol] [float] NULL,
    [vol_index] [float] NULL,
    [front_vol] [float] NULL,
    [back_vol] [float] NULL,
    [weighted_back_vol] [float] NULL,
    [vol_diff] [float] NULL,
    [put_call_ratio] [float] NULL,
    [call_volume_index] [float] NULL,
    [put_volume_index] [float] NULL,
    [option_volume_index] [float] NULL,
    [front_expected_move] [float] NULL,
    [back_expected_move] [float] NULL,
    [expected_move_diff] [float] NULL,
    [beta] [float] NULL,
    [high52] [money] NULL,
    [low52] [money] NULL,
    [pe] [float] NULL,
    [eps] [float] NULL,
    [market_cap] [nvarchar](255) NULL,
    [shares] [bigint] NULL,
    [dividend_yield] [float] NULL,
    [dividend_share] [float] NULL,
    [last_update_timestamp] [timestamp] NOT NULL,
  CONSTRAINT [pk_tos_stock_quotes_s_rtd] PRIMARY KEY ([symbol], [date], [time])
);

INSERT INTO [real_time_tables] ([TABLE_NAME], [LOAD_CODE], [IS_HISTORY], [IS_DISABLED], [TIME_ZONE], [RTD_INSTANCE_NAME]) VALUES ('tos_stock_quotes_s', 'SELECT symbol FROM tos_stock_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME]) VALUES ('tos_stock_quotes_s', 'symbol');
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'datetime', '=DateTime()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'date', '=Date()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'time', '=Time0()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'description', '=TOS|DESCRIPTION![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'last', '=TOS|LAST![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'change', '=TOS|NET_CHANGE![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'percent_change', '=TOS|PERCENT_CHANGE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'last_size', '=TOS|LAST_SIZE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'last_x', '=TOS|LX![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'mark', '=TOS|MARK![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'mark_change', '=TOS|MARK_CHANGE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'mark_percent_change', '=TOS|MARK_PERCENT_CHANGE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'bid', '=TOS|BID![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'ask', '=TOS|ASK![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'bid_size', '=TOS|BID_SIZE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'ask_size', '=TOS|ASK_SIZE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'bid_ask_size', '=TOS|BA_SIZE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'bid_x', '=TOS|BX![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'ask_x', '=TOS|AX![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'strength_meter', '=TOS|STRENGTH_METER![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'open', '=TOS|OPEN![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'high', '=TOS|HIGH![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'low', '=TOS|LOW![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'close', '=TOS|CLOSE![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'volume', '=TOS|VOLUME![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'open_int', '=TOS|OPEN_INT![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'implied_vol', '=TOS|IMPL_VOL![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'vol_index', '=TOS|VOL_INDEX![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'front_vol', '=TOS|FRONT_VOL![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'back_vol', '=TOS|BACK_VOL![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'weighted_back_vol', '=TOS|WEIGHTED_BACK_VOL![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'vol_diff', '=TOS|VOL_DIFF![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'put_call_ratio', '=TOS|PUT_CALL_RATIO![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'call_volume_index', '=TOS|CALL_VOLUME_INDEX![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'put_volume_index', '=TOS|PUT_VOLUME_INDEX![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'option_volume_index', '=TOS|OPTION_VOLUME_INDEX![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'front_expected_move', '=TOS|FRONT_EX_MOVE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'back_expected_move', '=TOS|BACK_EX_MOVE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'expected_move_diff', '=TOS|EX_MOVE_DIFF![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'beta', '=TOS|BETA![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'high52', '=TOS|''52HIGH''![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'low52', '=TOS|''52LOW''![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'pe', '=TOS|PE![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'eps', '=TOS|EPS![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'market_cap', '=TOS|MARKET_CAP![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'shares', '=TOS|SHARES![symbol]', 1);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'dividend_yield', '=TOS|YIELD![symbol]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tos_stock_quotes_s', 'dividend_share', '=TOS|DIV![symbol]', NULL);

