CREATE TABLE [real_time_formulas](
    [id] [int] IDENTITY(1,1) NOT NULL,
    [table_schema] [nvarchar](128) NULL,
    [table_name] [nvarchar](128) NOT NULL,
    [column_name] [nvarchar](128) NOT NULL,
    [rtd_formula] [nvarchar](255) NULL,
    [is_disabled] [tinyint] NULL,
  CONSTRAINT [pk_real_time_formulas] PRIMARY KEY ([id]),
  CONSTRAINT [ix_real_time_formulas_name_column_name] UNIQUE ([table_name], [column_name])
);

CREATE TABLE [real_time_tables](
    [id] [int] IDENTITY(1,1) NOT NULL,
    [table_schema] [nvarchar](128) NULL,
    [table_name] [nvarchar](128) NOT NULL,
    [load_code] [nvarchar](2000) NULL,
    [is_history] [tinyint] NULL,
    [is_disabled] [tinyint] NULL,
    [time_zone] [nvarchar](50) NULL,
    [rtd_instance_name] [nvarchar](50) NULL,
  CONSTRAINT [pk_real_time_tables] PRIMARY KEY ([id]),
  CONSTRAINT [ix_real_time_tables_schema_name] UNIQUE ([table_name])
);

CREATE TABLE [tws_stock_list] (
    [tick_id] [int] IDENTITY(1,1) NOT NULL,
    [code] [nvarchar](50) NOT NULL,
  CONSTRAINT [pk_tws_stock_list] PRIMARY KEY ([tick_id]),
  CONSTRAINT [ix_tws_stock_list_code] UNIQUE ([code])
);

CREATE TABLE [tws_historical_option_data] (
    [code] [nvarchar](255) NOT NULL,
    [date] [datetime] NOT NULL,
    [time] [datetime] NULL,
    [last] [money] NULL,
    [last_size] [int] NULL,
    [bid] [money] NULL,
    [ask] [money] NULL,
    [bid_size] [int] NULL,
    [ask_size] [int] NULL,
    [high] [money] NULL,
    [low] [money] NULL,
    [close] [money] NULL,
    [volume] [bigint] NULL,
    [underlying_price] [money] NULL,
    [model_price] [money] NULL,
    [implied_vol] [float] NULL,
    [bid_implied_vol] [float] NULL,
    [ask_implied_vol] [float] NULL,
    [last_implied_vol] [float] NULL,
    [bid_delta] [float] NULL,
    [ask_delta] [float] NULL,
    [last_delta] [float] NULL,
    [delta] [float] NULL,
    [gamma] [float] NULL,
    [theta] [float] NULL,
    [vega] [float] NULL,
    [pv_dividend] [float] NULL,
    [last_update_timestamp] [timestamp] NULL,
  CONSTRAINT [pk_tws_historical_option_data] PRIMARY KEY ([code], [date])
);

INSERT INTO [real_time_tables] ([TABLE_NAME], [LOAD_CODE], [IS_HISTORY], [IS_DISABLED], [TIME_ZONE], [RTD_INSTANCE_NAME]) VALUES ('tws_historical_option_data', 'SELECT tick_id, code FROM tws_stock_list WHERE code LIKE ''%_OPT_20%''', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'tick_id', NULL, NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'code', NULL, NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'req', '=S|tik!''id[tick_id]?req?[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'date', '=Date()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'time', '=Time()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'last', '=S|tik!id[tick_id]?last', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'last_size', '=S|tik!id[tick_id]?lastSize', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'bid', '=S|tik!id[tick_id]?bid', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'ask', '=S|tik!id[tick_id]?ask', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'bid_size', '=S|tik!id[tick_id]?bidSize', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'ask_size', '=S|tik!id[tick_id]?askSize', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'high', '=S|tik!id[tick_id]?high', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'low', '=S|tik!id[tick_id]?low', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'close', '=S|tik!id[tick_id]?close', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'volume', '=S|tik!id[tick_id]?volume', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'underlying_price', '=S|tik!id[tick_id]?modelUndPrice', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'model_price', '=S|tik!id[tick_id]?modelPrice', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'implied_vol', '=S|tik!id[tick_id]?modelVolatility', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'bid_implied_vol', '=S|tik!id[tick_id]?bidImpliedVol', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'ask_implied_vol', '=S|tik!id[tick_id]?askImpliedVol', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'last_implied_vol', '=S|tik!id[tick_id]?lastImpliedVol', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'bid_delta', '=S|tik!id[tick_id]?bidDelta', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'ask_delta', '=S|tik!id[tick_id]?askDelta', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'last_delta', '=S|tik!id[tick_id]?lastDelta', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'delta', '=S|tik!id[tick_id]?modelDelta', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'gamma', '=S|tik!id[tick_id]?modelGamma', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'theta', '=S|tik!id[tick_id]?modelTheta', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'vega', '=S|tik!id[tick_id]?modelVega', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'pv_dividend', '=S|tik!id[tick_id]?pvDividend', NULL);

CREATE TABLE [tws_historical_prices] (
    [symbol] [nvarchar](50) NOT NULL,
    [date] [datetime] NOT NULL,
    [time] [datetime] NULL,
    [last] [money] NULL,
    [last_size] [int] NULL,
    [bid] [money] NULL,
    [ask] [money] NULL,
    [bid_size] [int] NULL,
    [ask_size] [int] NULL,
    [high] [money] NULL,
    [low] [money] NULL,
    [close] [money] NULL,
    [volume] [bigint] NULL,
    [last_update_timestamp] [timestamp] NULL,
  CONSTRAINT [pk_tws_historical_prices] PRIMARY KEY ([symbol], [date])
);

INSERT INTO [real_time_tables] ([TABLE_NAME], [LOAD_CODE], [IS_HISTORY], [IS_DISABLED], [TIME_ZONE], [RTD_INSTANCE_NAME]) VALUES ('tws_historical_prices', 'SELECT tick_id, code AS symbol FROM tws_stock_list WHERE code NOT LIKE ''%_OPT_20%''', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_prices', 'id', NULL, NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_prices', 'tick_id', NULL, NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_prices', 'symbol', NULL, NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_prices', 'req', '=S|tik!''id[tick_id]?req?[symbol]_STK_SMART_USD_~''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_prices', 'date', '=Date()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_prices', 'time', '=Time()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_prices', 'last', '=S|tik!id[tick_id]?last', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_prices', 'last_size', '=S|tik!id[tick_id]?lastSize', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_prices', 'bid', '=S|tik!id[tick_id]?bid', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_prices', 'ask', '=S|tik!id[tick_id]?ask', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_prices', 'bid_size', '=S|tik!id[tick_id]?bidSize', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_prices', 'ask_size', '=S|tik!id[tick_id]?askSize', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_prices', 'high', '=S|tik!id[tick_id]?high', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_prices', 'low', '=S|tik!id[tick_id]?low', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_prices', 'close', '=S|tik!id[tick_id]?close', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_prices', 'volume', '=S|tik!id[tick_id]?volume', NULL);

CREATE TABLE [tws_last_option_data] (
    [code] [nvarchar](255) NOT NULL,
    [datetime] [datetime] NULL,
    [date] [datetime] NULL,
    [time] [datetime] NULL,
    [last] [money] NULL,
    [last_size] [int] NULL,
    [bid] [money] NULL,
    [ask] [money] NULL,
    [bid_size] [int] NULL,
    [ask_size] [int] NULL,
    [high] [money] NULL,
    [low] [money] NULL,
    [close] [money] NULL,
    [volume] [bigint] NULL,
    [underlying_price] [money] NULL,
    [model_price] [money] NULL,
    [implied_vol] [float] NULL,
    [bid_implied_vol] [float] NULL,
    [ask_implied_vol] [float] NULL,
    [last_implied_vol] [float] NULL,
    [bid_delta] [float] NULL,
    [ask_delta] [float] NULL,
    [last_delta] [float] NULL,
    [delta] [float] NULL,
    [gamma] [float] NULL,
    [theta] [float] NULL,
    [vega] [float] NULL,
    [pv_dividend] [float] NULL,
    [last_update_timestamp] [timestamp] NULL,
  CONSTRAINT [pk_tws_last_option_data] PRIMARY KEY ([code])
);

INSERT INTO [real_time_tables] ([TABLE_NAME], [LOAD_CODE], [IS_HISTORY], [IS_DISABLED], [TIME_ZONE], [RTD_INSTANCE_NAME]) VALUES ('tws_last_option_data', 'SELECT tick_id, code FROM tws_stock_list WHERE code LIKE ''%_OPT_20%''', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'tick_id', NULL, NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'code', NULL, NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'req', '=S|tik!''id[tick_id]?req?[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'datetime', '=DateTime()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'date', '=Date()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'time', '=Time()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'last', '=S|tik!id[tick_id]?last', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'last_size', '=S|tik!id[tick_id]?lastSize', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'bid', '=S|tik!id[tick_id]?bid', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'ask', '=S|tik!id[tick_id]?ask', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'bid_size', '=S|tik!id[tick_id]?bidSize', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'ask_size', '=S|tik!id[tick_id]?askSize', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'high', '=S|tik!id[tick_id]?high', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'low', '=S|tik!id[tick_id]?low', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'close', '=S|tik!id[tick_id]?close', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'volume', '=S|tik!id[tick_id]?volume', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'underlying_price', '=S|tik!id[tick_id]?modelUndPrice', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'model_price', '=S|tik!id[tick_id]?modelPrice', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'implied_vol', '=S|tik!id[tick_id]?modelVolatility', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'bid_implied_vol', '=S|tik!id[tick_id]?bidImpliedVol', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'ask_implied_vol', '=S|tik!id[tick_id]?askImpliedVol', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'last_implied_vol', '=S|tik!id[tick_id]?lastImpliedVol', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'bid_delta', '=S|tik!id[tick_id]?bidDelta', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'ask_delta', '=S|tik!id[tick_id]?askDelta', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'last_delta', '=S|tik!id[tick_id]?lastDelta', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'delta', '=S|tik!id[tick_id]?modelDelta', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'gamma', '=S|tik!id[tick_id]?modelGamma', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'theta', '=S|tik!id[tick_id]?modelTheta', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'vega', '=S|tik!id[tick_id]?modelVega', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_option_data', 'pv_dividend', '=S|tik!id[tick_id]?pvDividend', NULL);

CREATE TABLE [tws_last_stock_quotes] (
    [symbol] [nvarchar](50) NOT NULL,
    [datetime] [datetime] NULL,
    [date] [datetime] NULL,
    [time] [datetime] NULL,
    [last] [money] NULL,
    [last_size] [int] NULL,
    [bid] [money] NULL,
    [ask] [money] NULL,
    [bid_size] [int] NULL,
    [ask_size] [int] NULL,
    [high] [money] NULL,
    [low] [money] NULL,
    [close] [money] NULL,
    [volume] [bigint] NULL,
    [last_update_timestamp] [timestamp] NULL,
  CONSTRAINT [pk_tws_last_stock_quotes] PRIMARY KEY ([symbol])
);

INSERT INTO [real_time_tables] ([TABLE_NAME], [LOAD_CODE], [IS_HISTORY], [IS_DISABLED], [TIME_ZONE], [RTD_INSTANCE_NAME]) VALUES ('tws_last_stock_quotes', 'SELECT tick_id, code AS symbol FROM tws_stock_list WHERE code NOT LIKE ''%_OPT_20%''', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_stock_quotes', 'tick_id', NULL, NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_stock_quotes', 'symbol', NULL, NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_stock_quotes', 'req', '=S|tik!''id[tick_id]?req?[symbol]_STK_SMART_USD_~''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_stock_quotes', 'datetime', '=DateTime()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_stock_quotes', 'date', '=Date()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_stock_quotes', 'time', '=Time()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_stock_quotes', 'last', '=S|tik!id[tick_id]?last', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_stock_quotes', 'last_size', '=S|tik!id[tick_id]?lastSize', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_stock_quotes', 'bid', '=S|tik!id[tick_id]?bid', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_stock_quotes', 'ask', '=S|tik!id[tick_id]?ask', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_stock_quotes', 'bid_size', '=S|tik!id[tick_id]?bidSize', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_stock_quotes', 'ask_size', '=S|tik!id[tick_id]?askSize', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_stock_quotes', 'high', '=S|tik!id[tick_id]?high', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_stock_quotes', 'low', '=S|tik!id[tick_id]?low', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_stock_quotes', 'close', '=S|tik!id[tick_id]?close', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_last_stock_quotes', 'volume', '=S|tik!id[tick_id]?volume', NULL);

CREATE TABLE [tws_option_data_ticks] (
    [id] [int] IDENTITY(1,1) NOT NULL,
    [code] [nvarchar](255) NULL,
    [datetime] [datetime] NULL,
    [date] [datetime] NULL,
    [time] [datetime] NULL,
    [last] [money] NULL,
    [last_size] [int] NULL,
    [bid] [money] NULL,
    [ask] [money] NULL,
    [bid_size] [int] NULL,
    [ask_size] [int] NULL,
    [high] [money] NULL,
    [low] [money] NULL,
    [close] [money] NULL,
    [volume] [bigint] NULL,
    [underlying_price] [money] NULL,
    [model_price] [money] NULL,
    [implied_vol] [float] NULL,
    [bid_implied_vol] [float] NULL,
    [ask_implied_vol] [float] NULL,
    [last_implied_vol] [float] NULL,
    [bid_delta] [float] NULL,
    [ask_delta] [float] NULL,
    [last_delta] [float] NULL,
    [delta] [float] NULL,
    [gamma] [float] NULL,
    [theta] [float] NULL,
    [vega] [float] NULL,
    [pv_dividend] [float] NULL,
  CONSTRAINT [pk_tws_option_data_ticks] PRIMARY KEY ([id])
);

INSERT INTO [real_time_tables] ([TABLE_NAME], [LOAD_CODE], [IS_HISTORY], [IS_DISABLED], [TIME_ZONE], [RTD_INSTANCE_NAME]) VALUES ('tws_option_data_ticks', 'SELECT tick_id, code FROM tws_stock_list WHERE code LIKE ''%_OPT_20%''', 1, 1, 'Eastern Standard Time', NULL);

INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'id', NULL, NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'tick_id', NULL, NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'code', NULL, NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'req', '=S|tik!''id[tick_id]?req?[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'datetime', '=DateTime()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'date', '=Date()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'time', '=Time()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'last', '=S|tik!id[tick_id]?last', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'last_size', '=S|tik!id[tick_id]?lastSize', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'bid', '=S|tik!id[tick_id]?bid', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'ask', '=S|tik!id[tick_id]?ask', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'bid_size', '=S|tik!id[tick_id]?bidSize', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'ask_size', '=S|tik!id[tick_id]?askSize', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'high', '=S|tik!id[tick_id]?high', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'low', '=S|tik!id[tick_id]?low', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'close', '=S|tik!id[tick_id]?close', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'volume', '=S|tik!id[tick_id]?volume', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'underlying_price', '=S|tik!id[tick_id]?modelUndPrice', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'model_price', '=S|tik!id[tick_id]?modelPrice', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'implied_vol', '=S|tik!id[tick_id]?modelVolatility', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'bid_implied_vol', '=S|tik!id[tick_id]?bidImpliedVol', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'ask_implied_vol', '=S|tik!id[tick_id]?askImpliedVol', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'last_implied_vol', '=S|tik!id[tick_id]?lastImpliedVol', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'bid_delta', '=S|tik!id[tick_id]?bidDelta', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'ask_delta', '=S|tik!id[tick_id]?askDelta', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'last_delta', '=S|tik!id[tick_id]?lastDelta', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'delta', '=S|tik!id[tick_id]?modelDelta', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'gamma', '=S|tik!id[tick_id]?modelGamma', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'theta', '=S|tik!id[tick_id]?modelTheta', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'vega', '=S|tik!id[tick_id]?modelVega', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_option_data_ticks', 'pv_dividend', '=S|tik!id[tick_id]?pvDividend', NULL);

CREATE TABLE [tws_stock_quotes_ticks] (
    [id] [int] IDENTITY(1,1) NOT NULL,
    [symbol] [nvarchar](50) NULL,
    [datetime] [datetime] NULL,
    [date] [datetime] NULL,
    [time] [datetime] NULL,
    [last] [money] NULL,
    [last_size] [int] NULL,
    [bid] [money] NULL,
    [ask] [money] NULL,
    [bid_size] [int] NULL,
    [ask_size] [int] NULL,
    [high] [money] NULL,
    [low] [money] NULL,
    [close] [money] NULL,
    [volume] [bigint] NULL,
  CONSTRAINT [pk_tws_stock_quotes_ticks] PRIMARY KEY ([id])
);

INSERT INTO [real_time_tables] ([TABLE_NAME], [LOAD_CODE], [IS_HISTORY], [IS_DISABLED], [TIME_ZONE], [RTD_INSTANCE_NAME]) VALUES ('tws_stock_quotes_ticks', 'SELECT tick_id, code AS symbol FROM tws_stock_list WHERE code NOT LIKE ''%_OPT_20%''', 1, 1, 'Eastern Standard Time', NULL);

INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_stock_quotes_ticks', 'id', NULL, NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_stock_quotes_ticks', 'tick_id', NULL, NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_stock_quotes_ticks', 'symbol', NULL, NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_stock_quotes_ticks', 'req', '=S|tik!''id[tick_id]?req?[symbol]_STK_SMART_USD_~''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_stock_quotes_ticks', 'datetime', '=DateTime()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_stock_quotes_ticks', 'date', '=Date()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_stock_quotes_ticks', 'time', '=Time()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_stock_quotes_ticks', 'last', '=S|tik!id[tick_id]?last', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_stock_quotes_ticks', 'last_size', '=S|tik!id[tick_id]?lastSize', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_stock_quotes_ticks', 'bid', '=S|tik!id[tick_id]?bid', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_stock_quotes_ticks', 'ask', '=S|tik!id[tick_id]?ask', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_stock_quotes_ticks', 'bid_size', '=S|tik!id[tick_id]?bidSize', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_stock_quotes_ticks', 'ask_size', '=S|tik!id[tick_id]?askSize', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_stock_quotes_ticks', 'high', '=S|tik!id[tick_id]?high', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_stock_quotes_ticks', 'low', '=S|tik!id[tick_id]?low', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_stock_quotes_ticks', 'close', '=S|tik!id[tick_id]?close', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_stock_quotes_ticks', 'volume', '=S|tik!id[tick_id]?volume', NULL);

