CREATE TABLE [tws_historical_option_data] (
    [code] [nvarchar](255) NOT NULL,
    [date] [datetime] NOT NULL,
    [time] [datetime] NULL,
    [last] [money] NULL,
    [last_size] [int] NULL,
    [bid] [money] NULL,
    [ask] [money] NULL,
    [bid_size] [int] NULL,
    [ask_size] [int] NULL,
    [high] [money] NULL,
    [low] [money] NULL,
    [close] [money] NULL,
    [volume] [bigint] NULL,
    [underlying_price] [money] NULL,
    [model_price] [money] NULL,
    [implied_vol] [float] NULL,
    [bid_implied_vol] [float] NULL,
    [ask_implied_vol] [float] NULL,
    [last_implied_vol] [float] NULL,
    [bid_delta] [float] NULL,
    [ask_delta] [float] NULL,
    [last_delta] [float] NULL,
    [delta] [float] NULL,
    [gamma] [float] NULL,
    [theta] [float] NULL,
    [vega] [float] NULL,
    [pv_dividend] [float] NULL,
    [last_update_timestamp] [timestamp] NULL,
  CONSTRAINT [pk_tws_historical_option_data] PRIMARY KEY ([code], [date])
);

INSERT INTO [real_time_tables] ([TABLE_NAME], [LOAD_CODE], [IS_HISTORY], [IS_DISABLED], [TIME_ZONE], [RTD_INSTANCE_NAME]) VALUES ('tws_historical_option_data', 'SELECT tick_id, code FROM tws_stock_list WHERE code LIKE ''%_OPT_20%''', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'tick_id', NULL, NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'code', NULL, NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'req', '=S|tik!''id[tick_id]?req?[code]''', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'date', '=Date()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'time', '=Time()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'last', '=S|tik!id[tick_id]?last', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'last_size', '=S|tik!id[tick_id]?lastSize', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'bid', '=S|tik!id[tick_id]?bid', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'ask', '=S|tik!id[tick_id]?ask', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'bid_size', '=S|tik!id[tick_id]?bidSize', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'ask_size', '=S|tik!id[tick_id]?askSize', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'high', '=S|tik!id[tick_id]?high', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'low', '=S|tik!id[tick_id]?low', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'close', '=S|tik!id[tick_id]?close', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'volume', '=S|tik!id[tick_id]?volume', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'underlying_price', '=S|tik!id[tick_id]?modelUndPrice', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'model_price', '=S|tik!id[tick_id]?modelPrice', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'implied_vol', '=S|tik!id[tick_id]?modelVolatility', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'bid_implied_vol', '=S|tik!id[tick_id]?bidImpliedVol', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'ask_implied_vol', '=S|tik!id[tick_id]?askImpliedVol', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'last_implied_vol', '=S|tik!id[tick_id]?lastImpliedVol', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'bid_delta', '=S|tik!id[tick_id]?bidDelta', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'ask_delta', '=S|tik!id[tick_id]?askDelta', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'last_delta', '=S|tik!id[tick_id]?lastDelta', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'delta', '=S|tik!id[tick_id]?modelDelta', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'gamma', '=S|tik!id[tick_id]?modelGamma', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'theta', '=S|tik!id[tick_id]?modelTheta', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'vega', '=S|tik!id[tick_id]?modelVega', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('tws_historical_option_data', 'pv_dividend', '=S|tik!id[tick_id]?pvDividend', NULL);

