CREATE TABLE [real_time_formulas](
    [id] [int] IDENTITY(1,1) NOT NULL,
    [table_schema] [nvarchar](128) NULL,
    [table_name] [nvarchar](128) NOT NULL,
    [column_name] [nvarchar](128) NOT NULL,
    [rtd_formula] [nvarchar](255) NULL,
    [is_disabled] [tinyint] NULL,
  CONSTRAINT [pk_real_time_formulas] PRIMARY KEY ([id]),
  CONSTRAINT [ix_real_time_formulas_name_column_name] UNIQUE ([table_name], [column_name])
);

CREATE TABLE [real_time_tables](
    [id] [int] IDENTITY(1,1) NOT NULL,
    [table_schema] [nvarchar](128) NULL,
    [table_name] [nvarchar](128) NOT NULL,
    [load_code] [nvarchar](2000) NULL,
    [is_history] [tinyint] NULL,
    [is_disabled] [tinyint] NULL,
    [time_zone] [nvarchar](50) NULL,
    [rtd_instance_name] [nvarchar](50) NULL,
  CONSTRAINT [pk_real_time_tables] PRIMARY KEY ([id]),
  CONSTRAINT [ix_real_time_tables_schema_name] UNIQUE ([table_name])
);

CREATE TABLE [vfx_stock_list] (
    [code] [nvarchar](50) NOT NULL,
  CONSTRAINT [pk_vfx_stock_list] PRIMARY KEY ([code])
);

CREATE TABLE [vfx_historical_prices] (
    [symbol] [nvarchar](50) NOT NULL,
    [date] [datetime] NOT NULL,
    [time] [datetime] NULL,
    [bid] [money] NULL,
    [ask] [money] NULL,
    [open] [money] NULL,
    [high] [money] NULL,
    [low] [money] NULL,
    [close] [money] NULL,
    [change] [money] NULL,
    [percent_change] [float] NULL,
    [last_update_timestamp] [timestamp] NULL,
  CONSTRAINT [pk_vfx_historical_prices] PRIMARY KEY ([symbol], [date])
);

INSERT INTO [real_time_tables] ([TABLE_NAME], [LOAD_CODE], [IS_HISTORY], [IS_DISABLED], [TIME_ZONE], [RTD_INSTANCE_NAME]) VALUES ('vfx_historical_prices', 'SELECT code FROM vfx_stock_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_historical_prices', 'code', NULL, NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_historical_prices', 'symbol', '=VFX|Name![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_historical_prices', 'date', '=Date()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_historical_prices', 'time', '=VFX|Time![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_historical_prices', 'change', '=VFX|NetChange![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_historical_prices', 'percent_change', '=VFX|PercentChange![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_historical_prices', 'bid', '=VFX|Bid![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_historical_prices', 'ask', '=VFX|Ask![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_historical_prices', 'open', '=VFX|OpenPrice![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_historical_prices', 'high', '=VFX|High![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_historical_prices', 'low', '=VFX|Low![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_historical_prices', 'close', '=VFX|ClosePrice![code]', NULL);

CREATE TABLE [vfx_last_stock_quotes] (
    [symbol] [nvarchar](50) NOT NULL,
    [date] [datetime] NULL,
    [time] [datetime] NULL,
    [bid] [money] NULL,
    [ask] [money] NULL,
    [open] [money] NULL,
    [high] [money] NULL,
    [low] [money] NULL,
    [close] [money] NULL,
    [change] [money] NULL,
    [percent_change] [float] NULL,
    [last_update_timestamp] [timestamp] NULL,
  CONSTRAINT [pk_vfx_last_stock_quotes] PRIMARY KEY ([symbol])
);

INSERT INTO [real_time_tables] ([TABLE_NAME], [LOAD_CODE], [IS_HISTORY], [IS_DISABLED], [TIME_ZONE], [RTD_INSTANCE_NAME]) VALUES ('vfx_last_stock_quotes', 'SELECT code FROM vfx_stock_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_last_stock_quotes', 'code', NULL, NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_last_stock_quotes', 'symbol', '=VFX|Name![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_last_stock_quotes', 'date', '=Date()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_last_stock_quotes', 'time', '=VFX|Time![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_last_stock_quotes', 'change', '=VFX|NetChange![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_last_stock_quotes', 'percent_change', '=VFX|PercentChange![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_last_stock_quotes', 'bid', '=VFX|Bid![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_last_stock_quotes', 'ask', '=VFX|Ask![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_last_stock_quotes', 'open', '=VFX|OpenPrice![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_last_stock_quotes', 'high', '=VFX|High![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_last_stock_quotes', 'low', '=VFX|Low![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_last_stock_quotes', 'close', '=VFX|ClosePrice![code]', NULL);

CREATE TABLE [vfx_stock_quotes_ticks] (
    [id] [int] IDENTITY(1,1) NOT NULL,
    [symbol] [nvarchar](50) NULL,
    [date] [datetime] NULL,
    [time] [datetime] NULL,
    [bid] [money] NULL,
    [ask] [money] NULL,
    [open] [money] NULL,
    [high] [money] NULL,
    [low] [money] NULL,
    [close] [money] NULL,
    [change] [money] NULL,
    [percent_change] [float] NULL,
  CONSTRAINT [pk_vfx_stock_quotes_ticks] PRIMARY KEY ([id])
);

INSERT INTO [real_time_tables] ([TABLE_NAME], [LOAD_CODE], [IS_HISTORY], [IS_DISABLED], [TIME_ZONE], [RTD_INSTANCE_NAME]) VALUES ('vfx_stock_quotes_ticks', 'SELECT code FROM vfx_stock_list', 1, 1, 'Eastern Standard Time', NULL);

INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_stock_quotes_ticks', 'id', NULL, NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_stock_quotes_ticks', 'code', NULL, NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_stock_quotes_ticks', 'symbol', '=VFX|Name![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_stock_quotes_ticks', 'date', '=Date()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_stock_quotes_ticks', 'time', '=VFX|Time![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_stock_quotes_ticks', 'change', '=VFX|NetChange![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_stock_quotes_ticks', 'percent_change', '=VFX|PercentChange![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_stock_quotes_ticks', 'bid', '=VFX|Bid![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_stock_quotes_ticks', 'ask', '=VFX|Ask![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_stock_quotes_ticks', 'open', '=VFX|OpenPrice![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_stock_quotes_ticks', 'high', '=VFX|High![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_stock_quotes_ticks', 'low', '=VFX|Low![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_stock_quotes_ticks', 'close', '=VFX|ClosePrice![code]', NULL);

CREATE TABLE [vfx_stock_quotes_time] (
    [symbol] [nvarchar](50) NOT NULL,
    [date] [datetime] NOT NULL,
    [time] [datetime] NOT NULL,
    [bid] [money] NULL,
    [ask] [money] NULL,
    [open] [money] NULL,
    [high] [money] NULL,
    [low] [money] NULL,
    [close] [money] NULL,
    [change] [money] NULL,
    [percent_change] [float] NULL,
    [last_update_timestamp] [timestamp] NULL,
  CONSTRAINT [pk_vfx_stock_quotes_time] PRIMARY KEY ([symbol], [date], [time])
);

INSERT INTO [real_time_tables] ([TABLE_NAME], [LOAD_CODE], [IS_HISTORY], [IS_DISABLED], [TIME_ZONE], [RTD_INSTANCE_NAME]) VALUES ('vfx_stock_quotes_time', 'SELECT code FROM vfx_stock_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_stock_quotes_time', 'code', NULL, NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_stock_quotes_time', 'symbol', '=VFX|Name![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_stock_quotes_time', 'date', '=Date()', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_stock_quotes_time', 'time', '=VFX|Time![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_stock_quotes_time', 'change', '=VFX|NetChange![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_stock_quotes_time', 'percent_change', '=VFX|PercentChange![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_stock_quotes_time', 'bid', '=VFX|Bid![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_stock_quotes_time', 'ask', '=VFX|Ask![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_stock_quotes_time', 'open', '=VFX|OpenPrice![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_stock_quotes_time', 'high', '=VFX|High![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_stock_quotes_time', 'low', '=VFX|Low![code]', NULL);
INSERT INTO [real_time_formulas] ([TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('vfx_stock_quotes_time', 'close', '=VFX|ClosePrice![code]', NULL);

