IF SCHEMA_ID('rtd') IS NULL
EXEC('CREATE SCHEMA [rtd]');

IF OBJECT_ID('[rtd].[real_time_formulas]') IS NULL
CREATE TABLE [rtd].[real_time_formulas] (
    [id] [int] IDENTITY(1,1) NOT NULL,
    [table_schema] [nvarchar](128) NOT NULL,
    [table_name] [nvarchar](128) NOT NULL,
    [column_name] [nvarchar](128) NOT NULL,
    [rtd_formula] [nvarchar](255) NULL,
    [is_disabled] [tinyint] NULL,
  CONSTRAINT [pk_real_time_formulas_rtd] PRIMARY KEY ([id]),
  CONSTRAINT [ix_real_time_formulas_schema_name_columnname_rtd] UNIQUE ([table_schema], [table_name], [column_name])
);

IF OBJECT_ID('[rtd].[real_time_tables]') IS NULL
CREATE TABLE [rtd].[real_time_tables] (
    [id] [int] IDENTITY(1,1) NOT NULL,
    [table_schema] [nvarchar](128) NOT NULL,
    [table_name] [nvarchar](128) NOT NULL,
    [load_code] [nvarchar](2000) NULL,
    [is_history] [tinyint] NULL,
    [is_disabled] [tinyint] NULL,
    [time_zone] [nvarchar](50) NULL,
    [rtd_instance_name] [nvarchar](50) NULL,
  CONSTRAINT [pk_real_time_tables_rtd] PRIMARY KEY ([id]),
  CONSTRAINT [ix_real_time_tables_schema_name_rtd] UNIQUE ([table_schema], [table_name])
);

CREATE TABLE [rtd].[vfx_stock_list] (
    [code] [varchar](50) NOT NULL,
  CONSTRAINT [pk_vfx_stock_list_rtd] PRIMARY KEY ([code])
);

CREATE TABLE [rtd].[vfx_historical_prices] (
    [symbol] [varchar](50) NOT NULL,
    [date] [date] NOT NULL,
    [time] [time](0) NULL,
    [bid] [smallmoney] NULL,
    [ask] [smallmoney] NULL,
    [open] [smallmoney] NULL,
    [high] [smallmoney] NULL,
    [low] [smallmoney] NULL,
    [close] [smallmoney] NULL,
    [change] [smallmoney] NULL,
    [percent_change] [float] NULL,
    [last_update_timestamp] [timestamp] NULL,
  CONSTRAINT [pk_vfx_historical_prices_rtd] PRIMARY KEY ([symbol], [date])
);

INSERT INTO [rtd].[real_time_tables] ([TABLE_SCHEMA], [TABLE_NAME], [LOAD_CODE], [IS_HISTORY], [IS_DISABLED], [TIME_ZONE], [RTD_INSTANCE_NAME]) VALUES ('rtd', 'vfx_historical_prices', 'SELECT code FROM rtd.vfx_stock_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_historical_prices', 'code', NULL, NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_historical_prices', 'symbol', '=VFX|Name![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_historical_prices', 'date', '=Date()', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_historical_prices', 'time', '=VFX|Time![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_historical_prices', 'change', '=VFX|NetChange![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_historical_prices', 'percent_change', '=VFX|PercentChange![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_historical_prices', 'bid', '=VFX|Bid![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_historical_prices', 'ask', '=VFX|Ask![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_historical_prices', 'open', '=VFX|OpenPrice![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_historical_prices', 'high', '=VFX|High![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_historical_prices', 'low', '=VFX|Low![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_historical_prices', 'close', '=VFX|ClosePrice![code]', NULL);

CREATE TABLE [rtd].[vfx_last_stock_quotes] (
    [symbol] [varchar](50) NOT NULL,
    [date] [date] NULL,
    [time] [time](0) NULL,
    [bid] [smallmoney] NULL,
    [ask] [smallmoney] NULL,
    [open] [smallmoney] NULL,
    [high] [smallmoney] NULL,
    [low] [smallmoney] NULL,
    [close] [smallmoney] NULL,
    [change] [smallmoney] NULL,
    [percent_change] [float] NULL,
    [last_update_timestamp] [timestamp] NULL,
  CONSTRAINT [pk_vfx_last_stock_quotes_rtd] PRIMARY KEY ([symbol])
);

INSERT INTO [rtd].[real_time_tables] ([TABLE_SCHEMA], [TABLE_NAME], [LOAD_CODE], [IS_HISTORY], [IS_DISABLED], [TIME_ZONE], [RTD_INSTANCE_NAME]) VALUES ('rtd', 'vfx_last_stock_quotes', 'SELECT code FROM rtd.vfx_stock_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_last_stock_quotes', 'code', NULL, NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_last_stock_quotes', 'symbol', '=VFX|Name![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_last_stock_quotes', 'date', '=Date()', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_last_stock_quotes', 'time', '=VFX|Time![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_last_stock_quotes', 'change', '=VFX|NetChange![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_last_stock_quotes', 'percent_change', '=VFX|PercentChange![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_last_stock_quotes', 'bid', '=VFX|Bid![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_last_stock_quotes', 'ask', '=VFX|Ask![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_last_stock_quotes', 'open', '=VFX|OpenPrice![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_last_stock_quotes', 'high', '=VFX|High![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_last_stock_quotes', 'low', '=VFX|Low![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_last_stock_quotes', 'close', '=VFX|ClosePrice![code]', NULL);

CREATE TABLE [rtd].[vfx_stock_quotes_ticks] (
    [id] [int] IDENTITY(1,1) NOT NULL,
    [symbol] [varchar](50) NULL,
    [date] [date] NULL,
    [time] [time](0) NULL,
    [bid] [smallmoney] NULL,
    [ask] [smallmoney] NULL,
    [open] [smallmoney] NULL,
    [high] [smallmoney] NULL,
    [low] [smallmoney] NULL,
    [close] [smallmoney] NULL,
    [change] [smallmoney] NULL,
    [percent_change] [float] NULL,
  CONSTRAINT [pk_vfx_stock_quotes_ticks_rtd] PRIMARY KEY ([id])
);

INSERT INTO [rtd].[real_time_tables] ([TABLE_SCHEMA], [TABLE_NAME], [LOAD_CODE], [IS_HISTORY], [IS_DISABLED], [TIME_ZONE], [RTD_INSTANCE_NAME]) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'SELECT code FROM rtd.vfx_stock_list', 1, 1, 'Eastern Standard Time', NULL);

INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'id', NULL, NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'code', NULL, NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'symbol', '=VFX|Name![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'date', '=Date()', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'time', '=VFX|Time![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'change', '=VFX|NetChange![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'percent_change', '=VFX|PercentChange![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'bid', '=VFX|Bid![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'ask', '=VFX|Ask![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'open', '=VFX|OpenPrice![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'high', '=VFX|High![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'low', '=VFX|Low![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_stock_quotes_ticks', 'close', '=VFX|ClosePrice![code]', NULL);

CREATE TABLE [rtd].[vfx_stock_quotes_time] (
    [symbol] [varchar](50) NOT NULL,
    [date] [date] NOT NULL,
    [time] [time](0) NOT NULL,
    [bid] [smallmoney] NULL,
    [ask] [smallmoney] NULL,
    [open] [smallmoney] NULL,
    [high] [smallmoney] NULL,
    [low] [smallmoney] NULL,
    [close] [smallmoney] NULL,
    [change] [smallmoney] NULL,
    [percent_change] [float] NULL,
    [last_update_timestamp] [timestamp] NULL,
  CONSTRAINT [pk_vfx_stock_quotes_time_rtd] PRIMARY KEY ([symbol],
    [date],
    [time])
);

INSERT INTO [rtd].[real_time_tables] ([TABLE_SCHEMA], [TABLE_NAME], [LOAD_CODE], [IS_HISTORY], [IS_DISABLED], [TIME_ZONE], [RTD_INSTANCE_NAME]) VALUES ('rtd', 'vfx_stock_quotes_time', 'SELECT code FROM rtd.vfx_stock_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_stock_quotes_time', 'code', NULL, NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_stock_quotes_time', 'symbol', '=VFX|Name![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_stock_quotes_time', 'date', '=Date()', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_stock_quotes_time', 'time', '=VFX|Time![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_stock_quotes_time', 'change', '=VFX|NetChange![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_stock_quotes_time', 'percent_change', '=VFX|PercentChange![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_stock_quotes_time', 'bid', '=VFX|Bid![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_stock_quotes_time', 'ask', '=VFX|Ask![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_stock_quotes_time', 'open', '=VFX|OpenPrice![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_stock_quotes_time', 'high', '=VFX|High![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_stock_quotes_time', 'low', '=VFX|Low![code]', NULL);
INSERT INTO [rtd].[real_time_formulas] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [RTD_FORMULA], [IS_DISABLED]) VALUES ('rtd', 'vfx_stock_quotes_time', 'close', '=VFX|ClosePrice![code]', NULL);

