CREATE SCHEMA IF NOT EXISTS `rtd`;

CREATE TABLE IF NOT EXISTS `rtd`.`real_time_formulas` (
    `ID` INTEGER NOT NULL AUTO_INCREMENT,
    `TABLE_SCHEMA` VARCHAR(128) NOT NULL,
    `TABLE_NAME` VARCHAR(128) NOT NULL,
    `COLUMN_NAME` VARCHAR(128) NOT NULL,
    `RTD_FORMULA` VARCHAR(255) NULL,
    `IS_DISABLED` TINYINT NULL,
  PRIMARY KEY (`ID`)
);

ALTER TABLE `rtd`.`real_time_formulas`
    ADD UNIQUE INDEX `ix_real_time_formulas_schema_name_column_name`
    USING BTREE (
       `TABLE_SCHEMA`,
       `TABLE_NAME`,
       `COLUMN_NAME`
    );


CREATE TABLE IF NOT EXISTS `rtd`.`real_time_tables` (
    `ID` INTEGER NOT NULL AUTO_INCREMENT,
    `TABLE_SCHEMA` VARCHAR(128) NOT NULL,
    `TABLE_NAME` VARCHAR(128) NOT NULL,
    `LOAD_CODE` VARCHAR(2000) NULL,
    `IS_HISTORY` TINYINT NULL,
    `IS_DISABLED` TINYINT NULL,
    `TIME_ZONE` VARCHAR(50) NULL,
    `RTD_INSTANCE_NAME` VARCHAR(50) NULL,
  PRIMARY KEY (`ID`)
);

ALTER TABLE `rtd`.`real_time_tables`
    ADD UNIQUE INDEX `ix_realtimetables_schema_name`
    USING BTREE (
       `TABLE_SCHEMA`,
       `TABLE_NAME`
    );
    
CREATE TABLE IF NOT EXISTS `rtd`.`tws_stock_list` (
    `TICK_ID` INTEGER NOT NULL AUTO_INCREMENT,
    `CODE` VARCHAR(50) NOT NULL,
  PRIMARY KEY (`TICK_ID`)
);

ALTER TABLE `rtd`.`tws_stock_list`
    ADD UNIQUE INDEX `ix_tws_stock_list_code`
    USING BTREE (
        `CODE`
    );

CREATE TABLE IF NOT EXISTS `rtd`.`tws_historical_option_data` (
    `CODE` VARCHAR(255) NOT NULL,
    `DATE` DATE NOT NULL,
    `TIME` TIME NULL,
    `LAST` DOUBLE NULL,
    `LAST_SIZE` INTEGER NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` INTEGER NULL,
    `ASK_SIZE` INTEGER NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `VOLUME` BIGINT NULL,
    `UNDERLYING_PRICE` DOUBLE NULL,
    `MODEL_PRICE` DOUBLE NULL,
    `IMPLIED_VOL` DOUBLE NULL,
    `BID_IMPLIED_VOL` DOUBLE NULL,
    `ASK_IMPLIED_VOL` DOUBLE NULL,
    `LAST_IMPLIED_VOL` DOUBLE NULL,
    `BID_DELTA` DOUBLE NULL,
    `ASK_DELTA` DOUBLE NULL,
    `LAST_DELTA` DOUBLE NULL,
    `DELTA` DOUBLE NULL,
    `GAMMA` DOUBLE NULL,
    `THETA` DOUBLE NULL,
    `VEGA` DOUBLE NULL,
    `PV_DIVIDEND` DOUBLE NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`CODE`, `DATE`)
);


INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('rtd', 'tws_historical_option_data', 'SELECT TICK_ID, CODE FROM rtd.tws_stock_list WHERE CODE LIKE ''%_OPT_20%''', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'TICK_ID', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'CODE', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'REQ', '=S|tik!''id[TICK_ID]?req?[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'DATE', '=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'TIME', '=Time()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'LAST', '=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'LAST_SIZE', '=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'BID', '=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'ASK', '=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'BID_SIZE', '=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'ASK_SIZE', '=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'HIGH', '=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'LOW', '=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'CLOSE', '=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'VOLUME', '=S|tik!id[TICK_ID]?volume', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'UNDERLYING_PRICE', '=S|tik!id[TICK_ID]?modelUndPrice', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'MODEL_PRICE', '=S|tik!id[TICK_ID]?modelPrice', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'IMPLIED_VOL', '=S|tik!id[TICK_ID]?modelVolatility', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'BID_IMPLIED_VOL', '=S|tik!id[TICK_ID]?bidImpliedVol', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'ASK_IMPLIED_VOL', '=S|tik!id[TICK_ID]?askImpliedVol', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'LAST_IMPLIED_VOL', '=S|tik!id[TICK_ID]?lastImpliedVol', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'BID_DELTA', '=S|tik!id[TICK_ID]?bidDelta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'ASK_DELTA', '=S|tik!id[TICK_ID]?askDelta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'LAST_DELTA', '=S|tik!id[TICK_ID]?lastDelta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'DELTA', '=S|tik!id[TICK_ID]?modelDelta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'GAMMA', '=S|tik!id[TICK_ID]?modelGamma', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'THETA', '=S|tik!id[TICK_ID]?modelTheta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'VEGA', '=S|tik!id[TICK_ID]?modelVega', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_option_data', 'PV_DIVIDEND', '=S|tik!id[TICK_ID]?pvDividend', NULL);

CREATE TABLE IF NOT EXISTS `rtd`.`tws_historical_prices` (
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATE` DATE NOT NULL,
    `TIME` TIME NULL,
    `LAST` DOUBLE NULL,
    `LAST_SIZE` INTEGER NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` INTEGER NULL,
    `ASK_SIZE` INTEGER NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `VOLUME` BIGINT NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`SYMBOL`, `DATE`)
);


INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('rtd', 'tws_historical_prices', 'SELECT TICK_ID, CODE AS SYMBOL FROM rtd.tws_stock_list WHERE CODE NOT LIKE ''%_OPT_20%''', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_prices', 'ID', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_prices', 'TICK_ID', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_prices', 'SYMBOL', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_prices', 'REQ', '=S|tik!''id[TICK_ID]?req?[SYMBOL]_STK_SMART_USD_~''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_prices', 'DATE', '=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_prices', 'TIME', '=Time()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_prices', 'LAST', '=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_prices', 'LAST_SIZE', '=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_prices', 'BID', '=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_prices', 'ASK', '=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_prices', 'BID_SIZE', '=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_prices', 'ASK_SIZE', '=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_prices', 'HIGH', '=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_prices', 'LOW', '=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_prices', 'CLOSE', '=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_historical_prices', 'VOLUME', '=S|tik!id[TICK_ID]?volume', NULL);

CREATE TABLE IF NOT EXISTS `rtd`.`tws_last_option_data` (
    `CODE` VARCHAR(255) NOT NULL,
    `DATETIME` DATETIME NULL,
    `DATE` DATE NULL,
    `TIME` TIME NULL,
    `LAST` DOUBLE NULL,
    `LAST_SIZE` INTEGER NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` INTEGER NULL,
    `ASK_SIZE` INTEGER NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `VOLUME` BIGINT NULL,
    `UNDERLYING_PRICE` DOUBLE NULL,
    `MODEL_PRICE` DOUBLE NULL,
    `IMPLIED_VOL` DOUBLE NULL,
    `BID_IMPLIED_VOL` DOUBLE NULL,
    `ASK_IMPLIED_VOL` DOUBLE NULL,
    `LAST_IMPLIED_VOL` DOUBLE NULL,
    `BID_DELTA` DOUBLE NULL,
    `ASK_DELTA` DOUBLE NULL,
    `LAST_DELTA` DOUBLE NULL,
    `DELTA` DOUBLE NULL,
    `GAMMA` DOUBLE NULL,
    `THETA` DOUBLE NULL,
    `VEGA` DOUBLE NULL,
    `PV_DIVIDEND` DOUBLE NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`CODE`)
);


INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('rtd', 'tws_last_option_data', 'SELECT TICK_ID, CODE FROM rtd.tws_stock_list WHERE CODE LIKE ''%_OPT_20%''', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'TICK_ID', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'CODE', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'REQ', '=S|tik!''id[TICK_ID]?req?[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'DATETIME', '=DateTime()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'DATE', '=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'TIME', '=Time()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'LAST', '=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'LAST_SIZE', '=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'BID', '=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'ASK', '=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'BID_SIZE', '=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'ASK_SIZE', '=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'HIGH', '=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'LOW', '=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'CLOSE', '=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'VOLUME', '=S|tik!id[TICK_ID]?volume', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'UNDERLYING_PRICE', '=S|tik!id[TICK_ID]?modelUndPrice', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'MODEL_PRICE', '=S|tik!id[TICK_ID]?modelPrice', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'IMPLIED_VOL', '=S|tik!id[TICK_ID]?modelVolatility', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'BID_IMPLIED_VOL', '=S|tik!id[TICK_ID]?bidImpliedVol', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'ASK_IMPLIED_VOL', '=S|tik!id[TICK_ID]?askImpliedVol', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'LAST_IMPLIED_VOL', '=S|tik!id[TICK_ID]?lastImpliedVol', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'BID_DELTA', '=S|tik!id[TICK_ID]?bidDelta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'ASK_DELTA', '=S|tik!id[TICK_ID]?askDelta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'LAST_DELTA', '=S|tik!id[TICK_ID]?lastDelta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'DELTA', '=S|tik!id[TICK_ID]?modelDelta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'GAMMA', '=S|tik!id[TICK_ID]?modelGamma', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'THETA', '=S|tik!id[TICK_ID]?modelTheta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'VEGA', '=S|tik!id[TICK_ID]?modelVega', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_option_data', 'PV_DIVIDEND', '=S|tik!id[TICK_ID]?pvDividend', NULL);

CREATE TABLE IF NOT EXISTS `rtd`.`tws_last_stock_quotes` (
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATETIME` DATETIME NULL,
    `DATE` DATE NULL,
    `TIME` TIME NULL,
    `LAST` DOUBLE NULL,
    `LAST_SIZE` INTEGER NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` INTEGER NULL,
    `ASK_SIZE` INTEGER NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `VOLUME` BIGINT NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`SYMBOL`)
);


INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('rtd', 'tws_last_stock_quotes', 'SELECT TICK_ID, CODE AS SYMBOL FROM rtd.tws_stock_list WHERE CODE NOT LIKE ''%_OPT_20%''', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_stock_quotes', 'TICK_ID', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_stock_quotes', 'SYMBOL', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_stock_quotes', 'REQ', '=S|tik!''id[TICK_ID]?req?[SYMBOL]_STK_SMART_USD_~''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_stock_quotes', 'DATETIME', '=DateTime()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_stock_quotes', 'DATE', '=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_stock_quotes', 'TIME', '=Time()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_stock_quotes', 'LAST', '=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_stock_quotes', 'LAST_SIZE', '=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_stock_quotes', 'BID', '=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_stock_quotes', 'ASK', '=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_stock_quotes', 'BID_SIZE', '=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_stock_quotes', 'ASK_SIZE', '=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_stock_quotes', 'HIGH', '=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_stock_quotes', 'LOW', '=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_stock_quotes', 'CLOSE', '=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_last_stock_quotes', 'VOLUME', '=S|tik!id[TICK_ID]?volume', NULL);

CREATE TABLE IF NOT EXISTS `rtd`.`tws_option_data_ticks` (
    `ID` INTEGER NOT NULL AUTO_INCREMENT,
    `CODE` VARCHAR(255) NOT NULL,
    `DATETIME` DATETIME NULL,
    `DATE` DATE NULL,
    `TIME` TIME NULL,
    `LAST` DOUBLE NULL,
    `LAST_SIZE` INTEGER NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` INTEGER NULL,
    `ASK_SIZE` INTEGER NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `VOLUME` BIGINT NULL,
    `UNDERLYING_PRICE` DOUBLE NULL,
    `MODEL_PRICE` DOUBLE NULL,
    `IMPLIED_VOL` DOUBLE NULL,
    `BID_IMPLIED_VOL` DOUBLE NULL,
    `ASK_IMPLIED_VOL` DOUBLE NULL,
    `LAST_IMPLIED_VOL` DOUBLE NULL,
    `BID_DELTA` DOUBLE NULL,
    `ASK_DELTA` DOUBLE NULL,
    `LAST_DELTA` DOUBLE NULL,
    `DELTA` DOUBLE NULL,
    `GAMMA` DOUBLE NULL,
    `THETA` DOUBLE NULL,
    `VEGA` DOUBLE NULL,
    `PV_DIVIDEND` DOUBLE NULL,
  PRIMARY KEY (`ID`)
);


INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('rtd', 'tws_option_data_ticks', 'SELECT TICK_ID, CODE FROM rtd.tws_stock_list WHERE CODE LIKE ''%_OPT_20%''', 1, 1, 'Eastern Standard Time', NULL);

INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'ID', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'TICK_ID', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'CODE', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'REQ', '=S|tik!''id[TICK_ID]?req?[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'DATETIME', '=DateTime()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'DATE', '=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'TIME', '=Time()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'LAST', '=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'LAST_SIZE', '=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'BID', '=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'ASK', '=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'BID_SIZE', '=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'ASK_SIZE', '=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'HIGH', '=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'LOW', '=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'CLOSE', '=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'VOLUME', '=S|tik!id[TICK_ID]?volume', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'UNDERLYING_PRICE', '=S|tik!id[TICK_ID]?modelUndPrice', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'MODEL_PRICE', '=S|tik!id[TICK_ID]?modelPrice', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'IMPLIED_VOL', '=S|tik!id[TICK_ID]?modelVolatility', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'BID_IMPLIED_VOL', '=S|tik!id[TICK_ID]?bidImpliedVol', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'ASK_IMPLIED_VOL', '=S|tik!id[TICK_ID]?askImpliedVol', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'LAST_IMPLIED_VOL', '=S|tik!id[TICK_ID]?lastImpliedVol', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'BID_DELTA', '=S|tik!id[TICK_ID]?bidDelta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'ASK_DELTA', '=S|tik!id[TICK_ID]?askDelta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'LAST_DELTA', '=S|tik!id[TICK_ID]?lastDelta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'DELTA', '=S|tik!id[TICK_ID]?modelDelta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'GAMMA', '=S|tik!id[TICK_ID]?modelGamma', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'THETA', '=S|tik!id[TICK_ID]?modelTheta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'VEGA', '=S|tik!id[TICK_ID]?modelVega', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_option_data_ticks', 'PV_DIVIDEND', '=S|tik!id[TICK_ID]?pvDividend', NULL);

CREATE TABLE IF NOT EXISTS `rtd`.`tws_stock_quotes_ticks` (
    `ID` INTEGER NOT NULL AUTO_INCREMENT,
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATETIME` DATETIME NULL,
    `DATE` DATE NULL,
    `TIME` TIME NULL,
    `LAST` DOUBLE NULL,
    `LAST_SIZE` INTEGER NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` INTEGER NULL,
    `ASK_SIZE` INTEGER NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `VOLUME` BIGINT NULL,
  PRIMARY KEY (`ID`)
);


INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('rtd', 'tws_stock_quotes_ticks', 'SELECT TICK_ID, CODE AS SYMBOL FROM rtd.tws_stock_list WHERE CODE NOT LIKE ''%_OPT_20%''', 1, 1, 'Eastern Standard Time', NULL);

INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_stock_quotes_ticks', 'ID', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_stock_quotes_ticks', 'TICK_ID', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_stock_quotes_ticks', 'SYMBOL', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_stock_quotes_ticks', 'REQ', '=S|tik!''id[TICK_ID]?req?[SYMBOL]_STK_SMART_USD_~''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_stock_quotes_ticks', 'DATETIME', '=DateTime()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_stock_quotes_ticks', 'DATE', '=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_stock_quotes_ticks', 'TIME', '=Time()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_stock_quotes_ticks', 'LAST', '=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_stock_quotes_ticks', 'LAST_SIZE', '=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_stock_quotes_ticks', 'BID', '=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_stock_quotes_ticks', 'ASK', '=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_stock_quotes_ticks', 'BID_SIZE', '=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_stock_quotes_ticks', 'ASK_SIZE', '=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_stock_quotes_ticks', 'HIGH', '=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_stock_quotes_ticks', 'LOW', '=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_stock_quotes_ticks', 'CLOSE', '=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('rtd', 'tws_stock_quotes_ticks', 'VOLUME', '=S|tik!id[TICK_ID]?volume', NULL);

