CREATE SCHEMA "RTD";

CREATE TABLE "RTD"."REAL_TIME_FORMULAS" (
    "ID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY,
    "TABLE_SCHEMA" VARCHAR(128) NOT NULL,
    "TABLE_NAME" VARCHAR(128) NOT NULL,
    "COLUMN_NAME" VARCHAR(128) NOT NULL,
    "RTD_FORMULA" VARCHAR(255) NULL,
    "IS_DISABLED" SMALLINT NULL,
    PRIMARY KEY ("ID")
);

CREATE UNIQUE INDEX "IX_REAL_TIME_FORMULAS_COLUMN"
    ON "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME");

CREATE TABLE "RTD"."REAL_TIME_TABLES" (
    "ID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY,
    "TABLE_SCHEMA" VARCHAR(128) NOT NULL,
    "TABLE_NAME" VARCHAR(128) NOT NULL,
    "LOAD_CODE" STRING NULL,
    "IS_HISTORY" SMALLINT NULL,
    "IS_DISABLED" SMALLINT NULL,
    "TIME_ZONE" VARCHAR(50) NULL,
    "RTD_INSTANCE_NAME" VARCHAR(50) NULL,
    PRIMARY KEY ("ID")
);

CREATE UNIQUE INDEX "IX_REAL_TIME_TABLES_TABLE"
    ON "RTD"."REAL_TIME_TABLES" ("TABLE_SCHEMA", "TABLE_NAME");
CREATE TABLE "RTD"."TOS_STOCK_LIST" (
    "SYMBOL" VARCHAR(50) NOT NULL,
    PRIMARY KEY ("SYMBOL")
);


CREATE TABLE "RTD"."TOS_OPTION_LIST" (
    "CODE" VARCHAR(50) NOT NULL,
    PRIMARY KEY ("CODE")
);


CREATE TABLE "RTD"."TOS_HISTORICAL_OPTION_DATA" (
    "CODE" VARCHAR(50) NOT NULL,
    "DATE" DATE NOT NULL,
    "TIME" TIME NULL,
    "DESCRIPTION" VARCHAR(255) NULL,
    "LAST" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "LAST_SIZE" SMALLINT NULL,
    "LAST_X" CHARACTER(1) NULL,
    "MARK" DOUBLE NULL,
    "MARK_CHANGE" DOUBLE NULL,
    "MARK_PERCENT_CHANGE" DOUBLE NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "BID_SIZE" SMALLINT NULL,
    "ASK_SIZE" SMALLINT NULL,
    "BID_ASK_SIZE" VARCHAR(50) NULL,
    "BID_X" CHARACTER(1) NULL,
    "ASK_X" CHARACTER(1) NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "CLOSE" DOUBLE NULL,
    "VOLUME" INTEGER NULL,
    "OPEN_INT" INTEGER NULL,
    "IMPLIED_VOL" DOUBLE NULL,
    "DELTA" DOUBLE NULL,
    "GAMMA" DOUBLE NULL,
    "THETA" DOUBLE NULL,
    "VEGA" DOUBLE NULL,
    "RHO" DOUBLE NULL,
    "EXTRINSIC" DOUBLE NULL,
    "INTRINSIC" DOUBLE NULL,
    "PROBABILITY_ITM" DOUBLE NULL,
    "PROBABILITY_OTM" DOUBLE NULL,
    "PROBABILITY_TOUCH" DOUBLE NULL,
    "COVERED_RETURN" DOUBLE NULL,
    "MAX_COVERED_RETURN" DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
    PRIMARY KEY ("CODE", "DATE")
);


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'SELECT CODE FROM RTD.TOS_OPTION_LIST', NULL, NULL, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'CODE');
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'TIME', '=Time()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'DESCRIPTION', '=TOS|DESCRIPTION!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'LAST', '=TOS|LAST!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'CHANGE', '=TOS|NET_CHANGE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'PERCENT_CHANGE', '=TOS|PERCENT_CHANGE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'LAST_SIZE', '=TOS|LAST_SIZE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'LAST_X', '=TOS|LX!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'MARK', '=TOS|MARK!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'MARK_CHANGE', '=TOS|MARK_CHANGE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'MARK_PERCENT_CHANGE', '=TOS|MARK_PERCENT_CHANGE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'BID', '=TOS|BID!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'ASK', '=TOS|ASK!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'BID_SIZE', '=TOS|BID_SIZE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'ASK_SIZE', '=TOS|ASK_SIZE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'BID_ASK_SIZE', '=TOS|BA_SIZE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'BID_X', '=TOS|BX!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'ASK_X', '=TOS|AX!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'OPEN', '=TOS|OPEN!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'HIGH', '=TOS|HIGH!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'LOW', '=TOS|LOW!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'CLOSE', '=TOS|Close!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'VOLUME', '=TOS|VOLUME!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'OPEN_INT', '=TOS|OPEN_INT!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'IMPLIED_VOL', '=TOS|IMPL_VOL!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'DELTA', '=TOS|DELTA!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'GAMMA', '=TOS|GAMMA!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'THETA', '=TOS|THETA!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'VEGA', '=TOS|VEGA!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'RHO', '=TOS|RHO!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'EXTRINSIC', '=TOS|EXTRINSIC!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'INTRINSIC', '=TOS|INTRINSIC!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'PROBABILITY_ITM', '=TOS|PROB_OF_EXPIRING!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'PROBABILITY_OTM', '=TOS|PROB_OTM!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'PROBABILITY_TOUCH', '=TOS|PROB_OF_TOUCHING!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'COVERED_RETURN', '=TOS|COVERED_RETURN!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'MAX_COVERED_RETURN', '=TOS|MAX_COVERED_RETURN!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'LAST_UPDATE_TIMESTAMP', '=TimeStamp()', NULL);

CREATE TABLE "RTD"."TOS_HISTORICAL_PRICES" (
    "SYMBOL" VARCHAR(50) NOT NULL,
    "DATE" DATE NOT NULL,
    "TIME" TIME NULL,
    "DESCRIPTION" VARCHAR(255) NULL,
    "LAST" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "LAST_SIZE" INTEGER NULL,
    "LAST_X" CHARACTER(1) NULL,
    "MARK" DOUBLE NULL,
    "MARK_CHANGE" DOUBLE NULL,
    "MARK_PERCENT_CHANGE" DOUBLE NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "BID_SIZE" INTEGER NULL,
    "ASK_SIZE" INTEGER NULL,
    "BID_ASK_SIZE" VARCHAR(255) NULL,
    "BID_X" CHARACTER(1) NULL,
    "ASK_X" CHARACTER(1) NULL,
    "STRENGTH_METER" VARCHAR(255) NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "CLOSE" DOUBLE NULL,
    "VOLUME" BIGINT NULL,
    "OPEN_INT" INTEGER NULL,
    "IMPLIED_VOL" DOUBLE NULL,
    "VOL_INDEX" DOUBLE NULL,
    "FRONT_VOL" DOUBLE NULL,
    "BACK_VOL" DOUBLE NULL,
    "WEIGHTED_BACK_VOL" DOUBLE NULL,
    "VOL_DIFF" DOUBLE NULL,
    "PUT_CALL_RATIO" DOUBLE NULL,
    "CALL_VOLUME_INDEX" DOUBLE NULL,
    "PUT_VOLUME_INDEX" DOUBLE NULL,
    "OPTION_VOLUME_INDEX" DOUBLE NULL,
    "FRONT_EXPECTED_MOVE" DOUBLE NULL,
    "BACK_EXPECTED_MOVE" DOUBLE NULL,
    "EXPECTED_MOVE_DIFF" DOUBLE NULL,
    "BETA" DOUBLE NULL,
    "HIGH52" DOUBLE NULL,
    "LOW52" DOUBLE NULL,
    "PE" DOUBLE NULL,
    "EPS" DOUBLE NULL,
    "MARKET_CAP" VARCHAR(255) NULL,
    "SHARES" BIGINT NULL,
    "DIVIDEND_YIELD" DOUBLE NULL,
    "DIVIDEND_SHARE" DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
    PRIMARY KEY ("SYMBOL", "DATE")
);


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'SELECT SYMBOL FROM RTD.TOS_STOCK_LIST', NULL, NULL, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'SYMBOL');
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'TIME', '=Time()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'DESCRIPTION', '=TOS|DESCRIPTION![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'LAST', '=TOS|LAST![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'CHANGE', '=TOS|NET_CHANGE![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'PERCENT_CHANGE', '=TOS|PERCENT_CHANGE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'LAST_SIZE', '=TOS|LAST_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'LAST_X', '=TOS|LX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'MARK', '=TOS|MARK![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'MARK_CHANGE', '=TOS|MARK_CHANGE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'MARK_PERCENT_CHANGE', '=TOS|MARK_PERCENT_CHANGE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'BID', '=TOS|BID![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'ASK', '=TOS|ASK![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'BID_SIZE', '=TOS|BID_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'ASK_SIZE', '=TOS|ASK_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'BID_ASK_SIZE', '=TOS|BA_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'BID_X', '=TOS|BX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'ASK_X', '=TOS|AX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'STRENGTH_METER', '=TOS|STRENGTH_METER![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'OPEN', '=TOS|OPEN![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'HIGH', '=TOS|HIGH![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'LOW', '=TOS|LOW![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'CLOSE', '=TOS|CLOSE![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'VOLUME', '=TOS|VOLUME![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'OPEN_INT', '=TOS|OPEN_INT![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'IMPLIED_VOL', '=TOS|IMPL_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'VOL_INDEX', '=TOS|VOL_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'FRONT_VOL', '=TOS|FRONT_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'BACK_VOL', '=TOS|BACK_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'WEIGHTED_BACK_VOL', '=TOS|WEIGHTED_BACK_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'VOL_DIFF', '=TOS|VOL_DIFF![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'PUT_CALL_RATIO', '=TOS|PUT_CALL_RATIO![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'CALL_VOLUME_INDEX', '=TOS|CALL_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'PUT_VOLUME_INDEX', '=TOS|PUT_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'OPTION_VOLUME_INDEX', '=TOS|OPTION_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'FRONT_EXPECTED_MOVE', '=TOS|FRONT_EX_MOVE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'BACK_EXPECTED_MOVE', '=TOS|BACK_EX_MOVE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'EXPECTED_MOVE_DIFF', '=TOS|EX_MOVE_DIFF![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'BETA', '=TOS|BETA![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'HIGH52', '=TOS|''52HIGH''![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'LOW52', '=TOS|''52LOW''![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'PE', '=TOS|PE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'EPS', '=TOS|EPS![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'MARKET_CAP', '=TOS|MARKET_CAP![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'SHARES', '=TOS|SHARES![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'DIVIDEND_YIELD', '=TOS|YIELD![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'DIVIDEND_SHARE', '=TOS|DIV![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'LAST_UPDATE_TIMESTAMP', '=TimeStamp()', NULL);

CREATE TABLE "RTD"."TOS_LAST_OPTION_DATA" (
    "CODE" VARCHAR(50) NOT NULL,
    "DATETIME" TIMESTAMP(3) NULL,
    "DATE" DATE NULL,
    "TIME" TIME NULL,
    "DESCRIPTION" VARCHAR(255) NULL,
    "LAST" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "LAST_SIZE" SMALLINT NULL,
    "LAST_X" CHARACTER(1) NULL,
    "MARK" DOUBLE NULL,
    "MARK_CHANGE" DOUBLE NULL,
    "MARK_PERCENT_CHANGE" DOUBLE NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "BID_SIZE" SMALLINT NULL,
    "ASK_SIZE" SMALLINT NULL,
    "BID_ASK_SIZE" VARCHAR(50) NULL,
    "BID_X" CHARACTER(1) NULL,
    "ASK_X" CHARACTER(1) NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "CLOSE" DOUBLE NULL,
    "VOLUME" INTEGER NULL,
    "OPEN_INT" INTEGER NULL,
    "IMPLIED_VOL" DOUBLE NULL,
    "DELTA" DOUBLE NULL,
    "GAMMA" DOUBLE NULL,
    "THETA" DOUBLE NULL,
    "VEGA" DOUBLE NULL,
    "RHO" DOUBLE NULL,
    "EXTRINSIC" DOUBLE NULL,
    "INTRINSIC" DOUBLE NULL,
    "PROBABILITY_ITM" DOUBLE NULL,
    "PROBABILITY_OTM" DOUBLE NULL,
    "PROBABILITY_TOUCH" DOUBLE NULL,
    "COVERED_RETURN" DOUBLE NULL,
    "MAX_COVERED_RETURN" DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
    PRIMARY KEY ("CODE")
);


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'SELECT CODE FROM RTD.TOS_OPTION_LIST', NULL, NULL, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'CODE');
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'DATETIME', '=DateTime()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'TIME', '=Time()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'DESCRIPTION', '=TOS|DESCRIPTION!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'LAST', '=TOS|LAST!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'CHANGE', '=TOS|NET_CHANGE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'PERCENT_CHANGE', '=TOS|PERCENT_CHANGE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'LAST_SIZE', '=TOS|LAST_SIZE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'LAST_X', '=TOS|LX!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'MARK', '=TOS|MARK!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'MARK_CHANGE', '=TOS|MARK_CHANGE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'MARK_PERCENT_CHANGE', '=TOS|MARK_PERCENT_CHANGE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'BID', '=TOS|BID!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'ASK', '=TOS|ASK!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'BID_SIZE', '=TOS|BID_SIZE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'ASK_SIZE', '=TOS|ASK_SIZE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'BID_ASK_SIZE', '=TOS|BA_SIZE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'BID_X', '=TOS|BX!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'ASK_X', '=TOS|AX!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'OPEN', '=TOS|OPEN!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'HIGH', '=TOS|HIGH!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'LOW', '=TOS|LOW!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'CLOSE', '=TOS|Close!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'VOLUME', '=TOS|VOLUME!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'OPEN_INT', '=TOS|OPEN_INT!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'IMPLIED_VOL', '=TOS|IMPL_VOL!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'DELTA', '=TOS|DELTA!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'GAMMA', '=TOS|GAMMA!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'THETA', '=TOS|THETA!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'VEGA', '=TOS|VEGA!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'RHO', '=TOS|RHO!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'EXTRINSIC', '=TOS|EXTRINSIC!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'INTRINSIC', '=TOS|INTRINSIC!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'PROBABILITY_ITM', '=TOS|PROB_OF_EXPIRING!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'PROBABILITY_OTM', '=TOS|PROB_OTM!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'PROBABILITY_TOUCH', '=TOS|PROB_OF_TOUCHING!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'COVERED_RETURN', '=TOS|COVERED_RETURN!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'MAX_COVERED_RETURN', '=TOS|MAX_COVERED_RETURN!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'LAST_UPDATE_TIMESTAMP', '=TimeStamp()', NULL);

CREATE TABLE "RTD"."TOS_LAST_STOCK_QUOTES" (
    "SYMBOL" VARCHAR(50) NOT NULL,
    "DATETIME" TIMESTAMP(3) NULL,
    "DATE" DATE NULL,
    "TIME" TIME NULL,
    "DESCRIPTION" VARCHAR(255) NULL,
    "LAST" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "LAST_SIZE" INTEGER NULL,
    "LAST_X" CHARACTER(1) NULL,
    "MARK" DOUBLE NULL,
    "MARK_CHANGE" DOUBLE NULL,
    "MARK_PERCENT_CHANGE" DOUBLE NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "BID_SIZE" INTEGER NULL,
    "ASK_SIZE" INTEGER NULL,
    "BID_ASK_SIZE" VARCHAR(255) NULL,
    "BID_X" CHARACTER(1) NULL,
    "ASK_X" CHARACTER(1) NULL,
    "STRENGTH_METER" VARCHAR(255) NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "CLOSE" DOUBLE NULL,
    "VOLUME" BIGINT NULL,
    "OPEN_INT" INTEGER NULL,
    "IMPLIED_VOL" DOUBLE NULL,
    "VOL_INDEX" DOUBLE NULL,
    "FRONT_VOL" DOUBLE NULL,
    "BACK_VOL" DOUBLE NULL,
    "WEIGHTED_BACK_VOL" DOUBLE NULL,
    "VOL_DIFF" DOUBLE NULL,
    "PUT_CALL_RATIO" DOUBLE NULL,
    "CALL_VOLUME_INDEX" DOUBLE NULL,
    "PUT_VOLUME_INDEX" DOUBLE NULL,
    "OPTION_VOLUME_INDEX" DOUBLE NULL,
    "FRONT_EXPECTED_MOVE" DOUBLE NULL,
    "BACK_EXPECTED_MOVE" DOUBLE NULL,
    "EXPECTED_MOVE_DIFF" DOUBLE NULL,
    "BETA" DOUBLE NULL,
    "HIGH52" DOUBLE NULL,
    "LOW52" DOUBLE NULL,
    "PE" DOUBLE NULL,
    "EPS" DOUBLE NULL,
    "MARKET_CAP" VARCHAR(255) NULL,
    "SHARES" BIGINT NULL,
    "DIVIDEND_YIELD" DOUBLE NULL,
    "DIVIDEND_SHARE" DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
    PRIMARY KEY ("SYMBOL")
);


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'SELECT SYMBOL FROM RTD.TOS_STOCK_LIST', NULL, NULL, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'SYMBOL');
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'DATETIME', '=DateTime()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'TIME', '=Time()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'DESCRIPTION', '=TOS|DESCRIPTION![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'LAST', '=TOS|LAST![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'CHANGE', '=TOS|NET_CHANGE![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'PERCENT_CHANGE', '=TOS|PERCENT_CHANGE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'LAST_SIZE', '=TOS|LAST_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'LAST_X', '=TOS|LX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'MARK', '=TOS|MARK![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'MARK_CHANGE', '=TOS|MARK_CHANGE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'MARK_PERCENT_CHANGE', '=TOS|MARK_PERCENT_CHANGE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'BID', '=TOS|BID![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'ASK', '=TOS|ASK![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'BID_SIZE', '=TOS|BID_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'ASK_SIZE', '=TOS|ASK_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'BID_ASK_SIZE', '=TOS|BA_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'BID_X', '=TOS|BX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'ASK_X', '=TOS|AX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'STRENGTH_METER', '=TOS|STRENGTH_METER![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'OPEN', '=TOS|OPEN![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'HIGH', '=TOS|HIGH![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'LOW', '=TOS|LOW![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'CLOSE', '=TOS|CLOSE![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'VOLUME', '=TOS|VOLUME![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'OPEN_INT', '=TOS|OPEN_INT![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'IMPLIED_VOL', '=TOS|IMPL_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'VOL_INDEX', '=TOS|VOL_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'FRONT_VOL', '=TOS|FRONT_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'BACK_VOL', '=TOS|BACK_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'WEIGHTED_BACK_VOL', '=TOS|WEIGHTED_BACK_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'VOL_DIFF', '=TOS|VOL_DIFF![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'PUT_CALL_RATIO', '=TOS|PUT_CALL_RATIO![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'CALL_VOLUME_INDEX', '=TOS|CALL_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'PUT_VOLUME_INDEX', '=TOS|PUT_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'OPTION_VOLUME_INDEX', '=TOS|OPTION_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'FRONT_EXPECTED_MOVE', '=TOS|FRONT_EX_MOVE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'BACK_EXPECTED_MOVE', '=TOS|BACK_EX_MOVE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'EXPECTED_MOVE_DIFF', '=TOS|EX_MOVE_DIFF![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'BETA', '=TOS|BETA![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'HIGH52', '=TOS|''52HIGH''![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'LOW52', '=TOS|''52LOW''![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'PE', '=TOS|PE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'EPS', '=TOS|EPS![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'MARKET_CAP', '=TOS|MARKET_CAP![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'SHARES', '=TOS|SHARES![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'DIVIDEND_YIELD', '=TOS|YIELD![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'DIVIDEND_SHARE', '=TOS|DIV![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'LAST_UPDATE_TIMESTAMP', '=TimeStamp()', NULL);

CREATE TABLE "RTD"."TOS_OPTION_DATA_TICKS" (
    "ID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY,
    "CODE" VARCHAR(50) NULL,
    "DATETIME" TIMESTAMP(3) NULL,
    "DATE" DATE NULL,
    "TIME" TIME NULL,
    "DESCRIPTION" VARCHAR(255) NULL,
    "LAST" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "LAST_SIZE" SMALLINT NULL,
    "LAST_X" CHARACTER(1) NULL,
    "MARK" DOUBLE NULL,
    "MARK_CHANGE" DOUBLE NULL,
    "MARK_PERCENT_CHANGE" DOUBLE NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "BID_SIZE" SMALLINT NULL,
    "ASK_SIZE" SMALLINT NULL,
    "BID_ASK_SIZE" VARCHAR(50) NULL,
    "BID_X" CHARACTER(1) NULL,
    "ASK_X" CHARACTER(1) NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "CLOSE" DOUBLE NULL,
    "VOLUME" INTEGER NULL,
    "OPEN_INT" INTEGER NULL,
    "IMPLIED_VOL" DOUBLE NULL,
    "DELTA" DOUBLE NULL,
    "GAMMA" DOUBLE NULL,
    "THETA" DOUBLE NULL,
    "VEGA" DOUBLE NULL,
    "RHO" DOUBLE NULL,
    "EXTRINSIC" DOUBLE NULL,
    "INTRINSIC" DOUBLE NULL,
    "PROBABILITY_ITM" DOUBLE NULL,
    "PROBABILITY_OTM" DOUBLE NULL,
    "PROBABILITY_TOUCH" DOUBLE NULL,
    "COVERED_RETURN" DOUBLE NULL,
    "MAX_COVERED_RETURN" DOUBLE NULL,
    PRIMARY KEY ("ID")
);



INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'SELECT CODE FROM RTD.TOS_OPTION_LIST', 1, 1, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'ID');
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'CODE');
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'DATETIME', '=DateTime()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'TIME', '=Time()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'DESCRIPTION', '=TOS|DESCRIPTION!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'LAST', '=TOS|LAST!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'CHANGE', '=TOS|NET_CHANGE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'PERCENT_CHANGE', '=TOS|PERCENT_CHANGE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'LAST_SIZE', '=TOS|LAST_SIZE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'LAST_X', '=TOS|LX!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'MARK', '=TOS|MARK!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'MARK_CHANGE', '=TOS|MARK_CHANGE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'MARK_PERCENT_CHANGE', '=TOS|MARK_PERCENT_CHANGE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'BID', '=TOS|BID!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'ASK', '=TOS|ASK!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'BID_SIZE', '=TOS|BID_SIZE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'ASK_SIZE', '=TOS|ASK_SIZE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'BID_ASK_SIZE', '=TOS|BA_SIZE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'BID_X', '=TOS|BX!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'ASK_X', '=TOS|AX!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'OPEN', '=TOS|OPEN!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'HIGH', '=TOS|HIGH!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'LOW', '=TOS|LOW!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'CLOSE', '=TOS|Close!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'VOLUME', '=TOS|VOLUME!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'OPEN_INT', '=TOS|OPEN_INT!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'IMPLIED_VOL', '=TOS|IMPL_VOL!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'DELTA', '=TOS|DELTA!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'GAMMA', '=TOS|GAMMA!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'THETA', '=TOS|THETA!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'VEGA', '=TOS|VEGA!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'RHO', '=TOS|RHO!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'EXTRINSIC', '=TOS|EXTRINSIC!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'INTRINSIC', '=TOS|INTRINSIC!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'PROBABILITY_ITM', '=TOS|PROB_OF_EXPIRING!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'PROBABILITY_OTM', '=TOS|PROB_OTM!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'PROBABILITY_TOUCH', '=TOS|PROB_OF_TOUCHING!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'COVERED_RETURN', '=TOS|COVERED_RETURN!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'MAX_COVERED_RETURN', '=TOS|MAX_COVERED_RETURN!''[CODE]''', 1);

CREATE TABLE "RTD"."TOS_STOCK_QUOTES_TICKS" (
    "ID" BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY,
    "SYMBOL" VARCHAR(50) NULL,
    "DATETIME" TIMESTAMP(3) NULL,
    "DATE" DATE NULL,
    "TIME" TIME NULL,
    "DESCRIPTION" VARCHAR(255) NULL,
    "LAST" DOUBLE NULL,
    "CHANGE" DOUBLE NULL,
    "PERCENT_CHANGE" DOUBLE NULL,
    "LAST_SIZE" INTEGER NULL,
    "LAST_X" CHARACTER(1) NULL,
    "MARK" DOUBLE NULL,
    "MARK_CHANGE" DOUBLE NULL,
    "MARK_PERCENT_CHANGE" DOUBLE NULL,
    "BID" DOUBLE NULL,
    "ASK" DOUBLE NULL,
    "BID_SIZE" INTEGER NULL,
    "ASK_SIZE" INTEGER NULL,
    "BID_ASK_SIZE" VARCHAR(255) NULL,
    "BID_X" CHARACTER(1) NULL,
    "ASK_X" CHARACTER(1) NULL,
    "STRENGTH_METER" VARCHAR(255) NULL,
    "OPEN" DOUBLE NULL,
    "HIGH" DOUBLE NULL,
    "LOW" DOUBLE NULL,
    "CLOSE" DOUBLE NULL,
    "VOLUME" BIGINT NULL,
    "OPEN_INT" INTEGER NULL,
    "IMPLIED_VOL" DOUBLE NULL,
    "VOL_INDEX" DOUBLE NULL,
    "FRONT_VOL" DOUBLE NULL,
    "BACK_VOL" DOUBLE NULL,
    "WEIGHTED_BACK_VOL" DOUBLE NULL,
    "VOL_DIFF" DOUBLE NULL,
    "PUT_CALL_RATIO" DOUBLE NULL,
    "CALL_VOLUME_INDEX" DOUBLE NULL,
    "PUT_VOLUME_INDEX" DOUBLE NULL,
    "OPTION_VOLUME_INDEX" DOUBLE NULL,
    "FRONT_EXPECTED_MOVE" DOUBLE NULL,
    "BACK_EXPECTED_MOVE" DOUBLE NULL,
    "EXPECTED_MOVE_DIFF" DOUBLE NULL,
    "BETA" DOUBLE NULL,
    "HIGH52" DOUBLE NULL,
    "LOW52" DOUBLE NULL,
    "PE" DOUBLE NULL,
    "EPS" DOUBLE NULL,
    "MARKET_CAP" VARCHAR(255) NULL,
    "SHARES" BIGINT NULL,
    "DIVIDEND_YIELD" DOUBLE NULL,
    "DIVIDEND_SHARE" DOUBLE NULL,
    PRIMARY KEY ("ID")
);


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'SELECT SYMBOL FROM RTD.TOS_STOCK_LIST', 1, 1, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'ID');
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'SYMBOL');
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'DATETIME', '=DateTime()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'TIME', '=Time()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'DESCRIPTION', '=TOS|DESCRIPTION![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'LAST', '=TOS|LAST![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'CHANGE', '=TOS|NET_CHANGE![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'PERCENT_CHANGE', '=TOS|PERCENT_CHANGE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'LAST_SIZE', '=TOS|LAST_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'LAST_X', '=TOS|LX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'MARK', '=TOS|MARK![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'MARK_CHANGE', '=TOS|MARK_CHANGE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'MARK_PERCENT_CHANGE', '=TOS|MARK_PERCENT_CHANGE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'BID', '=TOS|BID![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'ASK', '=TOS|ASK![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'BID_SIZE', '=TOS|BID_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'ASK_SIZE', '=TOS|ASK_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'BID_ASK_SIZE', '=TOS|BA_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'BID_X', '=TOS|BX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'ASK_X', '=TOS|AX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'STRENGTH_METER', '=TOS|STRENGTH_METER![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'OPEN', '=TOS|OPEN![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'HIGH', '=TOS|HIGH![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'LOW', '=TOS|LOW![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'CLOSE', '=TOS|CLOSE![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'VOLUME', '=TOS|VOLUME![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'OPEN_INT', '=TOS|OPEN_INT![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'IMPLIED_VOL', '=TOS|IMPL_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'VOL_INDEX', '=TOS|VOL_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'FRONT_VOL', '=TOS|FRONT_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'BACK_VOL', '=TOS|BACK_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'WEIGHTED_BACK_VOL', '=TOS|WEIGHTED_BACK_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'VOL_DIFF', '=TOS|VOL_DIFF![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'PUT_CALL_RATIO', '=TOS|PUT_CALL_RATIO![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'CALL_VOLUME_INDEX', '=TOS|CALL_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'PUT_VOLUME_INDEX', '=TOS|PUT_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'OPTION_VOLUME_INDEX', '=TOS|OPTION_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'FRONT_EXPECTED_MOVE', '=TOS|FRONT_EX_MOVE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'BACK_EXPECTED_MOVE', '=TOS|BACK_EX_MOVE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'EXPECTED_MOVE_DIFF', '=TOS|EX_MOVE_DIFF![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'BETA', '=TOS|BETA![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'HIGH52', '=TOS|''52HIGH''![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'LOW52', '=TOS|''52LOW''![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'PE', '=TOS|PE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'EPS', '=TOS|EPS![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'MARKET_CAP', '=TOS|MARKET_CAP![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'SHARES', '=TOS|SHARES![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'DIVIDEND_YIELD', '=TOS|YIELD![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'DIVIDEND_SHARE', '=TOS|DIV![SYMBOL]', NULL);

