CREATE USER RTD
  IDENTIFIED BY "r#td_2014_abc!"
    DEFAULT TABLESPACE USERS
    TEMPORARY TABLESPACE TEMP
    PROFILE "DEFAULT"
    ACCOUNT UNLOCK
    QUOTA UNLIMITED ON USERS;

GRANT CONNECT TO RTD;

CREATE TABLE "RTD"."REAL_TIME_FORMULAS" (
    "ID" NUMBER NOT NULL,
    "TABLE_SCHEMA" VARCHAR2(128) NOT NULL,
    "TABLE_NAME" VARCHAR2(128) NOT NULL,
    "COLUMN_NAME" VARCHAR2(128) NOT NULL,
    "RTD_FORMULA" VARCHAR2(255) NULL,
    "IS_DISABLED" NUMBER(1) NULL,
  CONSTRAINT "PK_REAL_TIME_FORMULAS"
    PRIMARY KEY ("ID"),
  CONSTRAINT "IX_REAL_TIME_FORMULAS_COLUMN"
    UNIQUE ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME")
);

CREATE SEQUENCE "RTD"."SQ_REAL_TIME_FORMULAS_ID"
  INCREMENT BY 1
  START WITH 1
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER "RTD"."TRG_REAL_TIME_FORMULAS_ID"
  BEFORE INSERT OR UPDATE
  ON "RTD"."REAL_TIME_FORMULAS"
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :new.ID IS NULL THEN
    SELECT SQ_REAL_TIME_FORMULAS_ID.NEXTVAL INTO :new.ID FROM dual;
  END IF;
END;
/

CREATE TABLE "RTD"."REAL_TIME_TABLES" (
    "ID" NUMBER NOT NULL,
    "TABLE_SCHEMA" VARCHAR2(128) NOT NULL,
    "TABLE_NAME" VARCHAR2(128) NOT NULL,
    "LOAD_CODE" VARCHAR2(2000) NULL,
    "IS_HISTORY" NUMBER(1) NULL,
    "IS_DISABLED" NUMBER(1) NULL,
    "TIME_ZONE" VARCHAR2(50) NULL,
    "RTD_INSTANCE_NAME" VARCHAR2(50) NULL,
  CONSTRAINT "PK_REAL_TIME_TABLES"
    PRIMARY KEY ("ID"),
  CONSTRAINT "IX_REAL_TIME_TABLES_TABLE"
    UNIQUE ("TABLE_SCHEMA", "TABLE_NAME")
);

CREATE SEQUENCE "RTD"."SQ_REAL_TIME_TABLES_ID"
  INCREMENT BY 1
  START WITH 1
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER "RTD"."TRG_REAL_TIME_TABLES_ID"
  BEFORE INSERT OR UPDATE
  ON "RTD"."REAL_TIME_TABLES"
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :new.ID IS NULL THEN
    SELECT SQ_REAL_TIME_TABLES_ID.NEXTVAL INTO :new.ID FROM dual;
  END IF;
END;
/

