CREATE USER RTD
  IDENTIFIED BY "r#td_2014_abc!"
    DEFAULT TABLESPACE USERS
    TEMPORARY TABLESPACE TEMP
    PROFILE "DEFAULT"
    ACCOUNT UNLOCK
    QUOTA UNLIMITED ON USERS;

GRANT CONNECT TO RTD;

CREATE TABLE "RTD"."REAL_TIME_FORMULAS" (
    "ID" NUMBER NOT NULL,
    "TABLE_SCHEMA" VARCHAR2(128) NOT NULL,
    "TABLE_NAME" VARCHAR2(128) NOT NULL,
    "COLUMN_NAME" VARCHAR2(128) NOT NULL,
    "RTD_FORMULA" VARCHAR2(255) NULL,
    "IS_DISABLED" NUMBER(1) NULL,
  CONSTRAINT "PK_REAL_TIME_FORMULAS"
    PRIMARY KEY ("ID"),
  CONSTRAINT "IX_REAL_TIME_FORMULAS_COLUMN"
    UNIQUE ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME")
);

CREATE SEQUENCE "RTD"."SQ_REAL_TIME_FORMULAS_ID"
  INCREMENT BY 1
  START WITH 1
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER "RTD"."TRG_REAL_TIME_FORMULAS_ID"
  BEFORE INSERT OR UPDATE
  ON "RTD"."REAL_TIME_FORMULAS"
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :new.ID IS NULL THEN
    SELECT SQ_REAL_TIME_FORMULAS_ID.NEXTVAL INTO :new.ID FROM dual;
  END IF;
END;
/

CREATE TABLE "RTD"."REAL_TIME_TABLES" (
    "ID" NUMBER NOT NULL,
    "TABLE_SCHEMA" VARCHAR2(128) NOT NULL,
    "TABLE_NAME" VARCHAR2(128) NOT NULL,
    "LOAD_CODE" VARCHAR2(2000) NULL,
    "IS_HISTORY" NUMBER(1) NULL,
    "IS_DISABLED" NUMBER(1) NULL,
    "TIME_ZONE" VARCHAR2(50) NULL,
    "RTD_INSTANCE_NAME" VARCHAR2(50) NULL,
  CONSTRAINT "PK_REAL_TIME_TABLES"
    PRIMARY KEY ("ID"),
  CONSTRAINT "IX_REAL_TIME_TABLES_TABLE"
    UNIQUE ("TABLE_SCHEMA", "TABLE_NAME")
);

CREATE SEQUENCE "RTD"."SQ_REAL_TIME_TABLES_ID"
  INCREMENT BY 1
  START WITH 1
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER "RTD"."TRG_REAL_TIME_TABLES_ID"
  BEFORE INSERT OR UPDATE
  ON "RTD"."REAL_TIME_TABLES"
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :new.ID IS NULL THEN
    SELECT SQ_REAL_TIME_TABLES_ID.NEXTVAL INTO :new.ID FROM dual;
  END IF;
END;
/

CREATE TABLE "RTD"."TOS_STOCK_LIST" (
    "SYMBOL" VARCHAR2(50) NOT NULL,
  CONSTRAINT "PK_TOS_STOCK_LIST"
    PRIMARY KEY ("SYMBOL")
);


CREATE TABLE "RTD"."TOS_OPTION_LIST" (
    "CODE" VARCHAR2(50) NOT NULL,
  CONSTRAINT "PK_TOS_OPTION_LIST"
    PRIMARY KEY ("CODE")
);


CREATE TABLE "RTD"."TOS_HISTORICAL_OPTION_DATA" (
    "CODE" VARCHAR2(50) NOT NULL,
    "DATE" DATE NOT NULL,
    "TIME" TIMESTAMP(3) NULL,
    "DESCRIPTION" VARCHAR2(255) NULL,
    "LAST" BINARY_DOUBLE NULL,
    "CHANGE" BINARY_DOUBLE NULL,
    "PERCENT_CHANGE" BINARY_DOUBLE NULL,
    "LAST_SIZE" NUMBER NULL,
    "LAST_X" CHAR(1) NULL,
    "MARK" BINARY_DOUBLE NULL,
    "MARK_CHANGE" BINARY_DOUBLE NULL,
    "MARK_PERCENT_CHANGE" BINARY_DOUBLE NULL,
    "BID" BINARY_DOUBLE NULL,
    "ASK" BINARY_DOUBLE NULL,
    "BID_SIZE" NUMBER NULL,
    "ASK_SIZE" NUMBER NULL,
    "BID_ASK_SIZE" VARCHAR2(50) NULL,
    "BID_X" CHAR(1) NULL,
    "ASK_X" CHAR(1) NULL,
    "OPEN" BINARY_DOUBLE NULL,
    "HIGH" BINARY_DOUBLE NULL,
    "LOW" BINARY_DOUBLE NULL,
    "CLOSE" BINARY_DOUBLE NULL,
    "VOLUME" NUMBER NULL,
    "OPEN_INT" NUMBER NULL,
    "IMPLIED_VOL" BINARY_DOUBLE NULL,
    "DELTA" BINARY_DOUBLE NULL,
    "GAMMA" BINARY_DOUBLE NULL,
    "THETA" BINARY_DOUBLE NULL,
    "VEGA" BINARY_DOUBLE NULL,
    "RHO" BINARY_DOUBLE NULL,
    "EXTRINSIC" BINARY_DOUBLE NULL,
    "INTRINSIC" BINARY_DOUBLE NULL,
    "PROBABILITY_ITM" BINARY_DOUBLE NULL,
    "PROBABILITY_OTM" BINARY_DOUBLE NULL,
    "PROBABILITY_TOUCH" BINARY_DOUBLE NULL,
    "COVERED_RETURN" BINARY_DOUBLE NULL,
    "MAX_COVERED_RETURN" BINARY_DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
  CONSTRAINT "PK_TOS_HISTORICAL_OPTION_DATA"
    PRIMARY KEY ("CODE", "DATE")
);


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'SELECT CODE FROM RTD.TOS_OPTION_LIST', NULL, NULL, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'CODE');
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'TIME', '=Time()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'DESCRIPTION', '=TOS|DESCRIPTION!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'LAST', '=TOS|LAST!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'CHANGE', '=TOS|NET_CHANGE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'PERCENT_CHANGE', '=TOS|PERCENT_CHANGE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'LAST_SIZE', '=TOS|LAST_SIZE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'LAST_X', '=TOS|LX!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'MARK', '=TOS|MARK!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'MARK_CHANGE', '=TOS|MARK_CHANGE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'MARK_PERCENT_CHANGE', '=TOS|MARK_PERCENT_CHANGE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'BID', '=TOS|BID!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'ASK', '=TOS|ASK!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'BID_SIZE', '=TOS|BID_SIZE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'ASK_SIZE', '=TOS|ASK_SIZE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'BID_ASK_SIZE', '=TOS|BA_SIZE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'BID_X', '=TOS|BX!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'ASK_X', '=TOS|AX!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'OPEN', '=TOS|OPEN!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'HIGH', '=TOS|HIGH!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'LOW', '=TOS|LOW!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'CLOSE', '=TOS|Close!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'VOLUME', '=TOS|VOLUME!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'OPEN_INT', '=TOS|OPEN_INT!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'IMPLIED_VOL', '=TOS|IMPL_VOL!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'DELTA', '=TOS|DELTA!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'GAMMA', '=TOS|GAMMA!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'THETA', '=TOS|THETA!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'VEGA', '=TOS|VEGA!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'RHO', '=TOS|RHO!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'EXTRINSIC', '=TOS|EXTRINSIC!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'INTRINSIC', '=TOS|INTRINSIC!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'PROBABILITY_ITM', '=TOS|PROB_OF_EXPIRING!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'PROBABILITY_OTM', '=TOS|PROB_OTM!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'PROBABILITY_TOUCH', '=TOS|PROB_OF_TOUCHING!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'COVERED_RETURN', '=TOS|COVERED_RETURN!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'MAX_COVERED_RETURN', '=TOS|MAX_COVERED_RETURN!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_OPTION_DATA', 'LAST_UPDATE_TIMESTAMP', '=TimeStamp()', NULL);

CREATE TABLE "RTD"."TOS_HISTORICAL_PRICES" (
    "SYMBOL" VARCHAR2(50) NOT NULL,
    "DATE" DATE NOT NULL,
    "TIME" TIMESTAMP(3) NULL,
    "DESCRIPTION" VARCHAR2(255) NULL,
    "LAST" BINARY_DOUBLE NULL,
    "CHANGE" BINARY_DOUBLE NULL,
    "PERCENT_CHANGE" BINARY_DOUBLE NULL,
    "LAST_SIZE" NUMBER NULL,
    "LAST_X" CHAR(1) NULL,
    "MARK" BINARY_DOUBLE NULL,
    "MARK_CHANGE" BINARY_DOUBLE NULL,
    "MARK_PERCENT_CHANGE" BINARY_DOUBLE NULL,
    "BID" BINARY_DOUBLE NULL,
    "ASK" BINARY_DOUBLE NULL,
    "BID_SIZE" NUMBER NULL,
    "ASK_SIZE" NUMBER NULL,
    "BID_ASK_SIZE" VARCHAR2(255) NULL,
    "BID_X" CHAR(1) NULL,
    "ASK_X" CHAR(1) NULL,
    "STRENGTH_METER" VARCHAR2(255) NULL,
    "OPEN" BINARY_DOUBLE NULL,
    "HIGH" BINARY_DOUBLE NULL,
    "LOW" BINARY_DOUBLE NULL,
    "CLOSE" BINARY_DOUBLE NULL,
    "VOLUME" NUMBER NULL,
    "OPEN_INT" NUMBER NULL,
    "IMPLIED_VOL" BINARY_DOUBLE NULL,
    "VOL_INDEX" BINARY_DOUBLE NULL,
    "FRONT_VOL" BINARY_DOUBLE NULL,
    "BACK_VOL" BINARY_DOUBLE NULL,
    "WEIGHTED_BACK_VOL" BINARY_DOUBLE NULL,
    "VOL_DIFF" BINARY_DOUBLE NULL,
    "PUT_CALL_RATIO" BINARY_DOUBLE NULL,
    "CALL_VOLUME_INDEX" BINARY_DOUBLE NULL,
    "PUT_VOLUME_INDEX" BINARY_DOUBLE NULL,
    "OPTION_VOLUME_INDEX" BINARY_DOUBLE NULL,
    "FRONT_EXPECTED_MOVE" BINARY_DOUBLE NULL,
    "BACK_EXPECTED_MOVE" BINARY_DOUBLE NULL,
    "EXPECTED_MOVE_DIFF" BINARY_DOUBLE NULL,
    "BETA" BINARY_DOUBLE NULL,
    "HIGH52" BINARY_DOUBLE NULL,
    "LOW52" BINARY_DOUBLE NULL,
    "PE" BINARY_DOUBLE NULL,
    "EPS" BINARY_DOUBLE NULL,
    "MARKET_CAP" VARCHAR2(255) NULL,
    "SHARES" NUMBER NULL,
    "DIVIDEND_YIELD" BINARY_DOUBLE NULL,
    "DIVIDEND_SHARE" BINARY_DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
  CONSTRAINT "PK_TOS_HISTORICAL_PRICES"
    PRIMARY KEY ("SYMBOL", "DATE")
);


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'SELECT SYMBOL FROM RTD.TOS_STOCK_LIST', NULL, NULL, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'SYMBOL');
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'TIME', '=Time()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'DESCRIPTION', '=TOS|DESCRIPTION![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'LAST', '=TOS|LAST![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'CHANGE', '=TOS|NET_CHANGE![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'PERCENT_CHANGE', '=TOS|PERCENT_CHANGE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'LAST_SIZE', '=TOS|LAST_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'LAST_X', '=TOS|LX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'MARK', '=TOS|MARK![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'MARK_CHANGE', '=TOS|MARK_CHANGE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'MARK_PERCENT_CHANGE', '=TOS|MARK_PERCENT_CHANGE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'BID', '=TOS|BID![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'ASK', '=TOS|ASK![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'BID_SIZE', '=TOS|BID_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'ASK_SIZE', '=TOS|ASK_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'BID_ASK_SIZE', '=TOS|BA_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'BID_X', '=TOS|BX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'ASK_X', '=TOS|AX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'STRENGTH_METER', '=TOS|STRENGTH_METER![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'OPEN', '=TOS|OPEN![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'HIGH', '=TOS|HIGH![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'LOW', '=TOS|LOW![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'CLOSE', '=TOS|CLOSE![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'VOLUME', '=TOS|VOLUME![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'OPEN_INT', '=TOS|OPEN_INT![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'IMPLIED_VOL', '=TOS|IMPL_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'VOL_INDEX', '=TOS|VOL_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'FRONT_VOL', '=TOS|FRONT_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'BACK_VOL', '=TOS|BACK_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'WEIGHTED_BACK_VOL', '=TOS|WEIGHTED_BACK_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'VOL_DIFF', '=TOS|VOL_DIFF![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'PUT_CALL_RATIO', '=TOS|PUT_CALL_RATIO![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'CALL_VOLUME_INDEX', '=TOS|CALL_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'PUT_VOLUME_INDEX', '=TOS|PUT_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'OPTION_VOLUME_INDEX', '=TOS|OPTION_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'FRONT_EXPECTED_MOVE', '=TOS|FRONT_EX_MOVE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'BACK_EXPECTED_MOVE', '=TOS|BACK_EX_MOVE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'EXPECTED_MOVE_DIFF', '=TOS|EX_MOVE_DIFF![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'BETA', '=TOS|BETA![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'HIGH52', '=TOS|''52HIGH''![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'LOW52', '=TOS|''52LOW''![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'PE', '=TOS|PE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'EPS', '=TOS|EPS![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'MARKET_CAP', '=TOS|MARKET_CAP![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'SHARES', '=TOS|SHARES![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'DIVIDEND_YIELD', '=TOS|YIELD![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'DIVIDEND_SHARE', '=TOS|DIV![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_HISTORICAL_PRICES', 'LAST_UPDATE_TIMESTAMP', '=TimeStamp()', NULL);

CREATE TABLE "RTD"."TOS_LAST_OPTION_DATA" (
    "CODE" VARCHAR2(50) NOT NULL,
    "DATETIME" TIMESTAMP(3) NULL,
    "DATE" DATE NULL,
    "TIME" TIMESTAMP(3) NULL,
    "DESCRIPTION" VARCHAR2(255) NULL,
    "LAST" BINARY_DOUBLE NULL,
    "CHANGE" BINARY_DOUBLE NULL,
    "PERCENT_CHANGE" BINARY_DOUBLE NULL,
    "LAST_SIZE" NUMBER NULL,
    "LAST_X" CHAR(1) NULL,
    "MARK" BINARY_DOUBLE NULL,
    "MARK_CHANGE" BINARY_DOUBLE NULL,
    "MARK_PERCENT_CHANGE" BINARY_DOUBLE NULL,
    "BID" BINARY_DOUBLE NULL,
    "ASK" BINARY_DOUBLE NULL,
    "BID_SIZE" NUMBER NULL,
    "ASK_SIZE" NUMBER NULL,
    "BID_ASK_SIZE" VARCHAR2(50) NULL,
    "BID_X" CHAR(1) NULL,
    "ASK_X" CHAR(1) NULL,
    "OPEN" BINARY_DOUBLE NULL,
    "HIGH" BINARY_DOUBLE NULL,
    "LOW" BINARY_DOUBLE NULL,
    "CLOSE" BINARY_DOUBLE NULL,
    "VOLUME" NUMBER NULL,
    "OPEN_INT" NUMBER NULL,
    "IMPLIED_VOL" BINARY_DOUBLE NULL,
    "DELTA" BINARY_DOUBLE NULL,
    "GAMMA" BINARY_DOUBLE NULL,
    "THETA" BINARY_DOUBLE NULL,
    "VEGA" BINARY_DOUBLE NULL,
    "RHO" BINARY_DOUBLE NULL,
    "EXTRINSIC" BINARY_DOUBLE NULL,
    "INTRINSIC" BINARY_DOUBLE NULL,
    "PROBABILITY_ITM" BINARY_DOUBLE NULL,
    "PROBABILITY_OTM" BINARY_DOUBLE NULL,
    "PROBABILITY_TOUCH" BINARY_DOUBLE NULL,
    "COVERED_RETURN" BINARY_DOUBLE NULL,
    "MAX_COVERED_RETURN" BINARY_DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
  CONSTRAINT "PK_TOS_LAST_OPTION_DATA"
    PRIMARY KEY ("CODE")
);


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'SELECT CODE FROM RTD.TOS_OPTION_LIST', NULL, NULL, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'CODE');
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'DATETIME', '=DateTime()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'TIME', '=Time()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'DESCRIPTION', '=TOS|DESCRIPTION!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'LAST', '=TOS|LAST!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'CHANGE', '=TOS|NET_CHANGE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'PERCENT_CHANGE', '=TOS|PERCENT_CHANGE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'LAST_SIZE', '=TOS|LAST_SIZE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'LAST_X', '=TOS|LX!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'MARK', '=TOS|MARK!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'MARK_CHANGE', '=TOS|MARK_CHANGE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'MARK_PERCENT_CHANGE', '=TOS|MARK_PERCENT_CHANGE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'BID', '=TOS|BID!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'ASK', '=TOS|ASK!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'BID_SIZE', '=TOS|BID_SIZE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'ASK_SIZE', '=TOS|ASK_SIZE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'BID_ASK_SIZE', '=TOS|BA_SIZE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'BID_X', '=TOS|BX!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'ASK_X', '=TOS|AX!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'OPEN', '=TOS|OPEN!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'HIGH', '=TOS|HIGH!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'LOW', '=TOS|LOW!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'CLOSE', '=TOS|Close!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'VOLUME', '=TOS|VOLUME!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'OPEN_INT', '=TOS|OPEN_INT!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'IMPLIED_VOL', '=TOS|IMPL_VOL!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'DELTA', '=TOS|DELTA!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'GAMMA', '=TOS|GAMMA!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'THETA', '=TOS|THETA!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'VEGA', '=TOS|VEGA!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'RHO', '=TOS|RHO!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'EXTRINSIC', '=TOS|EXTRINSIC!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'INTRINSIC', '=TOS|INTRINSIC!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'PROBABILITY_ITM', '=TOS|PROB_OF_EXPIRING!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'PROBABILITY_OTM', '=TOS|PROB_OTM!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'PROBABILITY_TOUCH', '=TOS|PROB_OF_TOUCHING!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'COVERED_RETURN', '=TOS|COVERED_RETURN!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'MAX_COVERED_RETURN', '=TOS|MAX_COVERED_RETURN!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_OPTION_DATA', 'LAST_UPDATE_TIMESTAMP', '=TimeStamp()', NULL);

CREATE TABLE "RTD"."TOS_LAST_STOCK_QUOTES" (
    "SYMBOL" VARCHAR2(50) NOT NULL,
    "DATETIME" TIMESTAMP(3) NOT NULL,
    "DATE" DATE NULL,
    "TIME" TIMESTAMP(3) NULL,
    "DESCRIPTION" VARCHAR2(255) NULL,
    "LAST" BINARY_DOUBLE NULL,
    "CHANGE" BINARY_DOUBLE NULL,
    "PERCENT_CHANGE" BINARY_DOUBLE NULL,
    "LAST_SIZE" NUMBER NULL,
    "LAST_X" CHAR(1) NULL,
    "MARK" BINARY_DOUBLE NULL,
    "MARK_CHANGE" BINARY_DOUBLE NULL,
    "MARK_PERCENT_CHANGE" BINARY_DOUBLE NULL,
    "BID" BINARY_DOUBLE NULL,
    "ASK" BINARY_DOUBLE NULL,
    "BID_SIZE" NUMBER NULL,
    "ASK_SIZE" NUMBER NULL,
    "BID_ASK_SIZE" VARCHAR2(255) NULL,
    "BID_X" CHAR(1) NULL,
    "ASK_X" CHAR(1) NULL,
    "STRENGTH_METER" VARCHAR2(255) NULL,
    "OPEN" BINARY_DOUBLE NULL,
    "HIGH" BINARY_DOUBLE NULL,
    "LOW" BINARY_DOUBLE NULL,
    "CLOSE" BINARY_DOUBLE NULL,
    "VOLUME" NUMBER NULL,
    "OPEN_INT" NUMBER NULL,
    "IMPLIED_VOL" BINARY_DOUBLE NULL,
    "VOL_INDEX" BINARY_DOUBLE NULL,
    "FRONT_VOL" BINARY_DOUBLE NULL,
    "BACK_VOL" BINARY_DOUBLE NULL,
    "WEIGHTED_BACK_VOL" BINARY_DOUBLE NULL,
    "VOL_DIFF" BINARY_DOUBLE NULL,
    "PUT_CALL_RATIO" BINARY_DOUBLE NULL,
    "CALL_VOLUME_INDEX" BINARY_DOUBLE NULL,
    "PUT_VOLUME_INDEX" BINARY_DOUBLE NULL,
    "OPTION_VOLUME_INDEX" BINARY_DOUBLE NULL,
    "FRONT_EXPECTED_MOVE" BINARY_DOUBLE NULL,
    "BACK_EXPECTED_MOVE" BINARY_DOUBLE NULL,
    "EXPECTED_MOVE_DIFF" BINARY_DOUBLE NULL,
    "BETA" BINARY_DOUBLE NULL,
    "HIGH52" BINARY_DOUBLE NULL,
    "LOW52" BINARY_DOUBLE NULL,
    "PE" BINARY_DOUBLE NULL,
    "EPS" BINARY_DOUBLE NULL,
    "MARKET_CAP" VARCHAR2(255) NULL,
    "SHARES" NUMBER NULL,
    "DIVIDEND_YIELD" BINARY_DOUBLE NULL,
    "DIVIDEND_SHARE" BINARY_DOUBLE NULL,
    "LAST_UPDATE_TIMESTAMP" TIMESTAMP(3),
  CONSTRAINT "PK_TOS_LAST_STOCK_QUOTES"
    PRIMARY KEY ("SYMBOL")
);


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'SELECT SYMBOL FROM RTD.TOS_STOCK_LIST', NULL, NULL, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'SYMBOL');
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'DATETIME', '=DateTime()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'TIME', '=Time()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'DESCRIPTION', '=TOS|DESCRIPTION![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'LAST', '=TOS|LAST![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'CHANGE', '=TOS|NET_CHANGE![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'PERCENT_CHANGE', '=TOS|PERCENT_CHANGE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'LAST_SIZE', '=TOS|LAST_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'LAST_X', '=TOS|LX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'MARK', '=TOS|MARK![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'MARK_CHANGE', '=TOS|MARK_CHANGE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'MARK_PERCENT_CHANGE', '=TOS|MARK_PERCENT_CHANGE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'BID', '=TOS|BID![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'ASK', '=TOS|ASK![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'BID_SIZE', '=TOS|BID_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'ASK_SIZE', '=TOS|ASK_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'BID_ASK_SIZE', '=TOS|BA_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'BID_X', '=TOS|BX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'ASK_X', '=TOS|AX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'STRENGTH_METER', '=TOS|STRENGTH_METER![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'OPEN', '=TOS|OPEN![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'HIGH', '=TOS|HIGH![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'LOW', '=TOS|LOW![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'CLOSE', '=TOS|CLOSE![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'VOLUME', '=TOS|VOLUME![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'OPEN_INT', '=TOS|OPEN_INT![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'IMPLIED_VOL', '=TOS|IMPL_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'VOL_INDEX', '=TOS|VOL_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'FRONT_VOL', '=TOS|FRONT_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'BACK_VOL', '=TOS|BACK_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'WEIGHTED_BACK_VOL', '=TOS|WEIGHTED_BACK_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'VOL_DIFF', '=TOS|VOL_DIFF![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'PUT_CALL_RATIO', '=TOS|PUT_CALL_RATIO![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'CALL_VOLUME_INDEX', '=TOS|CALL_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'PUT_VOLUME_INDEX', '=TOS|PUT_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'OPTION_VOLUME_INDEX', '=TOS|OPTION_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'FRONT_EXPECTED_MOVE', '=TOS|FRONT_EX_MOVE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'BACK_EXPECTED_MOVE', '=TOS|BACK_EX_MOVE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'EXPECTED_MOVE_DIFF', '=TOS|EX_MOVE_DIFF![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'BETA', '=TOS|BETA![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'HIGH52', '=TOS|''52HIGH''![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'LOW52', '=TOS|''52LOW''![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'PE', '=TOS|PE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'EPS', '=TOS|EPS![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'MARKET_CAP', '=TOS|MARKET_CAP![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'SHARES', '=TOS|SHARES![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'DIVIDEND_YIELD', '=TOS|YIELD![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'DIVIDEND_SHARE', '=TOS|DIV![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_LAST_STOCK_QUOTES', 'LAST_UPDATE_TIMESTAMP', '=TimeStamp()', NULL);

CREATE TABLE "RTD"."TOS_OPTION_DATA_TICKS" (
    "ID" NUMBER NOT NULL,
    "CODE" VARCHAR2(50) NULL,
    "DATETIME" TIMESTAMP(3) NULL,
    "DATE" DATE NULL,
    "TIME" TIMESTAMP(3) NULL,
    "DESCRIPTION" VARCHAR2(255) NULL,
    "LAST" BINARY_DOUBLE NULL,
    "CHANGE" BINARY_DOUBLE NULL,
    "PERCENT_CHANGE" BINARY_DOUBLE NULL,
    "LAST_SIZE" NUMBER NULL,
    "LAST_X" CHAR(1) NULL,
    "MARK" BINARY_DOUBLE NULL,
    "MARK_CHANGE" BINARY_DOUBLE NULL,
    "MARK_PERCENT_CHANGE" BINARY_DOUBLE NULL,
    "BID" BINARY_DOUBLE NULL,
    "ASK" BINARY_DOUBLE NULL,
    "BID_SIZE" NUMBER NULL,
    "ASK_SIZE" NUMBER NULL,
    "BID_ASK_SIZE" VARCHAR2(50) NULL,
    "BID_X" CHAR(1) NULL,
    "ASK_X" CHAR(1) NULL,
    "OPEN" BINARY_DOUBLE NULL,
    "HIGH" BINARY_DOUBLE NULL,
    "LOW" BINARY_DOUBLE NULL,
    "CLOSE" BINARY_DOUBLE NULL,
    "VOLUME" NUMBER NULL,
    "OPEN_INT" NUMBER NULL,
    "IMPLIED_VOL" BINARY_DOUBLE NULL,
    "DELTA" BINARY_DOUBLE NULL,
    "GAMMA" BINARY_DOUBLE NULL,
    "THETA" BINARY_DOUBLE NULL,
    "VEGA" BINARY_DOUBLE NULL,
    "RHO" BINARY_DOUBLE NULL,
    "EXTRINSIC" BINARY_DOUBLE NULL,
    "INTRINSIC" BINARY_DOUBLE NULL,
    "PROBABILITY_ITM" BINARY_DOUBLE NULL,
    "PROBABILITY_OTM" BINARY_DOUBLE NULL,
    "PROBABILITY_TOUCH" BINARY_DOUBLE NULL,
    "COVERED_RETURN" BINARY_DOUBLE NULL,
    "MAX_COVERED_RETURN" BINARY_DOUBLE NULL,
  CONSTRAINT "PK_TOS_OPTION_DATA_TICKS"
    PRIMARY KEY ("ID")
);

CREATE SEQUENCE "RTD"."SQ_TOS_OPTION_DATA_TICKS_ID"
  INCREMENT BY 1
  START WITH 1
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER "RTD"."TRG_TOS_OPTION_DATA_TICKS_ID"
  BEFORE INSERT OR UPDATE
  ON "RTD"."TOS_OPTION_DATA_TICKS"
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :new.ID IS NULL THEN
    SELECT SQ_TOS_OPTION_DATA_TICKS_ID.NEXTVAL INTO :new.ID FROM dual;
  END IF;
END;
/


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'SELECT CODE FROM RTD.TOS_OPTION_LIST', 1, NULL, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'ID');
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'CODE');
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'DATETIME', '=DateTime()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'TIME', '=Time()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'DESCRIPTION', '=TOS|DESCRIPTION!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'LAST', '=TOS|LAST!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'CHANGE', '=TOS|NET_CHANGE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'PERCENT_CHANGE', '=TOS|PERCENT_CHANGE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'LAST_SIZE', '=TOS|LAST_SIZE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'LAST_X', '=TOS|LX!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'MARK', '=TOS|MARK!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'MARK_CHANGE', '=TOS|MARK_CHANGE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'MARK_PERCENT_CHANGE', '=TOS|MARK_PERCENT_CHANGE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'BID', '=TOS|BID!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'ASK', '=TOS|ASK!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'BID_SIZE', '=TOS|BID_SIZE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'ASK_SIZE', '=TOS|ASK_SIZE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'BID_ASK_SIZE', '=TOS|BA_SIZE!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'BID_X', '=TOS|BX!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'ASK_X', '=TOS|AX!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'OPEN', '=TOS|OPEN!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'HIGH', '=TOS|HIGH!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'LOW', '=TOS|LOW!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'CLOSE', '=TOS|Close!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'VOLUME', '=TOS|VOLUME!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'OPEN_INT', '=TOS|OPEN_INT!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'IMPLIED_VOL', '=TOS|IMPL_VOL!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'DELTA', '=TOS|DELTA!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'GAMMA', '=TOS|GAMMA!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'THETA', '=TOS|THETA!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'VEGA', '=TOS|VEGA!''[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'RHO', '=TOS|RHO!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'EXTRINSIC', '=TOS|EXTRINSIC!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'INTRINSIC', '=TOS|INTRINSIC!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'PROBABILITY_ITM', '=TOS|PROB_OF_EXPIRING!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'PROBABILITY_OTM', '=TOS|PROB_OTM!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'PROBABILITY_TOUCH', '=TOS|PROB_OF_TOUCHING!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'COVERED_RETURN', '=TOS|COVERED_RETURN!''[CODE]''', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_OPTION_DATA_TICKS', 'MAX_COVERED_RETURN', '=TOS|MAX_COVERED_RETURN!''[CODE]''', 1);

CREATE TABLE "RTD"."TOS_STOCK_QUOTES_TICKS" (
    "ID" NUMBER NOT NULL,
    "SYMBOL" VARCHAR2(50) NULL,
    "DATETIME" TIMESTAMP(3) NULL,
    "DATE" DATE NULL,
    "TIME" TIMESTAMP(3) NULL,
    "DESCRIPTION" VARCHAR2(255) NULL,
    "LAST" BINARY_DOUBLE NULL,
    "CHANGE" BINARY_DOUBLE NULL,
    "PERCENT_CHANGE" BINARY_DOUBLE NULL,
    "LAST_SIZE" NUMBER NULL,
    "LAST_X" CHAR(1) NULL,
    "MARK" BINARY_DOUBLE NULL,
    "MARK_CHANGE" BINARY_DOUBLE NULL,
    "MARK_PERCENT_CHANGE" BINARY_DOUBLE NULL,
    "BID" BINARY_DOUBLE NULL,
    "ASK" BINARY_DOUBLE NULL,
    "BID_SIZE" NUMBER NULL,
    "ASK_SIZE" NUMBER NULL,
    "BID_ASK_SIZE" VARCHAR2(255) NULL,
    "BID_X" CHAR(1) NULL,
    "ASK_X" CHAR(1) NULL,
    "STRENGTH_METER" VARCHAR2(255) NULL,
    "OPEN" BINARY_DOUBLE NULL,
    "HIGH" BINARY_DOUBLE NULL,
    "LOW" BINARY_DOUBLE NULL,
    "CLOSE" BINARY_DOUBLE NULL,
    "VOLUME" NUMBER NULL,
    "OPEN_INT" NUMBER NULL,
    "IMPLIED_VOL" BINARY_DOUBLE NULL,
    "VOL_INDEX" BINARY_DOUBLE NULL,
    "FRONT_VOL" BINARY_DOUBLE NULL,
    "BACK_VOL" BINARY_DOUBLE NULL,
    "WEIGHTED_BACK_VOL" BINARY_DOUBLE NULL,
    "VOL_DIFF" BINARY_DOUBLE NULL,
    "PUT_CALL_RATIO" BINARY_DOUBLE NULL,
    "CALL_VOLUME_INDEX" BINARY_DOUBLE NULL,
    "PUT_VOLUME_INDEX" BINARY_DOUBLE NULL,
    "OPTION_VOLUME_INDEX" BINARY_DOUBLE NULL,
    "FRONT_EXPECTED_MOVE" BINARY_DOUBLE NULL,
    "BACK_EXPECTED_MOVE" BINARY_DOUBLE NULL,
    "EXPECTED_MOVE_DIFF" BINARY_DOUBLE NULL,
    "BETA" BINARY_DOUBLE NULL,
    "HIGH52" BINARY_DOUBLE NULL,
    "LOW52" BINARY_DOUBLE NULL,
    "PE" BINARY_DOUBLE NULL,
    "EPS" BINARY_DOUBLE NULL,
    "MARKET_CAP" VARCHAR2(255) NULL,
    "SHARES" NUMBER NULL,
    "DIVIDEND_YIELD" BINARY_DOUBLE NULL,
    "DIVIDEND_SHARE" BINARY_DOUBLE NULL,
  CONSTRAINT "PK_TOS_STOCK_QUOTES_TICKS"
    PRIMARY KEY ("ID")
);

CREATE SEQUENCE "RTD"."SQ_TOS_STOCK_QUOTES_TICKS_ID"
  INCREMENT BY 1
  START WITH 1
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER "RTD"."TRG_TOS_STOCK_QUOTES_TICKS_ID"
  BEFORE INSERT OR UPDATE
  ON "RTD"."TOS_STOCK_QUOTES_TICKS"
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :new.ID IS NULL THEN
    SELECT SQ_TOS_STOCK_QUOTES_TICKS_ID.NEXTVAL INTO :new.ID FROM dual;
  END IF;
END;
/


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'SELECT SYMBOL FROM RTD.TOS_STOCK_LIST', 1, NULL, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'ID');
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'SYMBOL');
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'DATETIME', '=DateTime()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'TIME', '=Time()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'DESCRIPTION', '=TOS|DESCRIPTION![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'LAST', '=TOS|LAST![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'CHANGE', '=TOS|NET_CHANGE![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'PERCENT_CHANGE', '=TOS|PERCENT_CHANGE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'LAST_SIZE', '=TOS|LAST_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'LAST_X', '=TOS|LX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'MARK', '=TOS|MARK![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'MARK_CHANGE', '=TOS|MARK_CHANGE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'MARK_PERCENT_CHANGE', '=TOS|MARK_PERCENT_CHANGE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'BID', '=TOS|BID![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'ASK', '=TOS|ASK![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'BID_SIZE', '=TOS|BID_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'ASK_SIZE', '=TOS|ASK_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'BID_ASK_SIZE', '=TOS|BA_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'BID_X', '=TOS|BX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'ASK_X', '=TOS|AX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'STRENGTH_METER', '=TOS|STRENGTH_METER![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'OPEN', '=TOS|OPEN![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'HIGH', '=TOS|HIGH![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'LOW', '=TOS|LOW![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'CLOSE', '=TOS|CLOSE![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'VOLUME', '=TOS|VOLUME![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'OPEN_INT', '=TOS|OPEN_INT![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'IMPLIED_VOL', '=TOS|IMPL_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'VOL_INDEX', '=TOS|VOL_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'FRONT_VOL', '=TOS|FRONT_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'BACK_VOL', '=TOS|BACK_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'WEIGHTED_BACK_VOL', '=TOS|WEIGHTED_BACK_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'VOL_DIFF', '=TOS|VOL_DIFF![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'PUT_CALL_RATIO', '=TOS|PUT_CALL_RATIO![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'CALL_VOLUME_INDEX', '=TOS|CALL_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'PUT_VOLUME_INDEX', '=TOS|PUT_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'OPTION_VOLUME_INDEX', '=TOS|OPTION_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'FRONT_EXPECTED_MOVE', '=TOS|FRONT_EX_MOVE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'BACK_EXPECTED_MOVE', '=TOS|BACK_EX_MOVE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'EXPECTED_MOVE_DIFF', '=TOS|EX_MOVE_DIFF![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'BETA', '=TOS|BETA![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'HIGH52', '=TOS|''52HIGH''![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'LOW52', '=TOS|''52LOW''![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'PE', '=TOS|PE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'EPS', '=TOS|EPS![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'MARKET_CAP', '=TOS|MARKET_CAP![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'SHARES', '=TOS|SHARES![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'DIVIDEND_YIELD', '=TOS|YIELD![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'DIVIDEND_SHARE', '=TOS|DIV![SYMBOL]', NULL);

