CREATE TABLE "RTD"."TOS_STOCK_QUOTES_TICKS" (
    "ID" NUMBER NOT NULL,
    "SYMBOL" VARCHAR2(50) NULL,
    "DATETIME" TIMESTAMP(3) NULL,
    "DATE" DATE NULL,
    "TIME" TIMESTAMP(3) NULL,
    "DESCRIPTION" VARCHAR2(255) NULL,
    "LAST" BINARY_DOUBLE NULL,
    "CHANGE" BINARY_DOUBLE NULL,
    "PERCENT_CHANGE" BINARY_DOUBLE NULL,
    "LAST_SIZE" NUMBER NULL,
    "LAST_X" CHAR(1) NULL,
    "MARK" BINARY_DOUBLE NULL,
    "MARK_CHANGE" BINARY_DOUBLE NULL,
    "MARK_PERCENT_CHANGE" BINARY_DOUBLE NULL,
    "BID" BINARY_DOUBLE NULL,
    "ASK" BINARY_DOUBLE NULL,
    "BID_SIZE" NUMBER NULL,
    "ASK_SIZE" NUMBER NULL,
    "BID_ASK_SIZE" VARCHAR2(255) NULL,
    "BID_X" CHAR(1) NULL,
    "ASK_X" CHAR(1) NULL,
    "STRENGTH_METER" VARCHAR2(255) NULL,
    "OPEN" BINARY_DOUBLE NULL,
    "HIGH" BINARY_DOUBLE NULL,
    "LOW" BINARY_DOUBLE NULL,
    "CLOSE" BINARY_DOUBLE NULL,
    "VOLUME" NUMBER NULL,
    "OPEN_INT" NUMBER NULL,
    "IMPLIED_VOL" BINARY_DOUBLE NULL,
    "VOL_INDEX" BINARY_DOUBLE NULL,
    "FRONT_VOL" BINARY_DOUBLE NULL,
    "BACK_VOL" BINARY_DOUBLE NULL,
    "WEIGHTED_BACK_VOL" BINARY_DOUBLE NULL,
    "VOL_DIFF" BINARY_DOUBLE NULL,
    "PUT_CALL_RATIO" BINARY_DOUBLE NULL,
    "CALL_VOLUME_INDEX" BINARY_DOUBLE NULL,
    "PUT_VOLUME_INDEX" BINARY_DOUBLE NULL,
    "OPTION_VOLUME_INDEX" BINARY_DOUBLE NULL,
    "FRONT_EXPECTED_MOVE" BINARY_DOUBLE NULL,
    "BACK_EXPECTED_MOVE" BINARY_DOUBLE NULL,
    "EXPECTED_MOVE_DIFF" BINARY_DOUBLE NULL,
    "BETA" BINARY_DOUBLE NULL,
    "HIGH52" BINARY_DOUBLE NULL,
    "LOW52" BINARY_DOUBLE NULL,
    "PE" BINARY_DOUBLE NULL,
    "EPS" BINARY_DOUBLE NULL,
    "MARKET_CAP" VARCHAR2(255) NULL,
    "SHARES" NUMBER NULL,
    "DIVIDEND_YIELD" BINARY_DOUBLE NULL,
    "DIVIDEND_SHARE" BINARY_DOUBLE NULL,
  CONSTRAINT "PK_TOS_STOCK_QUOTES_TICKS"
    PRIMARY KEY ("ID")
);

CREATE SEQUENCE "RTD"."SQ_TOS_STOCK_QUOTES_TICKS_ID"
  INCREMENT BY 1
  START WITH 1
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER "RTD"."TRG_TOS_STOCK_QUOTES_TICKS_ID"
  BEFORE INSERT OR UPDATE
  ON "RTD"."TOS_STOCK_QUOTES_TICKS"
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :new.ID IS NULL THEN
    SELECT SQ_TOS_STOCK_QUOTES_TICKS_ID.NEXTVAL INTO :new.ID FROM dual;
  END IF;
END;
/


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'SELECT SYMBOL FROM RTD.TOS_STOCK_LIST', 1, NULL, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'ID');
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'SYMBOL');
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'DATETIME', '=DateTime()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'TIME', '=Time()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'DESCRIPTION', '=TOS|DESCRIPTION![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'LAST', '=TOS|LAST![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'CHANGE', '=TOS|NET_CHANGE![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'PERCENT_CHANGE', '=TOS|PERCENT_CHANGE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'LAST_SIZE', '=TOS|LAST_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'LAST_X', '=TOS|LX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'MARK', '=TOS|MARK![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'MARK_CHANGE', '=TOS|MARK_CHANGE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'MARK_PERCENT_CHANGE', '=TOS|MARK_PERCENT_CHANGE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'BID', '=TOS|BID![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'ASK', '=TOS|ASK![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'BID_SIZE', '=TOS|BID_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'ASK_SIZE', '=TOS|ASK_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'BID_ASK_SIZE', '=TOS|BA_SIZE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'BID_X', '=TOS|BX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'ASK_X', '=TOS|AX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'STRENGTH_METER', '=TOS|STRENGTH_METER![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'OPEN', '=TOS|OPEN![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'HIGH', '=TOS|HIGH![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'LOW', '=TOS|LOW![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'CLOSE', '=TOS|CLOSE![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'VOLUME', '=TOS|VOLUME![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'OPEN_INT', '=TOS|OPEN_INT![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'IMPLIED_VOL', '=TOS|IMPL_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'VOL_INDEX', '=TOS|VOL_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'FRONT_VOL', '=TOS|FRONT_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'BACK_VOL', '=TOS|BACK_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'WEIGHTED_BACK_VOL', '=TOS|WEIGHTED_BACK_VOL![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'VOL_DIFF', '=TOS|VOL_DIFF![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'PUT_CALL_RATIO', '=TOS|PUT_CALL_RATIO![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'CALL_VOLUME_INDEX', '=TOS|CALL_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'PUT_VOLUME_INDEX', '=TOS|PUT_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'OPTION_VOLUME_INDEX', '=TOS|OPTION_VOLUME_INDEX![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'FRONT_EXPECTED_MOVE', '=TOS|FRONT_EX_MOVE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'BACK_EXPECTED_MOVE', '=TOS|BACK_EX_MOVE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'EXPECTED_MOVE_DIFF', '=TOS|EX_MOVE_DIFF![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'BETA', '=TOS|BETA![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'HIGH52', '=TOS|''52HIGH''![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'LOW52', '=TOS|''52LOW''![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'PE', '=TOS|PE![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'EPS', '=TOS|EPS![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'MARKET_CAP', '=TOS|MARKET_CAP![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'SHARES', '=TOS|SHARES![SYMBOL]', 1);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'DIVIDEND_YIELD', '=TOS|YIELD![SYMBOL]', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "RTD_FORMULA", "IS_DISABLED") VALUES ('RTD', 'TOS_STOCK_QUOTES_TICKS', 'DIVIDEND_SHARE', '=TOS|DIV![SYMBOL]', NULL);

