CREATE TABLE "RTD"."TWS_OPTION_DATA_TICKS" (
    "ID" NUMBER NOT NULL,
    "CODE" VARCHAR2(255) NULL,
    "DATETIME" TIMESTAMP(3) NULL,
    "DATE" DATE NULL,
    "TIME" TIMESTAMP(3) NULL,
    "LAST" BINARY_DOUBLE NULL,
    "LAST_SIZE" NUMBER NULL,
    "BID" BINARY_DOUBLE NULL,
    "ASK" BINARY_DOUBLE NULL,
    "BID_SIZE" NUMBER NULL,
    "ASK_SIZE" NUMBER NULL,
    "HIGH" BINARY_DOUBLE NULL,
    "LOW" BINARY_DOUBLE NULL,
    "CLOSE" BINARY_DOUBLE NULL,
    "VOLUME" NUMBER NULL,
    "UNDERLYING_PRICE" BINARY_DOUBLE NULL,
    "MODEL_PRICE" BINARY_DOUBLE NULL,
    "IMPLIED_VOL" BINARY_DOUBLE NULL,
    "BID_IMPLIED_VOL" BINARY_DOUBLE NULL,
    "ASK_IMPLIED_VOL" BINARY_DOUBLE NULL,
    "LAST_IMPLIED_VOL" BINARY_DOUBLE NULL,
    "BID_DELTA" BINARY_DOUBLE NULL,
    "ASK_DELTA" BINARY_DOUBLE NULL,
    "LAST_DELTA" BINARY_DOUBLE NULL,
    "DELTA" BINARY_DOUBLE NULL,
    "GAMMA" BINARY_DOUBLE NULL,
    "THETA" BINARY_DOUBLE NULL,
    "VEGA" BINARY_DOUBLE NULL,
    "PV_DIVIDEND" BINARY_DOUBLE NULL,
  CONSTRAINT "PK_TWS_OPTION_DATA_TICKS"
    PRIMARY KEY ("ID")
);

CREATE SEQUENCE "RTD"."SQ_TWS_OPTION_DATA_TICKS_ID"
  INCREMENT BY 1
  START WITH 1
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER "RTD"."TRG_TWS_OPTION_DATA_TICKS_ID"
  BEFORE INSERT OR UPDATE
  ON "RTD"."TWS_OPTION_DATA_TICKS"
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :new.ID IS NULL THEN
    SELECT SQ_TWS_OPTION_DATA_TICKS_ID.NEXTVAL INTO :new.ID FROM dual;
  END IF;
END;
/

INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'SELECT TICK_ID, CODE FROM RTD.TWS_STOCK_LIST WHERE CODE LIKE ''%_OPT_20%''', 1, 1, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'TICK_ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'CODE', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'REQ', '=S|tik!''id[TICK_ID]?req?[CODE]''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'DATETIME', '=DateTime()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'TIME', '=Time()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'LAST', '=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'LAST_SIZE', '=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'BID', '=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'ASK', '=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'BID_SIZE', '=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'ASK_SIZE', '=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'HIGH', '=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'LOW', '=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'CLOSE', '=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'VOLUME', '=S|tik!id[TICK_ID]?volume', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'UNDERLYING_PRICE', '=S|tik!id[TICK_ID]?modelUndPrice', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'MODEL_PRICE', '=S|tik!id[TICK_ID]?modelPrice', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'IMPLIED_VOL', '=S|tik!id[TICK_ID]?modelVolatility', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'BID_IMPLIED_VOL', '=S|tik!id[TICK_ID]?bidImpliedVol', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'ASK_IMPLIED_VOL', '=S|tik!id[TICK_ID]?askImpliedVol', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'LAST_IMPLIED_VOL', '=S|tik!id[TICK_ID]?lastImpliedVol', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'BID_DELTA', '=S|tik!id[TICK_ID]?bidDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'ASK_DELTA', '=S|tik!id[TICK_ID]?askDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'LAST_DELTA', '=S|tik!id[TICK_ID]?lastDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'DELTA', '=S|tik!id[TICK_ID]?modelDelta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'GAMMA', '=S|tik!id[TICK_ID]?modelGamma', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'THETA', '=S|tik!id[TICK_ID]?modelTheta', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'VEGA', '=S|tik!id[TICK_ID]?modelVega', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_OPTION_DATA_TICKS', 'PV_DIVIDEND', '=S|tik!id[TICK_ID]?pvDividend', NULL);

