CREATE TABLE "RTD"."TWS_STOCK_QUOTES_TICKS" (
    "ID" NUMBER NOT NULL,
    "SYMBOL" VARCHAR2(50) NULL,
    "DATETIME" TIMESTAMP(3) NULL,
    "DATE" DATE NULL,
    "TIME" TIMESTAMP(3) NULL,
    "LAST" BINARY_DOUBLE NULL,
    "LAST_SIZE" NUMBER NULL,
    "BID" BINARY_DOUBLE NULL,
    "ASK" BINARY_DOUBLE NULL,
    "BID_SIZE" NUMBER NULL,
    "ASK_SIZE" NUMBER NULL,
    "HIGH" BINARY_DOUBLE NULL,
    "LOW" BINARY_DOUBLE NULL,
    "CLOSE" BINARY_DOUBLE NULL,
    "VOLUME" NUMBER NULL,
  CONSTRAINT "PK_TWS_STOCK_QUOTES_TICKS"
    PRIMARY KEY ("ID")
);

CREATE SEQUENCE "RTD"."SQ_TWS_STOCK_QUOTES_TICKS_ID"
  INCREMENT BY 1
  START WITH 1
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER "RTD"."TRG_TWS_STOCK_QUOTES_TICKS_ID"
  BEFORE INSERT OR UPDATE
  ON "RTD"."TWS_STOCK_QUOTES_TICKS"
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :new.ID IS NULL THEN
    SELECT SQ_TWS_STOCK_QUOTES_TICKS_ID.NEXTVAL INTO :new.ID FROM dual;
  END IF;
END;
/


INSERT INTO "RTD"."REAL_TIME_TABLES" (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'SELECT TICK_ID, CODE AS SYMBOL FROM RTD.TWS_STOCK_LIST WHERE CODE NOT LIKE ''%_OPT_20%''', 1, 1, 'Eastern Standard Time', NULL);

INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'TICK_ID', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'SYMBOL', NULL, NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'REQ', '=S|tik!''id[TICK_ID]?req?[SYMBOL]_STK_SMART_USD_~''', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'DATETIME', '=DateTime()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'DATE', '=Date()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'TIME', '=Time()', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'LAST', '=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'LAST_SIZE', '=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'BID', '=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'ASK', '=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'BID_SIZE', '=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'ASK_SIZE', '=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'HIGH', '=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'LOW', '=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'CLOSE', '=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO "RTD"."REAL_TIME_FORMULAS" (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES ('RTD', 'TWS_STOCK_QUOTES_TICKS', 'VOLUME', '=S|tik!id[TICK_ID]?volume', NULL);

