CREATE TABLE IF NOT EXISTS real_time_formulas (
    id integer NOT NULL PRIMARY KEY AUTOINCREMENT,
    table_schema varchar(128) NULL,
    table_name varchar(128) NOT NULL,
    column_name varchar(128) NOT NULL,
    rtd_formula varchar(255) NULL,
    is_disabled smallint NULL
);

CREATE UNIQUE INDEX ix_real_time_formulas_schema_name_column_name ON real_time_formulas (table_name, column_name);


CREATE TABLE IF NOT EXISTS real_time_tables (
    id integer NOT NULL PRIMARY KEY AUTOINCREMENT,
    table_schema varchar(128) NULL,
    table_name varchar(128) NOT NULL,
    load_code varchar(2000) NULL,
    is_history smallint NULL,
    is_disabled smallint NULL,
    time_zone varchar(50) NULL,
    rtd_instance_name varchar(50) NULL
);

CREATE UNIQUE INDEX ix_realtimetables_schema_name ON real_time_tables (table_name);

CREATE TABLE IF NOT EXISTS tws_stock_list (
    tick_id integer NOT NULL PRIMARY KEY AUTOINCREMENT,
    code varchar(50) NOT NULL
);

CREATE UNIQUE INDEX ix_tws_stock_list_code ON tws_stock_list (code);

CREATE TABLE IF NOT EXISTS tws_historical_option_data (
    code varchar(255) NOT NULL,
    date date NOT NULL,
    time time NULL,
    last double NULL,
    last_size integer NULL,
    bid double NULL,
    ask double NULL,
    bid_size integer NULL,
    ask_size integer NULL,
    high double NULL,
    low double NULL,
    close double NULL,
    volume bigint NULL,
    underlying_price double NULL,
    model_price double NULL,
    implied_vol double NULL,
    bid_implied_vol double NULL,
    ask_implied_vol double NULL,
    last_implied_vol double NULL,
    bid_delta double NULL,
    ask_delta double NULL,
    last_delta double NULL,
    delta double NULL,
    gamma double NULL,
    theta double NULL,
    vega double NULL,
    pv_dividend double NULL,
    last_update_timestamp timestamp default current_timestamp,
  PRIMARY KEY (code, date)
);

INSERT INTO real_time_tables (table_schema, table_name, load_code, is_history, is_disabled, time_zone, rtd_instance_name) VALUES (NULL, 'tws_historical_option_data', 'SELECT tick_id, code FROM tws_stock_list WHERE code LIKE ''%_OPT_20%''', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'tick_id', NULL, NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'code', NULL, NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'req', '=S|tik!''id[TICK_ID]?req?[CODE]''', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'date', '=Date()', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'time', '=Time()', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'last', '=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'last_size', '=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'bid', '=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'ask', '=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'bid_size', '=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'ask_size', '=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'high', '=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'low', '=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'close', '=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'volume', '=S|tik!id[TICK_ID]?volume', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'underlying_price', '=S|tik!id[TICK_ID]?modelUndPrice', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'model_price', '=S|tik!id[TICK_ID]?modelPrice', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'implied_vol', '=S|tik!id[TICK_ID]?modelVolatility', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'bid_implied_vol', '=S|tik!id[TICK_ID]?bidImpliedVol', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'ask_implied_vol', '=S|tik!id[TICK_ID]?askImpliedVol', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'last_implied_vol', '=S|tik!id[TICK_ID]?lastImpliedVol', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'bid_delta', '=S|tik!id[TICK_ID]?bidDelta', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'ask_delta', '=S|tik!id[TICK_ID]?askDelta', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'last_delta', '=S|tik!id[TICK_ID]?lastDelta', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'delta', '=S|tik!id[TICK_ID]?modelDelta', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'gamma', '=S|tik!id[TICK_ID]?modelGamma', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'theta', '=S|tik!id[TICK_ID]?modelTheta', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'vega', '=S|tik!id[TICK_ID]?modelVega', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_option_data', 'pv_dividend', '=S|tik!id[TICK_ID]?pvDividend', NULL);

CREATE TABLE IF NOT EXISTS tws_historical_prices (
    symbol varchar(50) NOT NULL,
    date date NOT NULL,
    time time NULL,
    last double NULL,
    last_size integer NULL,
    bid double NULL,
    ask double NULL,
    bid_size integer NULL,
    ask_size integer NULL,
    high double NULL,
    low double NULL,
    close double NULL,
    volume bigint NULL,
    last_update_timestamp timestamp default current_timestamp,
  PRIMARY KEY (symbol, date)
);

INSERT INTO real_time_tables (table_schema, table_name, load_code, is_history, is_disabled, time_zone, rtd_instance_name) VALUES (NULL, 'tws_historical_prices', 'SELECT tick_id, code AS SYMBOL FROM tws_stock_list WHERE code NOT LIKE ''%_OPT_20%''', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_prices', 'id', NULL, NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_prices', 'tick_id', NULL, NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_prices', 'symbol', NULL, NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_prices', 'req', '=S|tik!''id[TICK_ID]?req?[SYMBOL]_STK_SMART_USD_~''', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_prices', 'date', '=Date()', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_prices', 'time', '=Time()', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_prices', 'last', '=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_prices', 'last_size', '=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_prices', 'bid', '=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_prices', 'ask', '=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_prices', 'bid_size', '=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_prices', 'ask_size', '=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_prices', 'high', '=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_prices', 'low', '=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_prices', 'close', '=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_historical_prices', 'volume', '=S|tik!id[TICK_ID]?volume', NULL);

CREATE TABLE IF NOT EXISTS tws_last_option_data (
    code varchar(255) NOT NULL,
    datetime timestamp NULL,
    date date NULL,
    time time NULL,
    last double NULL,
    last_size integer NULL,
    bid double NULL,
    ask double NULL,
    bid_size integer NULL,
    ask_size integer NULL,
    high double NULL,
    low double NULL,
    close double NULL,
    volume bigint NULL,
    underlying_price double NULL,
    model_price double NULL,
    implied_vol double NULL,
    bid_implied_vol double NULL,
    ask_implied_vol double NULL,
    last_implied_vol double NULL,
    bid_delta double NULL,
    ask_delta double NULL,
    last_delta double NULL,
    delta double NULL,
    gamma double NULL,
    theta double NULL,
    vega double NULL,
    pv_dividend double NULL,
    last_update_timestamp timestamp default current_timestamp,
  PRIMARY KEY (code)
);

INSERT INTO real_time_tables (table_schema, table_name, load_code, is_history, is_disabled, time_zone, rtd_instance_name) VALUES (NULL, 'tws_last_option_data', 'SELECT tick_id, code FROM tws_stock_list WHERE code LIKE ''%_OPT_20%''', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'tick_id', NULL, NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'code', NULL, NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'req', '=S|tik!''id[TICK_ID]?req?[CODE]''', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'datetime', '=DateTime()', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'date', '=Date()', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'time', '=Time()', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'last', '=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'last_size', '=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'bid', '=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'ask', '=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'bid_size', '=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'ask_size', '=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'high', '=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'low', '=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'close', '=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'volume', '=S|tik!id[TICK_ID]?volume', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'underlying_price', '=S|tik!id[TICK_ID]?modelUndPrice', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'model_price', '=S|tik!id[TICK_ID]?modelPrice', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'implied_vol', '=S|tik!id[TICK_ID]?modelVolatility', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'bid_implied_vol', '=S|tik!id[TICK_ID]?bidImpliedVol', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'ask_implied_vol', '=S|tik!id[TICK_ID]?askImpliedVol', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'last_implied_vol', '=S|tik!id[TICK_ID]?lastImpliedVol', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'bid_delta', '=S|tik!id[TICK_ID]?bidDelta', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'ask_delta', '=S|tik!id[TICK_ID]?askDelta', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'last_delta', '=S|tik!id[TICK_ID]?lastDelta', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'delta', '=S|tik!id[TICK_ID]?modelDelta', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'gamma', '=S|tik!id[TICK_ID]?modelGamma', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'theta', '=S|tik!id[TICK_ID]?modelTheta', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'vega', '=S|tik!id[TICK_ID]?modelVega', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_option_data', 'pv_dividend', '=S|tik!id[TICK_ID]?pvDividend', NULL);

CREATE TABLE IF NOT EXISTS tws_last_stock_quotes (
    symbol varchar(50) NOT NULL,
    datetime timestamp NULL,
    date date NULL,
    time time NULL,
    last double NULL,
    last_size integer NULL,
    bid double NULL,
    ask double NULL,
    bid_size integer NULL,
    ask_size integer NULL,
    high double NULL,
    low double NULL,
    close double NULL,
    volume bigint NULL,
    last_update_timestamp timestamp default current_timestamp,
  PRIMARY KEY (symbol)
);

INSERT INTO real_time_tables (table_schema, table_name, load_code, is_history, is_disabled, time_zone, rtd_instance_name) VALUES (NULL, 'tws_last_stock_quotes', 'SELECT tick_id, code AS SYMBOL FROM tws_stock_list WHERE code NOT LIKE ''%_OPT_20%''', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_stock_quotes', 'tick_id', NULL, NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_stock_quotes', 'symbol', NULL, NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_stock_quotes', 'req', '=S|tik!''id[TICK_ID]?req?[SYMBOL]_STK_SMART_USD_~''', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_stock_quotes', 'datetime', '=DateTime()', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_stock_quotes', 'date', '=Date()', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_stock_quotes', 'time', '=Time()', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_stock_quotes', 'last', '=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_stock_quotes', 'last_size', '=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_stock_quotes', 'bid', '=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_stock_quotes', 'ask', '=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_stock_quotes', 'bid_size', '=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_stock_quotes', 'ask_size', '=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_stock_quotes', 'high', '=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_stock_quotes', 'low', '=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_stock_quotes', 'close', '=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_last_stock_quotes', 'volume', '=S|tik!id[TICK_ID]?volume', NULL);

CREATE TABLE IF NOT EXISTS tws_option_data_ticks (
    id integer NOT NULL PRIMARY KEY AUTOINCREMENT,
    code varchar(255) NOT NULL,
    datetime timestamp NULL,
    date date NULL,
    time time NULL,
    last double NULL,
    last_size integer NULL,
    bid double NULL,
    ask double NULL,
    bid_size integer NULL,
    ask_size integer NULL,
    high double NULL,
    low double NULL,
    close double NULL,
    volume bigint NULL,
    underlying_price double NULL,
    model_price double NULL,
    implied_vol double NULL,
    bid_implied_vol double NULL,
    ask_implied_vol double NULL,
    last_implied_vol double NULL,
    bid_delta double NULL,
    ask_delta double NULL,
    last_delta double NULL,
    delta double NULL,
    gamma double NULL,
    theta double NULL,
    vega double NULL,
    pv_dividend double NULL
);

INSERT INTO real_time_tables (table_schema, table_name, load_code, is_history, is_disabled, time_zone, rtd_instance_name) VALUES (NULL, 'tws_option_data_ticks', 'SELECT tick_id, code FROM tws_stock_list WHERE code LIKE ''%_OPT_20%''', 1, 1, 'Eastern Standard Time', NULL);

INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'id', NULL, NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'tick_id', NULL, NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'code', NULL, NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'req', '=S|tik!''id[TICK_ID]?req?[CODE]''', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'datetime', '=DateTime()', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'date', '=Date()', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'time', '=Time()', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'last', '=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'last_size', '=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'bid', '=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'ask', '=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'bid_size', '=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'ask_size', '=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'high', '=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'low', '=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'close', '=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'volume', '=S|tik!id[TICK_ID]?volume', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'underlying_price', '=S|tik!id[TICK_ID]?modelUndPrice', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'model_price', '=S|tik!id[TICK_ID]?modelPrice', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'implied_vol', '=S|tik!id[TICK_ID]?modelVolatility', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'bid_implied_vol', '=S|tik!id[TICK_ID]?bidImpliedVol', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'ask_implied_vol', '=S|tik!id[TICK_ID]?askImpliedVol', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'last_implied_vol', '=S|tik!id[TICK_ID]?lastImpliedVol', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'bid_delta', '=S|tik!id[TICK_ID]?bidDelta', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'ask_delta', '=S|tik!id[TICK_ID]?askDelta', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'last_delta', '=S|tik!id[TICK_ID]?lastDelta', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'delta', '=S|tik!id[TICK_ID]?modelDelta', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'gamma', '=S|tik!id[TICK_ID]?modelGamma', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'theta', '=S|tik!id[TICK_ID]?modelTheta', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'vega', '=S|tik!id[TICK_ID]?modelVega', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_option_data_ticks', 'pv_dividend', '=S|tik!id[TICK_ID]?pvDividend', NULL);

CREATE TABLE IF NOT EXISTS tws_stock_quotes_ticks (
    id integer NOT NULL PRIMARY KEY AUTOINCREMENT,
    symbol varchar(50) NOT NULL,
    datetime timestamp NULL,
    date date NULL,
    time time NULL,
    last double NULL,
    last_size integer NULL,
    bid double NULL,
    ask double NULL,
    bid_size integer NULL,
    ask_size integer NULL,
    high double NULL,
    low double NULL,
    close double NULL,
    volume bigint NULL
);

INSERT INTO real_time_tables (table_schema, table_name, load_code, is_history, is_disabled, time_zone, rtd_instance_name) VALUES (NULL, 'tws_stock_quotes_ticks', 'SELECT tick_id, code AS SYMBOL FROM tws_stock_list WHERE code NOT LIKE ''%_OPT_20%''', 1, 1, 'Eastern Standard Time', NULL);

INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_stock_quotes_ticks', 'id', NULL, NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_stock_quotes_ticks', 'tick_id', NULL, NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_stock_quotes_ticks', 'symbol', NULL, NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_stock_quotes_ticks', 'req', '=S|tik!''id[TICK_ID]?req?[SYMBOL]_STK_SMART_USD_~''', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_stock_quotes_ticks', 'datetime', '=DateTime()', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_stock_quotes_ticks', 'date', '=Date()', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_stock_quotes_ticks', 'time', '=Time()', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_stock_quotes_ticks', 'last', '=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_stock_quotes_ticks', 'last_size', '=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_stock_quotes_ticks', 'bid', '=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_stock_quotes_ticks', 'ask', '=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_stock_quotes_ticks', 'bid_size', '=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_stock_quotes_ticks', 'ask_size', '=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_stock_quotes_ticks', 'high', '=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_stock_quotes_ticks', 'low', '=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_stock_quotes_ticks', 'close', '=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'tws_stock_quotes_ticks', 'volume', '=S|tik!id[TICK_ID]?volume', NULL);

