CREATE TABLE IF NOT EXISTS real_time_formulas (
    id integer NOT NULL PRIMARY KEY AUTOINCREMENT,
    table_schema varchar(128) NULL,
    table_name varchar(128) NOT NULL,
    column_name varchar(128) NOT NULL,
    rtd_formula varchar(255) NULL,
    is_disabled smallint NULL
);

CREATE UNIQUE INDEX ix_real_time_formulas_schema_name_column_name ON real_time_formulas (table_name, column_name);


CREATE TABLE IF NOT EXISTS real_time_tables (
    id integer NOT NULL PRIMARY KEY AUTOINCREMENT,
    table_schema varchar(128) NULL,
    table_name varchar(128) NOT NULL,
    load_code varchar(2000) NULL,
    is_history smallint NULL,
    is_disabled smallint NULL,
    time_zone varchar(50) NULL,
    rtd_instance_name varchar(50) NULL
);

CREATE UNIQUE INDEX ix_realtimetables_schema_name ON real_time_tables (table_name);

CREATE TABLE IF NOT EXISTS vfx_stock_list (
    code varchar(50) NOT NULL,
  PRIMARY KEY (code)
);


CREATE TABLE IF NOT EXISTS vfx_historical_prices (
    symbol varchar(50) NOT NULL,
    date date NOT NULL,
    time time NULL,
    bid double NULL,
    ask double NULL,
    open double NULL,
    high double NULL,
    low double NULL,
    close double NULL,
    change double NULL,
    percent_change double NULL,
    last_update_timestamp timestamp default current_timestamp,
  PRIMARY KEY (symbol, date)
);

INSERT INTO real_time_tables (table_schema, table_name, load_code, is_history, is_disabled, time_zone, rtd_instance_name) VALUES (NULL, 'vfx_historical_prices', 'SELECT code FROM vfx_stock_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_historical_prices', 'code', NULL, NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_historical_prices', 'symbol', '=VFX|Name![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_historical_prices', 'date', '=Date()', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_historical_prices', 'time', '=VFX|Time![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_historical_prices', 'change', '=VFX|NetChange![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_historical_prices', 'percent_change', '=VFX|PercentChange![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_historical_prices', 'bid', '=VFX|Bid![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_historical_prices', 'ask', '=VFX|Ask![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_historical_prices', 'open', '=VFX|OpenPrice![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_historical_prices', 'high', '=VFX|High![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_historical_prices', 'low', '=VFX|Low![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_historical_prices', 'close', '=VFX|ClosePrice![CODE]', NULL);

CREATE TABLE IF NOT EXISTS vfx_last_stock_quotes (
    symbol varchar(50) NOT NULL,
    date date NULL,
    time time NULL,
    bid double NULL,
    ask double NULL,
    open double NULL,
    high double NULL,
    low double NULL,
    close double NULL,
    change double NULL,
    percent_change double NULL,
    last_update_timestamp timestamp default current_timestamp,
  PRIMARY KEY (symbol)
);

INSERT INTO real_time_tables (table_schema, table_name, load_code, is_history, is_disabled, time_zone, rtd_instance_name) VALUES (NULL, 'vfx_last_stock_quotes', 'SELECT code FROM vfx_stock_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_last_stock_quotes', 'code', NULL, NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_last_stock_quotes', 'symbol', '=VFX|Name![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_last_stock_quotes', 'date', '=Date()', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_last_stock_quotes', 'time', '=VFX|Time![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_last_stock_quotes', 'change', '=VFX|NetChange![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_last_stock_quotes', 'percent_change', '=VFX|PercentChange![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_last_stock_quotes', 'bid', '=VFX|Bid![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_last_stock_quotes', 'ask', '=VFX|Ask![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_last_stock_quotes', 'open', '=VFX|OpenPrice![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_last_stock_quotes', 'high', '=VFX|High![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_last_stock_quotes', 'low', '=VFX|Low![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_last_stock_quotes', 'close', '=VFX|ClosePrice![CODE]', NULL);

CREATE TABLE IF NOT EXISTS vfx_stock_quotes_ticks (
    id integer NOT NULL PRIMARY KEY AUTOINCREMENT,
    symbol varchar(50) NOT NULL,
    date date NULL,
    time time NULL,
    bid double NULL,
    ask double NULL,
    open double NULL,
    high double NULL,
    low double NULL,
    close double NULL,
    change double NULL,
    percent_change double NULL
);

INSERT INTO real_time_tables (table_schema, table_name, load_code, is_history, is_disabled, time_zone, rtd_instance_name) VALUES (NULL, 'vfx_stock_quotes_ticks', 'SELECT code FROM vfx_stock_list', 1, 1, 'Eastern Standard Time', NULL);

INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_stock_quotes_ticks', 'id', NULL, NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_stock_quotes_ticks', 'code', NULL, NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_stock_quotes_ticks', 'symbol', '=VFX|Name![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_stock_quotes_ticks', 'date', '=Date()', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_stock_quotes_ticks', 'time', '=VFX|Time![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_stock_quotes_ticks', 'change', '=VFX|NetChange![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_stock_quotes_ticks', 'percent_change', '=VFX|PercentChange![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_stock_quotes_ticks', 'bid', '=VFX|Bid![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_stock_quotes_ticks', 'ask', '=VFX|Ask![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_stock_quotes_ticks', 'open', '=VFX|OpenPrice![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_stock_quotes_ticks', 'high', '=VFX|High![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_stock_quotes_ticks', 'low', '=VFX|Low![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_stock_quotes_ticks', 'close', '=VFX|ClosePrice![CODE]', NULL);

CREATE TABLE IF NOT EXISTS vfx_stock_quotes_time (
    symbol varchar(50) NOT NULL,
    date date NOT NULL,
    time time NOT NULL,
    bid double NULL,
    ask double NULL,
    open double NULL,
    high double NULL,
    low double NULL,
    close double NULL,
    change double NULL,
    percent_change double NULL,
    last_update_timestamp timestamp default current_timestamp,
  PRIMARY KEY (symbol, date, time)
);

INSERT INTO real_time_tables (table_schema, table_name, load_code, is_history, is_disabled, time_zone, rtd_instance_name) VALUES (NULL, 'vfx_stock_quotes_time', 'SELECT code FROM vfx_stock_list', NULL, 1, 'Eastern Standard Time', NULL);

INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_stock_quotes_time', 'code', NULL, NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_stock_quotes_time', 'symbol', '=VFX|Name![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_stock_quotes_time', 'date', '=Date()', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_stock_quotes_time', 'time', '=VFX|Time![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_stock_quotes_time', 'change', '=VFX|NetChange![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_stock_quotes_time', 'percent_change', '=VFX|PercentChange![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_stock_quotes_time', 'bid', '=VFX|Bid![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_stock_quotes_time', 'ask', '=VFX|Ask![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_stock_quotes_time', 'open', '=VFX|OpenPrice![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_stock_quotes_time', 'high', '=VFX|High![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_stock_quotes_time', 'low', '=VFX|Low![CODE]', NULL);
INSERT INTO real_time_formulas (table_schema, table_name, column_name, rtd_formula, is_disabled) VALUES (NULL, 'vfx_stock_quotes_time', 'close', '=VFX|ClosePrice![CODE]', NULL);

